# *******************************************************************************
# IBM Confidential
# OCO Source Materials
# © Copyright IBM Corp. 2011
#
# The source code for this program is not published or otherwise divested of its trade secrets, 
# irrespective of what has been deposited with the U.S. Copyright Office.
# ******************************************************************************/

#!/bin/bash

JAVA=java

CLASSNAME=com.ibm.sunset.common.globalization.Server.MessageRetrieval

export CLASSPATH=./MessageRetrieval.jar:./lib/log4j-1.2.15.jar:$CLASSPATH

DB2=db2

TMP_F_NAME=sql.tmp
LOG_F_NAME=federation.log

SPACE=" "
DB2_CMD_SEPARATOR="@"

TDW_SCHEMA_NAME="ITMUSER"

REM="rm -f"
DB2_CMD_CREATE_NICKNAME="CREATE OR REPLACE NICKNAME"
DB2_CMD_DROP_NICKNAME="DROP NICKNAME"
DB2_CMD_CREATE_VIEW="CREATE OR REPLACE VIEW"
DB2_CMD_DROP_VIEW="DROP VIEW"
DB2_CMD_CREATE_TABLE="CREATE TABLE"
DB2_CMD_DROP_TABLE="DROP TABLE"

VIEW_EXISTS=0
LAST_ERROR=0

FAILED_COUNT=0
FAILED_VIEWS=""

################################################################################
# List of supported federated metrices.
################################################################################
ALL_SUPPORTED="PS_CPU PS_CPU_H PS_CPU_D PS_CPU_W PS_CPU_M PS_CPU_Q PS_CPU_Y PS_MEM PS_MEM_H PS_MEM_D PS_MEM_W PS_MEM_M PS_MEM_Q PS_MEM_Y PS_IO PS_IO_H PS_IO_D PS_IO_W PS_IO_M PS_IO_Q PS_IO_Y PS_NET PS_NET_H PS_NET_D PS_NET_W PS_NET_M PS_NET_Q PS_NET_Y VM_CPU VM_CPU_H VM_CPU_D VM_CPU_W VM_CPU_M VM_CPU_Q VM_CPU_Y VM_MEM VM_MEM_H VM_MEM_D VM_MEM_W VM_MEM_M VM_MEM_Q VM_MEM_Y VM_NET VM_NET_H VM_NET_D VM_NET_W VM_NET_M VM_NET_Q VM_NET_Y VM_DS VM_DS_H VM_DS_D VM_DS_W VM_DS_M VM_DS_Q VM_DS_Y"

################################################################################
# List of SQL statements forming bodies of the Datamart views.
################################################################################
VIEW_BODY_SERVER_CPU="SELECT T.\"SERVER_HOSTNAME\" AS HOST_NAME, T.\"CPU_NUMBER\" AS CPU_NUMBER, T.\"CPU_UTILIZATION\" AS CPU_UTILIZATION, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_SERVER_CPU_AGG="SELECT T.\"SERVER_HOSTNAME\" AS HOST_NAME, T.\"CPU_NUMBER\" AS CPU_NUMBER, T.\"MIN_CPU_UTILIZATION\" AS MIN_CPU_UTILIZATION, T.\"MAX_CPU_UTILIZATION\" AS MAX_CPU_UTILIZATION, T.\"SUM_CPU_UTILIZATION\" AS SUM_CPU_UTILIZATION, T.\"AVG_CPU_UTILIZATION\" AS AVG_CPU_UTILIZATION, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_SERVER_MEM="SELECT T.\"SERVER_HOSTNAME\" AS HOST_NAME, T.\"PHYSICAL_MEMORY\" AS PHYSICAL_MEMORY, T.\"MEMORY_USAGE\" AS MEMORY_USAGE, T.\"MEMORY_UTILIZATION\" AS MEMORY_UTILIZATION, T.\"ACTIVE_MEMORY\" AS ACTIVE_MEMORY, T.\"GRANTED_MEMORY\" AS GRANTED_MEMORY, T.\"SWAP_USED\" AS SWAP_USED, T.\"FREE_MEMORY\" AS FREE_MEM, T.\"BALLOON_USED\" AS BALLOON_USED, T.\"SWAP_IN_RATE\" AS SWAP_IN_RATE, T.\"SWAP_OUT_RATE\" AS SWAP_OUT_RATE, T.\"SWAP_TOTAL_RATE\" AS SWAP_TOTAL_RATE, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_SERVER_MEM_AGG="SELECT T.\"SERVER_HOSTNAME\" AS HOST_NAME, T.\"MIN_PHYSICAL_MEMORY\" AS PHYSICAL_MEMORY, T.\"MIN_MEMORY_USAGE\" AS MIN_MEMORY_USAGE, T.\"MAX_MEMORY_USAGE\" AS MAX_MEMORY_USAGE, T.\"SUM_MEMORY_USAGE\" AS SUM_MEMORY_USAGE, T.\"AVG_MEMORY_USAGE\" AS AVG_MEMORY_USAGE, T.\"MIN_MEMORY_UTILIZATION\" AS MIN_MEMORY_UTILIZATION, T.\"MAX_MEMORY_UTILIZATION\" AS MAX_MEMORY_UTILIZATION, T.\"SUM_MEMORY_UTILIZATION\" AS SUM_MEMORY_UTILIZATION, T.\"AVG_MEMORY_UTILIZATION\" AS AVG_MEMORY_UTILIZATION, T.\"MIN_ACTIVE_MEMORY\" AS MIN_ACTIVE_MEMORY, T.\"MAX_ACTIVE_MEMORY\" AS MAX_ACTIVE_MEMORY, T.\"SUM_ACTIVE_MEMORY\" AS SUM_ACTIVE_MEMORY, T.\"AVG_ACTIVE_MEMORY\" AS AVG_ACTIVE_MEMORY, T.\"MIN_GRANTED_MEMORY\" AS MIN_GRANTED_MEMORY, T.\"MAX_GRANTED_MEMORY\" AS MAX_GRANTED_MEMORY, T.\"SUM_GRANTED_MEMORY\" AS SUM_GRANTED_MEMORY, T.\"AVG_GRANTED_MEMORY\" AS AVG_GRANTED_MEMORY, T.\"MIN_SWAP_USED\" AS MIN_SWAP_USED, T.\"MAX_SWAP_USED\" AS MAX_SWAP_USED, T.\"SUM_SWAP_USED\" AS SUM_SWAP_USED, T.\"AVG_SWAP_USED\" AS AVG_SWAP_USED, T.\"MIN_FREE_MEMORY\" AS MIN_FREE_MEM, T.\"MAX_FREE_MEMORY\" AS MAX_FREE_MEM, T.\"SUM_FREE_MEMORY\" AS SUM_FREE_MEM, T.\"AVG_FREE_MEMORY\" AS AVG_FREE_MEM, T.\"MIN_BALLOON_USED\" AS MIN_BALLOON_USED, T.\"MAX_BALLOON_USED\" AS MAX_BALLOON_USED, T.\"SUM_BALLOON_USED\" AS SUM_BALLOON_USED, T.\"AVG_BALLOON_USED\" AS AVG_BALLOON_USED, T.\"MIN_SWAP_IN_RATE\" AS MIN_SWAP_IN_RATE, T.\"MAX_SWAP_IN_RATE\" AS MAX_SWAP_IN_RATE, T.\"SUM_SWAP_IN_RATE\" AS SUM_SWAP_IN_RATE, T.\"AVG_SWAP_IN_RATE\" AS AVG_SWAP_IN_RATE, T.\"MIN_SWAP_OUT_RATE\" AS MIN_SWAP_OUT_RATE, T.\"MAX_SWAP_OUT_RATE\" AS MAX_SWAP_OUT_RATE, T.\"SUM_SWAP_OUT_RATE\" AS SUM_SWAP_OUT_RATE, T.\"AVG_SWAP_OUT_RATE\" AS AVG_SWAP_OUT_RATE, T.\"MIN_SWAP_TOTAL_RATE\" AS MIN_SWAP_TOTAL_RATE, T.\"MAX_SWAP_TOTAL_RATE\" AS MAX_SWAP_TOTAL_RATE, T.\"SUM_SWAP_TOTAL_RATE\" AS SUM_SWAP_TOTAL_RATE, T.\"AVG_SWAP_TOTAL_RATE\" AS AVG_SWAP_TOTAL_RATE, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_SERVER_DISK="SELECT T.\"SERVER_HOSTNAME\" AS HOST_NAME, T.\"DISK_NAME\" AS DISK_NAME, T.\"BACKING_DATASTORE\" AS DATA_STORE_NAME, T.\"READ\" AS READ_KBPS, T.\"WRITE\" AS WRITE_KBPS, T.\"NUMBER_READ\" AS READ_COUNT, T.\"NUMBER_WRITE\" AS WRITE_COUNT, T.\"BUS_RESETS\" AS BUS_RESET, T.\"COMMANDS\" AS COMMANDS_COUNT, T.\"COMMANDS_ABORTED\" AS COMMANDS_ABORTED_COUNT, T.\"DEVICE_READ_LATENCY\" AS DEVICE_READ_LATENCY, T.\"DEVICE_WRITE_LATENCY\" AS DEVICE_WRITE_LATENCY, T.\"DEVICE_TOTAL_LATENCY\" AS DEVICE_TOTAL_LATENCY, T.\"DEVICE_LATENCY\" AS DEVICE_LATENCY, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_SERVER_DISK_AGG="SELECT T.\"SERVER_HOSTNAME\" AS HOST_NAME, T.\"DISK_NAME\" AS DISK_NAME, T.\"LAT_BACKING_DATASTORE\" AS DATA_STORE_NAME, T.\"MIN_READ\" AS MIN_READ_KBPS, T.\"MAX_READ\" AS MAX_READ_KBPS, T.\"SUM_READ\" AS	SUM_READ_KBPS, T.\"AVG_READ\" AS	AVG_READ_KBPS, T.\"MIN_WRITE\" AS MIN_WRITE_KBPS, T.\"MAX_WRITE\" AS MAX_WRITE_KBPS, T.\"SUM_WRITE\" AS SUM_WRITE_KBPS, T.\"AVG_WRITE\" AS AVG_WRITE_KBPS, T.\"SUM_NUMBER_READ\" AS SUM_READ_COUNT, T.\"AVG_NUMBER_READ\" AS AVG_READ_COUNT, T.\"MIN_NUMBER_WRITE\" AS MIN_WRITE_COUNT, T.\"MAX_NUMBER_WRITE\" AS MAX_WRITE_COUNT, T.\"SUM_NUMBER_WRITE\" AS SUM_WRITE_COUNT, T.\"AVG_NUMBER_WRITE\" AS AVG_WRITE_COUNT, T.\"MIN_BUS_RESETS\" AS MIN_BUS_RESET, T.\"MAX_BUS_RESETS\" AS MAX_BUS_RESET, T.\"SUM_BUS_RESETS\" AS SUM_BUS_RESET, T.\"AVG_BUS_RESETS\" AS AVG_BUS_RESET, T.\"MIN_COMMANDS\" AS MIN_COMMANDS_COUNT, T.\"MAX_COMMANDS\" AS	MAX_COMMANDS_COUNT, T.\"SUM_COMMANDS\" AS SUM_COMMANDS_COUNT, T.\"AVG_COMMANDS\" AS AVG_COMMANDS_COUNT, T.\"MIN_COMMANDS_ABORTED\" AS MIN_COMMANDS_ABORTED_COUNT, T.\"MAX_COMMANDS_ABORTED\" AS MAX_COMMANDS_ABORTED_COUNT, T.\"SUM_COMMANDS_ABORTED\" AS SUM_COMMANDS_ABORTED_COUNT, T.\"AVG_COMMANDS_ABORTED\" AS AVG_COMMANDS_ABORTED_COUNT, T.\"MIN_DEVICE_LATENCY\" AS MIN_DEVICE_READ_LATENCY, T.\"MAX_DEVICE_READ_LATENCY\" AS MAX_DEVICE_READ_LATENCY, T.\"SUM_DEVICE_READ_LATENCY\" AS SUM_DEVICE_READ_LATENCY, T.\"AVG_DEVICE_READ_LATENCY\" AS AVG_DEVICE_READ_LATENCY, T.\"MIN_DEVICE_WRITE_LATENCY\" AS MIN_DEVICE_WRITE_LATENCY, T.\"MAX_DEVICE_WRITE_LATENCY\" AS MAX_DEVICE_WRITE_LATENCY, T.\"SUM_DEVICE_WRITE_LATENCY\" AS SUM_DEVICE_WRITE_LATENCY, T.\"AVG_DEVICE_WRITE_LATENCY\" AS AVG_DEVICE_WRITE_LATENCY, T.\"MIN_DEVICE_TOTAL_LATENCY\" AS MIN_DEVICE_TOTAL_LATENCY, T.\"MAX_DEVICE_TOTAL_LATENCY\" AS MAX_DEVICE_TOTAL_LATENCY, T.\"SUM_DEVICE_TOTAL_LATENCY\" AS SUM_DEVICE_TOTAL_LATENCY, T.\"AVG_DEVICE_TOTAL_LATENCY\" AS AVG_DEVICE_TOTAL_LATENCY, T.\"MIN_DEVICE_LATENCY\" AS MIN_DEVICE_LATENCY, T.\"MAX_DEVICE_LATENCY\" AS MAX_DEVICE_LATENCY, T.\"SUM_DEVICE_LATENCY\" AS SUM_DEVICE_LATENCY, T.\"AVG_DEVICE_LATENCY\" AS AVG_DEVICE_LATENCY, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_SERVER_NET="SELECT T.\"SERVER_HOSTNAME\" AS HOST_NAME, T.\"NIC_NAME\" AS NIC_NAME, T.\"USAGE\" AS USAGE, T.\"TRANSMITTED\"	AS TRANSMITTED_KBPS, T.\"RECEIVED\" AS RECEIVED_KBPS, T.\"PKTS_TRANSMITTED\" AS PKTS_TRANSMITTED, T.\"PKTS_RECEIVED\" AS PKTS_RECEIVED, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_SERVER_NET_AGG="SELECT T.\"SERVER_HOSTNAME\" AS HOST_NAME, T.\"NIC_NAME\" AS NIC_NAME, T.\"MIN_USAGE\" AS MIN_USAGE, T.\"MAX_USAGE\" AS MAX_USAGE, T.\"SUM_USAGE\" AS SUM_USAGE, T.\"AVG_USAGE\" AS AVG_USAGE, T.\"MIN_TRANSMITTED\" AS MIN_TRANSMITTED_KBPS, T.\"MAX_TRANSMITTED\" AS MAX_TRANSMITTED_KBPS, T.\"SUM_TRANSMITTED\" AS SUM_TRANSMITTED_KBPS, T.\"AVG_TRANSMITTED\" AS AVG_TRANSMITTED_KBPS, T.\"MIN_RECEIVED\" AS MIN_RECEIVED_KBPS, T.\"MAX_RECEIVED\" AS MAX_RECEIVED_KBPS, T.\"SUM_RECEIVED\" AS SUM_RECEIVED_KBPS, T.\"AVG_RECEIVED\" AS AVG_RECEIVED_KBPS, T.\"MIN_PKTS_RECEIVED\" AS MIN_PKTS_TRANSMITTED, T.\"MAX_PKTS_RECEIVED\" AS MAX_PKTS_TRANSMITTED, T.\"SUM_PKTS_RECEIVED\" AS SUM_PKTS_TRANSMITTED, T.\"AVG_PKTS_RECEIVED\" AS AVG_PKTS_TRANSMITTED, T.\"MIN_PKTS_TRANSMITTED\" AS MIN_PKTS_RECEIVED, T.\"MAX_PKTS_TRANSMITTED\" AS MAX_PKTS_RECEIVED, T.\"SUM_PKTS_TRANSMITTED\" AS SUM_PKTS_RECEIVED, T.\"AVG_PKTS_TRANSMITTED\" AS AVG_PKTS_RECEIVED, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_VM="SELECT T.\"VM_NAME\" AS HOST_NAME, T.\"VM_SERVER_NAME\" AS VM_SERVER_NAME, T.\"VM_NAME\" AS VM_NAME, T.\"DATACENTER\" AS DATA_CENTER_NAME, T.\"CLUSTER\" AS VM_POOL_NAME, T.\"USED_CPU_MHZ\" AS CPU_UTILIZATION, T.\"USED_CPU_MHZ\" AS USED_CPU_MHZ, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_VM_AGG="SELECT T.\"VM_NAME\" AS HOST_NAME, T.\"VM_SERVER_NAME\" AS VM_SERVER_NAME, T.\"VM_NAME\" AS VM_NAME, T.\"DATACENTER\" AS DATA_CENTER_NAME, T.\"LAT_CLUSTER\" AS VM_POOL_NAME, T.\"MIN_USED_CPU_MHZ\" AS MIN_USED_CPU_MHZ, T.\"MAX_USED_CPU_MHZ\" AS MAX_USED_CPU_MHZ, T.\"SUM_USED_CPU_MHZ\" AS SUM_USED_CPU_MHZ, T.\"AVG_USED_CPU_MHZ\" AS AVG_USED_CPU_MHZ, T.\"MIN_USED_CPU_MHZ\" AS MIN_CPU_UTILIZATION, T.\"MAX_USED_CPU_MHZ\" AS MAX_CPU_UTILIZATION, T.\"SUM_USED_CPU_MHZ\" AS SUM_CPU_UTILIZATION, T.\"AVG_USED_CPU_MHZ\" AS AVG_CPU_UTILIZATION, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_VM_MEM="SELECT T.\"VM_NAME\" AS HOST_NAME, T.\"VM_NAME\" AS VM_NAME, T.\"VM_SERVER_NAME\" AS VM_SERVER_NAME, T.\"HOST_USAGE\" AS HOST_USAGE, T.\"GUEST_USAGE\" AS GUEST_USAGE,T.\"HOST_UTIL\" AS HOST_UTILIZATION, T.\"HOST_USAGE\" AS GUEST_UTILIZATION, T.\"HOST_FREE\" AS HOST_FREE, T.\"GUEST_FREE\" AS GUEST_FREE, T.\"BALLOON_USAGE\" AS BALLOON_USAGE, T.\"SWAP_TO_FILE\" AS SWAP_TO_FILE, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_VM_MEM_AGG="SELECT T.\"VM_NAME\" AS HOST_NAME, T.\"VM_NAME\" AS VM_NAME, T.\"VM_SERVER_NAME\" AS VM_SERVER_NAME, T.\"MIN_HOST_USAGE\" AS MIN_HOST_USAGE, T.\"MAX_HOST_USAGE\" AS MAX_HOST_USAGE, T.\"SUM_HOST_USAGE\" AS SUM_HOST_USAGE, T.\"AVG_HOST_USAGE\" AS AVG_HOST_USAGE, T.\"MIN_GUEST_USAGE\" AS MIN_GUEST_USAGE, T.\"MAX_GUEST_USAGE\" AS MAX_GUEST_USAGE, T.\"SUM_GUEST_USAGE\" AS SUM_GUEST_USAGE, T.\"AVG_GUEST_USAGE\" AS AVG_GUEST_USAGE, T.\"MIN_HOST_UTIL\" AS MIN_HOST_UTILIZATION, T.\"MAX_HOST_UTIL\" AS MAX_HOST_UTILIZATION, T.\"SUM_HOST_UTIL\" AS SUM_HOST_UTILIZATION, T.\"AVG_HOST_UTIL\" AS AVG_HOST_UTILIZATION, T.\"MIN_HOST_USAGE\" AS MIN_GUEST_UTILIZATION, T.\"MAX_HOST_USAGE\" AS MAX_GUEST_UTILIZATION, T.\"SUM_HOST_USAGE\" AS SUM_GUEST_UTILIZATION, T.\"AVG_HOST_USAGE\" AS AVG_GUEST_UTILIZATION, T.\"MIN_HOST_FREE\" AS MIN_HOST_FREE, T.\"MAX_HOST_FREE\" AS MAX_HOST_FREE, T.\"SUM_HOST_FREE\" AS SUM_HOST_FREE, T.\"AVG_HOST_FREE\" AS AVG_HOST_FREE, T.\"MIN_GUEST_FREE\" AS MIN_GUEST_FREE, T.\"MAX_GUEST_FREE\" AS MAX_GUEST_FREE, T.\"SUM_GUEST_FREE\" AS SUM_GUEST_FREE, T.\"AVG_GUEST_FREE\" AS AVG_GUEST_FREE, T.\"MIN_BALLOON_USAGE\" AS MIN_BALLOON_USAGE, T.\"MAX_BALLOON_USAGE\" AS MAX_BALLOON_USAGE, T.\"SUM_BALLOON_USAGE\" AS SUM_BALLOON_USAGE, T.\"AVG_BALLOON_USAGE\" AS AVG_BALLOON_USAGE, T.\"MIN_SWAP_TO_FILE\" AS MIN_SWAP_TO_FILE, T.\"MAX_SWAP_TO_FILE\" AS MAX_SWAP_TO_FILE, T.\"SUM_SWAP_TO_FILE\" AS SUM_SWAP_TO_FILE, T.\"AVG_SWAP_TO_FILE\" AS AVG_SWAP_TO_FILE, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_VM_NET="SELECT T.\"VM_NAME\" AS HOST_NAME, T.\"VM_NAME\" AS VM_NAME, T.\"VM_SERVER_NAME\" AS VM_SERVER_NAME, T.\"TRANSMITTED\" AS TRANSMITTED_KBPS, T.\"RECEIVED\" AS RECEIVED_KBPS, T.\"PKTS_TRANS\" AS PKTS_TRANSMITTED, T.\"PKTS_RECD\" AS PKTS_RECEIVED, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_VM_NET_AGG="SELECT T.\"VM_NAME\" AS HOST_NAME, T.\"LAT_DESCRIPTION\" AS NIC_NAME, T.\"VM_NAME\" AS VM_NAME, T.\"VM_SERVER_NAME\" AS VM_SERVER_NAME, T.\"MIN_TRANSMITTED\" AS MIN_TRANSMITTED_KBPS, T.\"MAX_TRANSMITTED\" AS MAX_TRANSMITTED_KBPS, T.\"SUM_TRANSMITTED\" AS SUM_TRANSMITTED_KBPS, T.\"AVG_TRANSMITTED\" AS AVG_TRANSMITTED_KBPS, T.\"MIN_RECEIVED\" AS	MIN_RECEIVED_KBPS, T.\"MAX_RECEIVED\" AS MAX_RECEIVED_KBPS, T.\"SUM_RECEIVED\" AS SUM_RECEIVED_KBPS, T.\"AVG_RECEIVED\" AS AVG_RECEIVED_KBPS, T.\"MIN_PKTS_TRANS\" AS MIN_PKTS_TRANSMITTED, T.\"MAX_PKTS_TRANS\" AS MAX_PKTS_TRANSMITTED, T.\"SUM_PKTS_TRANS\" AS SUM_PKTS_TRANSMITTED, T.\"AVG_PKTS_TRANS\" AS AVG_PKTS_TRANSMITTED, T.\"MIN_PKTS_RECD\" AS MIN_PKTS_RECEIVED, T.\"MAX_PKTS_RECD\" AS MAX_PKTS_RECEIVED, T.\"SUM_PKTS_RECD\" AS SUM_PKTS_RECEIVED, T.\"AVG_PKTS_RECD\" AS AVG_PKTS_RECEIVED, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_VM_DS="SELECT T.\"NAME\" AS DATA_STORE_NAME, T.\"VIRTUAL_MACHINE\" AS HOST_NAME, T.\"VIRTUAL_MACHINE\" AS VM_NAME, T.\"DATACENTER\" AS DATA_CENTER_NAME, T.\"TOTAL_READ_KBPS\" AS TOTAL_READ, T.\"TOTAL_WRITE_KBPS\" AS TOTAL_WRITE, T.\"TOTAL_IO_KBPS\" AS TOTAL_IO, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_BODY_VM_DS_AGG="SELECT T.\"NAME\" AS DATA_STORE_NAME, T.\"LAT_VIRTUAL_MACHINE\" AS HOST_NAME, T.\"LAT_VIRTUAL_MACHINE\" AS VM_NAME, T.\"DATACENTER\" AS DATA_CENTER_NAME, T.\"MIN_TOTAL_READ_KBPS\" AS MIN_TOTAL_READ, T.\"MAX_TOTAL_READ_KBPS\" AS MAX_TOTAL_READ, T.\"SUM_TOTAL_READ_KBPS\" AS SUM_TOTAL_READ, T.\"AVG_TOTAL_READ_KBPS\" AS AVG_TOTAL_READ, T.\"MIN_TOTAL_WRITE_KBPS\" AS MIN_TOTAL_WRITE, T.\"MAX_TOTAL_WRITE_KBPS\" AS MAX_TOTAL_WRITE, T.\"SUM_TOTAL_WRITE_KBPS\" AS SUM_TOTAL_WRITE, T.\"AVG_TOTAL_WRITE_KBPS\" AS AVG_TOTAL_WRITE, T.\"MIN_TOTAL_IO_KBPS\" AS MIN_TOTAL_IO, T.\"MAX_TOTAL_IO_KBPS\" AS MAX_TOTAL_IO, T.\"SUM_TOTAL_IO_KBPS\" AS SUM_TOTAL_IO, T.\"AVG_TOTAL_IO_KBPS\" AS AVG_TOTAL_IO, T.\"TIMESTAMP\" AS TIMESTAMP, T.\"WRITETIME\" AS WRITETIME"

VIEW_PERC_CPU_H_V="MES_PERCENTILE_CPU_H_V (VM_KEY, VM_NAME, WRITETIME, AVG_CPU_UTILIZATION) AS ( SELECT VM.VIRTUAL_MACHINE_PK, MES.VM_NAME, MES.WRITETIME, MES.AVG_CPU_UTILIZATION FROM MES_VM_CPU_H AS MES , ANL_WORKING_SET_V AS WORKINGSET , ANL_TIME_DIM AS TIME , CFG_USER_CONFIGURATION AS USER_CONFIG , CFG_VIRTUAL_MACHINE AS VM WHERE MES.VM_NAME = VM.VM_NAME AND VM.PHYSICAL_SERVER_PK = WORKINGSET.PHYSICAL_SERVER_PK AND MES.WRITETIME = TIME.CANDLETIMESTAMP AND TIME.TIME_RANGE_START BETWEEN USER_CONFIG.START_TIME AND USER_CONFIG.END_TIME AND MES.AVG_CPU_UTILIZATION >=0)"

VIEW_PERC_DISK_H_V="MES_PERCENTILE_DISK_H_V (VM_KEY, VM_NAME, WRITETIME, AVG_TOTAL_IO) AS ( SELECT VM.VIRTUAL_MACHINE_PK, MES.VM_NAME, MES.WRITETIME, MES.AVG_TOTAL_IO FROM MES_VM_DATA_STORE_H AS MES , ANL_WORKING_SET_V AS WORKINGSET , ANL_TIME_DIM AS TIME , CFG_USER_CONFIGURATION AS USER_CONFIG , CFG_VIRTUAL_MACHINE AS VM WHERE MES.VM_NAME = VM.VM_NAME AND VM.PHYSICAL_SERVER_PK = WORKINGSET.PHYSICAL_SERVER_PK AND MES.WRITETIME = TIME.CANDLETIMESTAMP AND TIME.TIME_RANGE_START BETWEEN USER_CONFIG.START_TIME AND USER_CONFIG.END_TIME AND MES.AVG_TOTAL_IO >=0)"

VIEW_PERC_MEM_H_V="MES_PERCENTILE_MEM_H_V (VM_KEY, VM_NAME, WRITETIME, AVG_GUEST_UTILIZATION) AS ( SELECT VM.VIRTUAL_MACHINE_PK, MES.VM_NAME, MES.WRITETIME, MES.AVG_GUEST_UTILIZATION FROM MES_VM_MEM_H AS MES , ANL_WORKING_SET_V AS WORKINGSET , ANL_TIME_DIM AS TIME , CFG_USER_CONFIGURATION AS USER_CONFIG , CFG_VIRTUAL_MACHINE AS VM WHERE MES.VM_NAME = VM.VM_NAME AND VM.PHYSICAL_SERVER_PK = WORKINGSET.PHYSICAL_SERVER_PK AND MES.WRITETIME = TIME.CANDLETIMESTAMP AND TIME.TIME_RANGE_START BETWEEN USER_CONFIG.START_TIME AND USER_CONFIG.END_TIME AND MES.AVG_GUEST_UTILIZATION >=0)"

VIEW_PERC_NW_H_V="MES_PERCENTILE_NW_H_V (VM_KEY, VM_NAME, WRITETIME, AVG_TOTAL_KBPS) AS ( SELECT VM.VIRTUAL_MACHINE_PK, MES.VM_NAME, MES.WRITETIME, (MES.AVG_RECEIVED_KBPS + MES.AVG_TRANSMITTED_KBPS) FROM MES_VM_NETWORK_H AS MES , ANL_WORKING_SET_V AS WORKINGSET , ANL_TIME_DIM AS TIME , CFG_USER_CONFIGURATION AS USER_CONFIG , CFG_VIRTUAL_MACHINE AS VM WHERE MES.VM_NAME = VM.VM_NAME AND VM.PHYSICAL_SERVER_PK = WORKINGSET.PHYSICAL_SERVER_PK AND MES.WRITETIME = TIME.CANDLETIMESTAMP AND TIME.TIME_RANGE_START BETWEEN USER_CONFIG.START_TIME AND USER_CONFIG.END_TIME AND MES.AVG_RECEIVED_KBPS >=0 AND MES.AVG_TRANSMITTED_KBPS >=0)"
################################################################################

################################################################################
# List of SQL statements forming bodies of the Datamart tables.
################################################################################
TABLE_BODY_SERVER_CPU="( 		PS_CPU_PK BIGINT NOT NULL, 		HOST_NAME VARCHAR(256), 		CPU_NUMBER INTEGER, 		CPU_UTILIZATION BIGINT, 		PHYSICAL_SERVER_PK BIGINT, 		TIMESTAMP TIMESTAMP 	) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_CPU_AGG="( 		PS_CPU_PK BIGINT NOT NULL, 		HOST_NAME VARCHAR(256), 		CPU_NUMBER INTEGER, 		MIN_CPU_UTILIZATION BIGINT, 		MAX_CPU_UTILIZATION BIGINT, 		SUM_CPU_UTILIZATION BIGINT, 		AVG_CPU_UTILIZATION BIGINT, 		PHYSICAL_SERVER_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_MEM="( 		PS_MEM_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		HOST_NAME VARCHAR(256), 		PHYSICAL_MEMORY BIGINT, 		MEMORY_USAGE BIGINT, 		MEMORY_UTILIZATION BIGINT, 		ACTIVE_MEMORY BIGINT, 		GRANTED_MEMORY BIGINT, 		SWAP_USED BIGINT, 		FREE_MEM BIGINT, 		BALLOON_USED BIGINT, 		SWAP_IN_RATE BIGINT, 		SWAP_OUT_RATE BIGINT, 		SWAP_TOTAL_RATE BIGINT, 		PHYSICAL_SERVER_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_MEM_AGG="( 		PS_MEM_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		HOST_NAME VARCHAR(256), 		PHYSICAL_MEMORY BIGINT, 		MIN_MEMORY_USAGE BIGINT, 		MAX_MEMORY_USAGE BIGINT, 		SUM_MEMORY_USAGE BIGINT, 		AVG_MEMORY_USAGE BIGINT, 		MIN_MEMORY_UTILIZATION BIGINT, 		MAX_MEMORY_UTILIZATION BIGINT, 		SUM_MEMORY_UTILIZATION BIGINT, 		AVG_MEMORY_UTILIZATION BIGINT, 		MIN_ACTIVE_MEMORY BIGINT, 		MAX_ACTIVE_MEMORY BIGINT, 		SUM_ACTIVE_MEMORY BIGINT, 		AVG_ACTIVE_MEMORY BIGINT, 		MIN_GRANTED_MEMORY BIGINT, 		MAX_GRANTED_MEMORY BIGINT, 		SUM_GRANTED_MEMORY BIGINT, 		AVG_GRANTED_MEMORY BIGINT, 		MIN_SWAP_USED BIGINT, 		MAX_SWAP_USED BIGINT, 		SUM_SWAP_USED BIGINT, 		AVG_SWAP_USED BIGINT, 		MIN_FREE_MEM BIGINT, 		MAX_FREE_MEM BIGINT, 		SUM_FREE_MEM BIGINT, 		AVG_FREE_MEM BIGINT, 		MIN_BALLOON_USED BIGINT, 		MAX_BALLOON_USED BIGINT, 		SUM_BALLOON_USED BIGINT, 		AVG_BALLOON_USED BIGINT, 		MIN_SWAP_IN_RATE BIGINT, 		MAX_SWAP_IN_RATE BIGINT, 		SUM_SWAP_IN_RATE BIGINT, 		AVG_SWAP_IN_RATE BIGINT, 		MIN_SWAP_OUT_RATE BIGINT, 		MAX_SWAP_OUT_RATE BIGINT, 		SUM_SWAP_OUT_RATE BIGINT, 		AVG_SWAP_OUT_RATE BIGINT, 		MIN_SWAP_TOTAL_RATE BIGINT, 		MAX_SWAP_TOTAL_RATE BIGINT, 		SUM_SWAP_TOTAL_RATE BIGINT, 		AVG_SWAP_TOTAL_RATE BIGINT, 		PHYSICAL_SERVER_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_DISK="( 		HOST_NAME VARCHAR(256), 		PS_DISK_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		DISK_NAME VARCHAR(256), 		DATA_STORE_NAME VARCHAR(256), 		READ_KBPS BIGINT, 		WRITE_KBPS BIGINT, 		READ_COUNT BIGINT, 		WRITE_COUNT BIGINT, 		BUS_RESET BIGINT, 		COMMANDS_COUNT BIGINT, 		COMMANDS_ABORTED_COUNT BIGINT, 		DEVICE_READ_LATENCY BIGINT, 		DEVICE_WRITE_LATENCY BIGINT, 		DEVICE_TOTAL_LATENCY BIGINT, 		DEVICE_LATENCY BIGINT, 		PHYSICAL_SERVER_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_DISK_AGG="( 		HOST_NAME VARCHAR(256), 		PS_DISK_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		DISK_NAME VARCHAR(256), 		DATA_STORE_NAME VARCHAR(256), 		MIN_READ_KBPS BIGINT, 		MAX_READ_KBPS BIGINT, 		SUM_READ_KBPS BIGINT, 		AVG_READ_KBPS BIGINT, 		MIN_WRITE_KBPS BIGINT, 		MAX_WRITE_KBPS BIGINT, 		SUM_WRITE_KBPS BIGINT, 		AVG_WRITE_KBPS BIGINT, 		MIN_READ_COUNT BIGINT, 		MAX_READ_COUNT BIGINT, 		SUM_READ_COUNT BIGINT, 		AVG_READ_COUNT BIGINT, 		MIN_WRITE_COUNT BIGINT, 		MAX_WRITE_COUNT BIGINT, 		SUM_WRITE_COUNT BIGINT, 		AVG_WRITE_COUNT BIGINT, 		MIN_BUS_RESET BIGINT, 		MAX_BUS_RESET BIGINT, 		SUM_BUS_RESET BIGINT, 		AVG_BUS_RESET BIGINT, 		MIN_COMMANDS_COUNT BIGINT, 		MAX_COMMANDS_COUNT BIGINT, 		SUM_COMMANDS_COUNT BIGINT, 		AVG_COMMANDS_COUNT BIGINT, 		MIN_COMMANDS_ABORTED_COUNT BIGINT, 		MAX_COMMANDS_ABORTED_COUNT BIGINT, 		SUM_COMMANDS_ABORTED_COUNT BIGINT, 		AVG_COMMANDS_ABORTED_COUNT BIGINT, 		MIN_DEVICE_READ_LATENCY BIGINT, 		MAX_DEVICE_READ_LATENCY BIGINT, 		SUM_DEVICE_READ_LATENCY BIGINT, 		AVG_DEVICE_READ_LATENCY BIGINT, 		MIN_DEVICE_WRITE_LATENCY BIGINT, 		MAX_DEVICE_WRITE_LATENCY BIGINT, 		SUM_DEVICE_WRITE_LATENCY BIGINT, 		AVG_DEVICE_WRITE_LATENCY BIGINT, 		MIN_DEVICE_TOTAL_LATENCY BIGINT, 		MAX_DEVICE_TOTAL_LATENCY BIGINT, 		SUM_DEVICE_TOTAL_LATENCY BIGINT, 		AVG_DEVICE_TOTAL_LATENCY BIGINT, 		MIN_DEVICE_LATENCY BIGINT, 		MAX_DEVICE_LATENCY BIGINT, 		SUM_DEVICE_LATENCY BIGINT, 		AVG_DEVICE_LATENCY BIGINT, 		PHYSICAL_SERVER_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_NET="( 		PS_NETWORK_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		HOST_NAME VARCHAR(256), 		NIC_NAME VARCHAR(256), 		USAGE BIGINT, 		TRANSMITTED_KBPS BIGINT, 		RECEIVED_KBPS BIGINT, 		PKTS_TRANSMITTED BIGINT, 		PKTS_RECEIVED BIGINT, 		PHYSICAL_SERVER_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_NET_AGG="( 		PS_NETWORK_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		HOST_NAME VARCHAR(256), 		NIC_NAME VARCHAR(256), 		MIN_USAGE BIGINT, 		MAX_USAGE BIGINT, 		SUM_USAGE BIGINT, 		AVG_USAGE BIGINT, 		MIN_TRANSMITTED_KBPS BIGINT, 		MAX_TRANSMITTED_KBPS BIGINT, 		SUM_TRANSMITTED_KBPS BIGINT, 		AVG_TRANSMITTED_KBPS BIGINT, 		MIN_RECEIVED_KBPS BIGINT, 		MAX_RECEIVED_KBPS BIGINT, 		SUM_RECEIVED_KBPS BIGINT, 		AVG_RECEIVED_KBPS BIGINT, 		MIN_PKTS_TRANSMITTED BIGINT, 		MAX_PKTS_TRANSMITTED BIGINT, 		SUM_PKTS_TRANSMITTED BIGINT, 		AVG_PKTS_TRANSMITTED BIGINT, 		MIN_PKTS_RECEIVED BIGINT, 		MAX_PKTS_RECEIVED BIGINT, 		SUM_PKTS_RECEIVED BIGINT, 		AVG_PKTS_RECEIVED BIGINT, 		PHYSICAL_SERVER_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM="( 		VM_CPU_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		VM_CPU_NUMBER INTEGER, 		WAIT_TIME BIGINT, 		USED_TIME BIGINT, 		READY_TIME BIGINT, 		SYS_TIME BIGINT, 		CPU_UTILIZATION BIGINT, 		PERCENT_READY INTEGER, 		USER_TIME BIGINT, 		VIRTUAL_MACHINE_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_AGG="( 		VM_CPU_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		VM_CPU_NUMBER INTEGER, 		MIN_WAIT_TIME BIGINT, 		MAX_WAIT_TIME BIGINT, 		SUM_WAIT_TIME BIGINT, 		AVG_WAIT_TIME BIGINT, 		MIN_USED_TIME BIGINT, 		MAX_USED_TIME BIGINT, 		SUM_USED_TIME BIGINT, 		AVG_USED_TIME BIGINT, 		MIN_READY_TIME BIGINT, 		MAX_READY_TIME BIGINT, 		SUM_READY_TIME BIGINT, 		AVG_READY_TIME BIGINT, 		MIN_SYS_TIME BIGINT, 		MAX_SYS_TIME BIGINT, 		SUM_SYS_TIME BIGINT, 		AVG_SYS_TIME BIGINT, 		MIN_CPU_UTILIZATION BIGINT, 		MAX_CPU_UTILIZATION BIGINT, 		SUM_CPU_UTILIZATION BIGINT, 		AVG_CPU_UTILIZATION BIGINT, 		MIN_PERCENT_READY INTEGER, 		MAX_PERCENT_READY INTEGER, 		SUM_PERCENT_READY INTEGER, 		AVG_PERCENT_READY INTEGER, 		IN_USER_TIME BIGINT, 		MAX_USER_TIME BIGINT, 		SUM_USER_TIME BIGINT, 		AVG_USER_TIME BIGINT, 		VIRTUAL_MACHINE_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_MEM="( 		VM_MEM_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		HOST_USAGE BIGINT, 		GUEST_USAGE BIGINT, 		HOST_UTILIZATION BIGINT, 		GUEST_UTILIZATION BIGINT, 		HOST_FREE BIGINT, 		GUEST_FREE BIGINT, 		BALLOON_USAGE BIGINT, 		SWAP_TO_FILE BIGINT, 		VIRTUAL_MACHINE_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_MEM_AGG="( 		VM_MEM_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		MIN_HOST_USAGE BIGINT, 		MAX_HOST_USAGE BIGINT, 		SUM_HOST_USAGE BIGINT, 		AVG_HOST_USAGE BIGINT, 		MIN_GUEST_USAGE BIGINT, 		MAX_GUEST_USAGE BIGINT, 		SUM_GUEST_USAGE BIGINT, 		AVG_GUEST_USAGE BIGINT, 		MIN_HOST_UTILIZATION BIGINT, 		MAX_HOST_UTILIZATION BIGINT, 		SUM_HOST_UTILIZATION BIGINT, 		AVG_HOST_UTILIZATION BIGINT, 		MIN_GUEST_UTILIZATION BIGINT, 		MAX_GUEST_UTILIZATION BIGINT, 		SUM_GUEST_UTILIZATION BIGINT, 		AVG_GUEST_UTILIZATION BIGINT, 		MIN_HOST_FREE BIGINT, 		MAX_HOST_FREE BIGINT, 		SUM_HOST_FREE BIGINT, 		AVG_HOST_FREE BIGINT, 		MIN_GUEST_FREE BIGINT, 		MAX_GUEST_FREE BIGINT, 		SUM_GUEST_FREE BIGINT, 		AVG_GUEST_FREE BIGINT, 		MIN_BALLOON_USAGE BIGINT, 		MAX_BALLOON_USAGE BIGINT, 		SUM_BALLOON_USAGE BIGINT, 		AVG_BALLOON_USAGE BIGINT, 		MIN_SWAP_TO_FILE BIGINT, 		MAX_SWAP_TO_FILE BIGINT, 		SUM_SWAP_TO_FILE BIGINT, 		AVG_SWAP_TO_FILE BIGINT, 		VIRTUAL_MACHINE_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_NET="( 		VM_NETWORK_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		TRANSMITTED_KBPS BIGINT, 		RECEIVED_KBPS BIGINT, 		PKTS_TRANSMITTED BIGINT, 		PKTS_RECEIVED BIGINT, 		VIRTUAL_MACHINE_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_NET_AGG="( 		VM_NETWORK_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		NIC_NAME VARCHAR(256), 		MIN_USAGE BIGINT, 		MAX_USAGE BIGINT, 		SUM_USAGE BIGINT, 		AVG_USAGE BIGINT, 		MIN_TRANSMITTED_KBPS BIGINT, 		MAX_TRANSMITTED_KBPS BIGINT, 		SUM_TRANSMITTED_KBPS BIGINT, 		AVG_TRANSMITTED_KBPS BIGINT, 		MIN_RECEIVED_KBPS BIGINT, 		MAX_RECEIVED_KBPS BIGINT, 		SUM_RECEIVED_KBPS BIGINT, 		AVG_RECEIVED_KBPS BIGINT, 		MIN_PKTS_TRANSMITTED BIGINT, 		MAX_PKTS_TRANSMITTED BIGINT, 		SUM_PKTS_TRANSMITTED BIGINT, 		AVG_PKTS_TRANSMITTED BIGINT, 		MIN_PKTS_RECEIVED BIGINT, 		MAX_PKTS_RECEIVED BIGINT, 		SUM_PKTS_RECEIVED BIGINT, 		AVG_PKTS_RECEIVED BIGINT, 		PHYSICAL_SERVER_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_DS="( 		VM_DATA_STORE_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		DATA_STORE_NAME VARCHAR(256), VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		TOTAL_READ BIGINT, 		TOTAL_WRITE BIGINT, 		TOTAL_IO BIGINT, 		VIRTUAL_MACHINE_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_DS_AGG="( 		VM_DATA_STORE_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		DATA_STORE_NAME VARCHAR(256), VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		MIN_TOTAL_READ BIGINT, 		MAX_TOTAL_READ BIGINT, 		SUM_TOTAL_READ BIGINT, 		AVG_TOTAL_READ BIGINT, 		MIN_TOTAL_WRITE BIGINT, 		MAX_TOTAL_WRITE BIGINT, 		SUM_TOTAL_WRITE BIGINT, 		AVG_TOTAL_WRITE BIGINT, 		MIN_TOTAL_IO BIGINT, 		MAX_TOTAL_IO BIGINT, 		SUM_TOTAL_IO BIGINT, 		AVG_TOTAL_IO BIGINT, 		VIRTUAL_MACHINE_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"


################################################################################
# Runs a DB2 command contained in $TMP_F_NAME.
################################################################################
run_command()
{
    LAST_ERROR=0
    echo "Running command: " "`cat $TMP_F_NAME`" >> $LOG_F_NAME

    $DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME

	LAST_ERROR=$?
    if [ $LAST_ERROR != 0 ]
    then
        echo $0 $SPACE "Failed." 2>&1 >> $LOG_F_NAME
        # Failed,  "Please check $LOG_F_NAME for details."
        $JAVA $CLASSNAME "ANA01001E"
	exit 9
    fi
}

################################################################################
# Creates nickname for a given argument.
################################################################################
create_nickname()
{
    LAST_ERROR=0

    L_NICK_NAME="$FED_TABLE_NAME_PREFIX"_"$1"
    L_TDW_TABLE="$TDW_TABLE_PREFIX"_"$1"

	if [ $DB2_VERSION = "v9.5" ]
	then
		drop_nickname_if_exists $L_NICK_NAME
		if [ $LAST_ERROR != 0 ]
		then
			return
		fi
	fi

    echo "Creating nick name: " $L_NICK_NAME >> $LOG_F_NAME
    DB2CMD="$DB2_CMD_CREATE_NICKNAME $SPACE $L_NICK_NAME FOR $L_TDW_TABLE"
    echo "Running:" $DB2CMD >> $LOG_F_NAME

    $DB2 "$DB2CMD" 2>&1 >> $LOG_F_NAME

	LAST_ERROR=$?
	if [ $LAST_ERROR != 0 ]
	then
		echo "Failed to create nick name: $L_NICK_NAME." >> $LOG_F_NAME
        echo "................................................................................" >> $LOG_F_NAME
        return
	fi
}

################################################################################
# Creates Datamart view for a given argument.
################################################################################
create_dm_view()
{
    LAST_ERROR=0

    CHANGE_FED_TABLE_SUFFIX=0
    case $1 in
        SERVER_CPU)
    
        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        L_VIEW_BODY=$VIEW_BODY_SERVER_CPU
        ;;

        SERVER_CPU_*)
    
        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        L_VIEW_BODY=$VIEW_BODY_SERVER_CPU_AGG
        ;;
    
        SERVER_MEMORY)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
        FED_TABLE_NAME_SUFFIX=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("MEMORY", "MEM");print}'`
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        L_VIEW_BODY=$VIEW_BODY_SERVER_MEM
        ;;

        SERVER_MEMORY_*)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
        FED_TABLE_NAME_SUFFIX=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("MEMORY", "MEM");print}'`
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        L_VIEW_BODY=$VIEW_BODY_SERVER_MEM_AGG
        ;;

        SERVER_DISK)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        L_VIEW_BODY=$VIEW_BODY_SERVER_DISK
        ;;

        SERVER_DISK_*)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        L_VIEW_BODY=$VIEW_BODY_SERVER_DISK_AGG
        ;;

        SERVER_NETWORK)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        L_VIEW_BODY=$VIEW_BODY_SERVER_NET
        ;;

        SERVER_NETWORK_*)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        L_VIEW_BODY=$VIEW_BODY_SERVER_NET_AGG
        ;;
    
        VIRTUAL_MACHINES)

        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("VIRTUAL_MACHINES", "VM_CPU");print}'`
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        CHANGE_FED_TABLE_SUFFIX=1
        L_VIEW_BODY=$VIEW_BODY_VM
        ;;

        VIRTUAL_MACHINES_*)

        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("VIRTUAL_MACHINES", "VM_CPU");print}'`
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        CHANGE_FED_TABLE_SUFFIX=1
        L_VIEW_BODY=$VIEW_BODY_VM_AGG
        ;;

        VM_MEMORY)

        FED_TABLE_NAME_SUFFIX=$1
	L_VIEW_NAME=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("MEMORY", "MEM");print}'`
        L_VIEW_BODY=$VIEW_BODY_VM_MEM
        ;;

        VM_MEMORY_*)

        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("MEMORY", "MEM");print}'`
	L_VIEW_NAME=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("MEMORY", "MEM");print}'`
        CHANGE_FED_TABLE_SUFFIX=1
        L_VIEW_BODY=$VIEW_BODY_VM_MEM_AGG
        ;;

        VM_NETWORK)

        FED_TABLE_NAME_SUFFIX=$1
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        L_VIEW_BODY=$VIEW_BODY_VM_NET
        ;;

        VM_NETWORK_*)

        FED_TABLE_NAME_SUFFIX=$1
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        L_VIEW_BODY=$VIEW_BODY_VM_NET_AGG
        ;;

        VM_DATASTORE_UTIL)

        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("DATASTORE_UTIL", "DATA_STORE");print}'`
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        CHANGE_FED_TABLE_SUFFIX=1
        L_VIEW_BODY=$VIEW_BODY_VM_DS
        ;;

        VM_DATASTORE_UTIL_*)

        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("DATASTORE_UTIL", "DATA_STORE");print}'`
	L_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        CHANGE_FED_TABLE_SUFFIX=1
        L_VIEW_BODY=$VIEW_BODY_VM_DS_AGG
        ;;

        *)
		$JAVA $CLASSNAME "ANA01002E"
		LAST_ERROR=9
            return
    esac

    # One odd case for VM_DATASTORE_UTIL
    if [ $CHANGE_FED_TABLE_SUFFIX == "0" ]
    then
        FINAL_FED_TABLE_SUFFIX=$FED_TABLE_NAME_SUFFIX
    else
        FINAL_FED_TABLE_SUFFIX=$1
    fi

	drop_table_if_exists "MES"_"$L_VIEW_NAME"
	if [ $LAST_ERROR != 0 ]
	then
		return
	fi

	if [ $DB2_VERSION = "v9.5" ]
	then
		drop_view_if_exists "$L_VIEW_NAME"
		if [ $LAST_ERROR != 0 ]
		then
			return
		fi
	fi

    DB2CMD="$DB2_CMD_CREATE_VIEW $SPACE "$DM_VIEW_NAME_PREFIX"_"$L_VIEW_NAME" $SPACE AS $L_VIEW_BODY $SPACE FROM "$FED_TABLE_NAME_PREFIX"_"$FINAL_FED_TABLE_SUFFIX" $SPACE T"

    echo $DB2CMD > $TMP_F_NAME
    echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME

    run_command
}

################################################################################
# Removes table corresponding to the argument.
################################################################################
drop_table_if_exists()
{
    LAST_ERROR=0

	# Drop the measurements table if it exists.
	ORIG_TABLE=`db2 -x "select tabname from syscat.tables where tabname = '$1' and type = 'T' and tabschema = '$DM_SCHEMA_NAME'"`

	LAST_ERROR=$?
	if [ $LAST_ERROR != 0 -a $LAST_ERROR != 1 ]
	then
		echo "Failed to query system catalog for table: $1." >> $LOG_F_NAME
		return
	fi

    LAST_ERROR=0
	if [ ! -z $ORIG_TABLE ]
	then
    	DB2CMD="$DB2_CMD_DROP_TABLE $SPACE "$DM_SCHEMA_NAME"."$1""
		echo "Dropping Datamart table: " "$DM_SCHEMA_NAME"."$1" >> $LOG_F_NAME
    	echo "Running:" $DB2CMD >> $LOG_F_NAME
    	$DB2 "$DB2CMD" 2>&1 >> $LOG_F_NAME	

		LAST_ERROR=$?
		if [ $LAST_ERROR != 0 ]
		then
			echo "Failed to drop Datamart table: $1." >> $LOG_F_NAME
			return
		fi
	fi
}

################################################################################
# Removes nickname corresponding to the argument.
################################################################################
delete_nickname()
{
    LAST_ERROR=0

    DEL_N_NICK_NAME="$FED_TABLE_NAME_PREFIX"_"$1"
	drop_nickname_if_exists $DEL_N_NICK_NAME
    if [ $LAST_ERROR != 0 ]
    then
        return
    fi
}

################################################################################
# Removes view corresponding to a given argument.
################################################################################
delete_dm_view()
{
    LAST_ERROR=0

    CHANGE_FED_TABLE_SUFFIX=0
	DEL_V_VIEW_NAME=$1	
    case $1 in
        SERVER_CPU)
    
        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_CPU
        ;;

        SERVER_CPU_*)
    
        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
		DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_CPU_AGG
        ;;
    
        SERVER_MEMORY)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
        FED_TABLE_NAME_SUFFIX=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("MEMORY", "MEM");print}'` 
	DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_MEM
        ;;

        SERVER_MEMORY_*)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
        FED_TABLE_NAME_SUFFIX=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("MEMORY", "MEM");print}'` 
	DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_MEM_AGG
        ;;

        SERVER_DISK)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_DISK
        ;;

        SERVER_DISK_*)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_DISK_AGG
        ;;

        SERVER_NETWORK)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_NET
        ;;

        SERVER_NETWORK_*)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
		DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_NET_AGG
        ;;
    
        VIRTUAL_MACHINES)

        FED_TABLE_NAME_SUFFIX=$1
	DEL_V_VIEW_NAME=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("VIRTUAL_MACHINES", "VM_CPU");print}'`
        TABLE_BODY=$TABLE_BODY_VM
        ;;

        VIRTUAL_MACHINES_*)

        FED_TABLE_NAME_SUFFIX=$1
	DEL_V_VIEW_NAME=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("VIRTUAL_MACHINES", "VM_CPU");print}'`
        TABLE_BODY=$TABLE_BODY_VM_AGG
        ;;

        VM_MEMORY)

        FED_TABLE_NAME_SUFFIX=$1
	DEL_V_VIEW_NAME=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("MEMORY", "MEM");print}'`
        TABLE_BODY=$TABLE_BODY_VM_MEM
        ;;

        VM_MEMORY_*)

        FED_TABLE_NAME_SUFFIX=$1
		DEL_V_VIEW_NAME=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("MEMORY", "MEM");print}'`
        TABLE_BODY=$TABLE_BODY_VM_MEM_AGG
        ;;

        VM_NETWORK)

        FED_TABLE_NAME_SUFFIX=$1
		DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_VM_NET
        ;;

        VM_NETWORK_*)

        FED_TABLE_NAME_SUFFIX=$1
		DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_VM_NET_AGG
        ;;

        VM_DATASTORE_UTIL)

        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("DATASTORE_UTIL", "DATA_STORE");print}'`
	DEL_V_VIEW_NAME=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("DATASTORE_UTIL", "DATA_STORE");print}'`
        CHANGE_FED_TABLE_SUFFIX=1
        TABLE_BODY=$TABLE_BODY_VM_DS
        ;;

        VM_DATASTORE_UTIL_*)

        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("DATASTORE_UTIL", "DATA_STORE");print}'`
	DEL_V_VIEW_NAME=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("DATASTORE_UTIL", "DATA_STORE");print}'`
        CHANGE_FED_TABLE_SUFFIX=1
        TABLE_BODY=$TABLE_BODY_VM_DS_AGG
        ;;

        *)
            # "Invalid argument:" $1
	    $JAVA $CLASSNAME "ANA01002E"
            return
    esac

    # One odd case for VM_DATASTORE_UTIL
    if [ $CHANGE_FED_TABLE_SUFFIX == "0" ]
    then
        FINAL_FED_TABLE_SUFFIX=$FED_TABLE_NAME_SUFFIX
    else
        FINAL_FED_TABLE_SUFFIX=$1
    fi

	drop_view_if_exists $DEL_V_VIEW_NAME
    if [ $LAST_ERROR != 0 ]
    then
        return
    fi

	if [ $VIEW_EXISTS -eq 1 ]
	then
		create_dm_table $DEL_V_VIEW_NAME "$TABLE_BODY"
        if [ $LAST_ERROR != 0 ]
        then
            return
        fi

		PERC_VIEW=
		# Update Percentile views.
        if [ $DB2_VERSION = "v9.5" ]
        then
            if [ $1 == "VIRTUAL_MACHINES_H" ]
            then
                PERC_VIEW="$DM_SCHEMA_NAME"."$VIEW_PERC_CPU_H_V"
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" >> $LOG_F_NAME
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" > $TMP_F_NAME
            	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
				$DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME
                LAST_ERROR=$?
            elif [ $1 == "VM_MEMORY_H" ]
            then
                PERC_VIEW="$DM_SCHEMA_NAME"."$VIEW_PERC_MEM_H_V"
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" >> $LOG_F_NAME
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" > $TMP_F_NAME
            	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
				$DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME
                LAST_ERROR=$?
            elif [ $1 == "VM_NETWORK_H" ]
            then
                PERC_VIEW="$DM_SCHEMA_NAME"."$VIEW_PERC_NW_H_V"
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" >> $LOG_F_NAME
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" > $TMP_F_NAME
            	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
				$DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME
                LAST_ERROR=$?
            fi

		    if [ $LAST_ERROR != 0 -a $LAST_ERROR != 2 ]
		    then
                echo "Failed to re-create view: $PERC_VIEW" >> $LOG_F_NAME
			    return
		    fi
        fi
	fi
}

################################################################################
# Drops a given view if it exists.
################################################################################
drop_view_if_exists()
{
    LAST_ERROR=0

	DROP_V_VIEW_NAME="MES"_"$1"
	# Drop the view if it exists.
	E_VIEW=`db2 -x "select tabname from syscat.tables where tabname = '$DROP_V_VIEW_NAME' and type = 'V' and tabschema = '$DM_SCHEMA_NAME'"`

    LAST_ERROR=$?
    if [ $LAST_ERROR != 0 -a $LAST_ERROR != 1 ]
    then
        echo "Failed to query system catalog for view name: $DROP_V_VIEW_NAME" >> $LOG_F_NAME
        return
    fi
	if [ ! -z $E_VIEW ]
	then
    	DB2CMD="$DB2_CMD_DROP_VIEW $SPACE "$DM_VIEW_NAME_PREFIX"_"$1""

    	echo "Dropping Datamart view if exists: " "$DM_VIEW_NAME_PREFIX"_"$1" >> $LOG_F_NAME

    	echo "Running: " $DB2CMD >> $LOG_F_NAME
    	$DB2 "$DB2CMD" 2>&1 >> $LOG_F_NAME
		LAST_ERROR=$?
		if [ $LAST_ERROR != 0 ]
		then
			echo "Failed to drop view: " "$DM_VIEW_NAME_PREFIX"_"$1" >> $LOG_F_NAME
			return
		fi
		VIEW_EXISTS=1
	else
        LAST_ERROR=0
    	echo "View:" "$DM_VIEW_NAME_PREFIX"_"$1" "does not exist." >> $LOG_F_NAME
		VIEW_EXISTS=0
	fi
}

################################################################################
# Creates a table once its view was dropped. Analytics reports need either the
# table of the view to work for each of the metrics tables.
################################################################################
create_dm_table()
{
    LAST_ERROR=0

	TABLE_NAME=$1
	TABLE_BODY=$2

	# Check if the table already exists.
	E_TABLE=`db2 -x "select tabname from syscat.tables where tabname = '$TABLE_NAME' and type = 'T' and tabschema = '$DM_SCHEMA_NAME'"`

    LAST_ERROR=$?
    if [ $LAST_ERROR != 0 -a $LAST_ERROR != 1 ]
    then
        echo "Failed to query system catalog for table name: $TABLE_NAME" >> $LOG_F_NAME
        return
    fi

	if [ -z "$E_TABLE" ]
	then
    	DB2CMD="$DB2_CMD_CREATE_TABLE $SPACE "$DM_SCHEMA_NAME"."MES_$TABLE_NAME" "$TABLE_BODY""

    	echo $DB2CMD > $TMP_F_NAME
    	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME

    	run_command
	fi
}

################################################################################
# Drops a given nick name if it exists.
################################################################################
drop_nickname_if_exists()
{
    LAST_ERROR=0

	DN_NICK_NAME=`echo $1 | awk -v var="$DM_SCHEMA_NAME." '{ sub(var, "");print}'`
	# Drop the nick name if it exists.
	E_NICK=`db2 -x "select tabname from syscat.tables where tabname = '$DN_NICK_NAME' and type = 'N' and tabschema = '$DM_SCHEMA_NAME'"`

	LAST_ERROR=$?
	if [ $LAST_ERROR != 0 -a $LAST_ERROR != 1 ]
	then
		echo "Failed to query system catalog for nick name: $DN_NICK_NAME." >> $LOG_F_NAME
		return
	fi

	if [ ! -z $E_NICK ]
	then
    	echo "Dropping nick name if exists: " $1 >> $LOG_F_NAME
    	DB2CMD="$DB2_CMD_DROP_NICKNAME $SPACE $1"

    	echo $DB2CMD >> $LOG_F_NAME
    	$DB2 "$DB2CMD" 2>&1 >> $LOG_F_NAME

		LAST_ERROR=$?
		if [ $LAST_ERROR != 0 ]
		then
			echo "Failed to drop nick name: $1." >> $LOG_F_NAME
			return
		fi

	else
        LAST_ERROR=0
    	echo "Nick name:" "$1" "does not exist." >> $LOG_F_NAME
	fi
}

################################################################################
# Handles all the required processing.
################################################################################
process()
{
    LAST_ERROR=0


    if [ $COMMAND == "-add" ]
    then
        create_nickname $1
		if [ $LAST_ERROR != 0 ]
		then
			FAILED_COUNT=$[FAILED_COUNT + 1]
			return
		fi

        create_dm_view $1
		if [ $LAST_ERROR != 0 ]
		then
			FAILED_COUNT=$[FAILED_COUNT + 1]
			return
		fi

		PERC_VIEW=
		# Update Percentile views.
        if [ $DB2_VERSION = "v9.5" ]
        then
            if [ $1 == "VIRTUAL_MACHINES_H" ]
            then
                PERC_VIEW="$DM_SCHEMA_NAME"."$VIEW_PERC_CPU_H_V"
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" >> $LOG_F_NAME
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" > $TMP_F_NAME
            	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
				$DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME
                LAST_ERROR=$?
            elif [ $1 == "VM_MEMORY_H" ]
            then
                PERC_VIEW="$DM_SCHEMA_NAME"."$VIEW_PERC_MEM_H_V"
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" >> $LOG_F_NAME
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" > $TMP_F_NAME
            	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
				$DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME
                LAST_ERROR=$?
            elif [ $1 == "VM_NETWORK_H" ]
            then
                PERC_VIEW="$DM_SCHEMA_NAME"."$VIEW_PERC_NW_H_V"
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" >> $LOG_F_NAME
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" > $TMP_F_NAME
            	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
				$DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME
                LAST_ERROR=$?
            fi

		    if [ $LAST_ERROR != 0 -a $LAST_ERROR != 2 ]
		    then
                echo "Failed to re-create view: $PERC_VIEW" >> $LOG_F_NAME
			    return
		    fi
        fi

    elif [ $COMMAND == "-delete" ]
    then
        delete_dm_view $1
		if [ $LAST_ERROR != 0 ]
		then
			FAILED_COUNT=$[FAILED_COUNT + 1]
			return
		fi
        
        if [ $VIEW_EXISTS -eq 1 ]
	    then
            delete_nickname $1
		    if [ $LAST_ERROR != 0 ]
		    then
		    	FAILED_COUNT=$[FAILED_COUNT + 1]
			    return
		    fi
        fi

    fi
    echo "................................................................................" >> $LOG_F_NAME
}

################################################################################
# Usage. 
################################################################################
usage()
{
	echo "Usage: $0 -help
       tadfdc_setup_fed_mssql.sh -server <SERVER_NAME> -dm <DATABASE_NAME>
          -dmschema <SCHEMA_NAME> [-add | -delete]
          [ all | PS_CPU[_[H|D|W|M|Q|Y]] PS_MEM[_[H|D|W|M|Q|Y]]
          PS_IO[_[H|D|W|M|Q|Y]] PS_NET[_[H|D|W|M|Q|Y]]
          VM_CPU[_[H|D|W|M|Q|Y]] VM_MEM[_[H|D|W|M|Q|Y]]
          VM_NET[_[H|D|W|M|Q|Y]] VM_DS[_[H|D|W|M|Q|Y]] ]
where
       -server    : Name of the remote data source configured with
                    the DRDA wrapper using CREATE SERVER command
       -dm        : Name of the Capacity Planner database
       -dmschema  : Name of the Capacity Planner database schema
       -add       : Adds a federation link
       -delete    : Removes a federation link

Arguments are of the form MACHINE_COMPONENT[_AGGREGATION-LEVEL]

where
   MACHINE     : physical server (PS) or virtual machine (VM),
   COMPONENT   : CPU (CPU), memory (MEM), IO (IO),
                 network (NET) or datastore (DS)
and
   AGGREGATION-LEVEL   : Hourly (_H), Daily (_D), Weekly (_W),
                         Monthly (_M), Quarterly (_Q) or Yearly (_Y)
Argument all adds or deletes all the required federation links.

Examples

(i) Set up federation for Physical Server CPU Hourly utilization:

tadfdc_setup_fed_mssql.sh -server WHSERVER -dm TADFDCDB -dmschema TADFDC -add PS_CPU_
H

(ii) Set up federation for Virtual Machine Memory Daily utilization:

tadfdc_setup_fed_mssql.sh -server WHSERVER -dm TADFDCDB -dmschema TADFDC -add VM_MEM_
D

(iii) Set up federation for Physical Server Network Weekly utilization:

tadfdc_setup_fed_mssql.sh -server WHSERVER -dm TADFDCDB -dmschema TADFDC -add PS_NET_
W

(iv) Set up federation for all supported utilization metrics:

tadfdc_setup_fed_mssql.sh -server WHSERVER -dm TADFDCDB -dmschema TADFDC -add all

(v) Remove federation for Virtual Machine Datastore Monthly utilization:

tadfdc_setup_fed_mssql.sh -server WHSERVER -dm TADFDCDB -dmschema TADFDC -delete VM_D
S_M

(vi) Remove federation for Physical Server Disk IO Quarterly utilization:

tadfdc_setup_fed_mssql.sh -server WHSERVER -dm TADFDCDB -dmschema TADFDC -delete PS_I
O_Q"
}

################################################################################
# Initializes the working environment of the script.
################################################################################
init()
{
    LAST_ERROR=0


	if [ -f $TMP_F_NAME ]
	then
		$REM $TMP_F_NAME
	fi

    LOCAL_SERVER_NAME=$2
    DM_NAME=$4
    DM_SCHEMA_NAME=$6
    COMMAND=$7

    FED_TABLE_NAME_PREFIX="$DM_SCHEMA_NAME"."FED_KVM"
    DM_VIEW_NAME_PREFIX="$DM_SCHEMA_NAME"."MES"
    TDW_TABLE_PREFIX="$LOCAL_SERVER_NAME"."$TDW_SCHEMA_NAME"."KVM"

    echo "Connecting to: " $DM_NAME "..." >> $LOG_F_NAME
	echo >> $LOG_F_NAME
    $DB2 "connect to $DM_NAME" 2>&1 >> $LOG_F_NAME

	LAST_ERROR=$?
	if [ $LAST_ERROR != 0 ]
	then
		echo "Failed to connect to database: $DM_NAME." >> $LOG_F_NAME
		exit 6
	fi

    echo "Setting schema to: " $DM_SCHEMA_NAME "..." >> $LOG_F_NAME
    $DB2 "set schema=$DM_SCHEMA_NAME" 2>&1 >> $LOG_F_NAME

	LAST_ERROR=$?
	if [ $LAST_ERROR != 0 ]
	then
		echo "Failed to set schema to: $DM_SCHEMA_NAME." >> $LOG_F_NAME
		exit 7
	fi

	echo "................................................................................" >> $LOG_F_NAME
	echo >> $LOG_F_NAME

	VERSION=`db2 -x select service_level from sysibmadm.env_inst_info`

	LAST_ERROR=$?
	if [ $LAST_ERROR != 0 ]
	then
		echo "Failed to extract DB2 version." >> $LOG_F_NAME
		exit 8
	fi

	DB2_VERSION=`expr substr "$VERSION" 5 4`
	if [ $DB2_VERSION = "v9.5" ]
	then
		DB2_CMD_CREATE_NICKNAME="CREATE NICKNAME"
		DB2_CMD_CREATE_VIEW="CREATE VIEW"
	fi
}

################################################################################
# Releases resources.
################################################################################
shut_down()
{

    rm -f $TMP_F_NAME
	echo >> $LOG_F_NAME
	echo "Disconnecting from: " $DM_NAME >> $LOG_F_NAME
}

################################################################################
# Argument parsing.
################################################################################
parse_arguments()
{
    LAST_ERROR=0


    if [ $# -eq 1 ]
    then
        if [ $1 == "-help" ]
        then
		# "Configures federation between remote metrics data sources and the Capacity Planner database."
		$JAVA $CLASSNAME "ANA01003I"
	else
		$JAVA $CLASSNAME "ANA01002E"
            	usage
            	exit 6
       	fi

        usage
        exit 0
    fi

    if [ $# -lt 8 ]
    then
	$JAVA $CLASSNAME "ANA01002E"
        usage
        exit 1
    fi
    
    if [ $1 != "-server" -o $3 != "-dm" -o $5 != "-dmschema" ]
    then
	$JAVA $CLASSNAME "ANA01002E"
        usage
        exit 2
    fi
    
    if [ $7 != "-add" -a $7 != "-delete" ]
    then
	$JAVA $CLASSNAME "ANA01002E"
        usage
        exit 3
    fi

    ITEM_NO=0
    for ITEM in $*
    do
        ITEM_NO=$[ITEM_NO + 1]
        if [ $ITEM_NO -lt 8 ]
        then
            continue;
        fi

        case $ITEM in
			all)

            shift
            ;;

            PS_CPU|PS_CPU_H|PS_CPU_D|PS_CPU_W|PS_CPU_M|PS_CPU_Q|PS_CPU_Y)
            shift
            ;;
        
            PS_MEM|PS_MEM_H|PS_MEM_D|PS_MEM_W|PS_MEM_M|PS_MEM_Q|PS_MEM_Y)
            ;;
    
            PS_IO|PS_IO_H|PS_IO_D|PS_IO_W|PS_IO_M|PS_IO_Q|PS_IO_Y)
            ;;
    
            PS_NET|PS_NET_H|PS_NET_D|PS_NET_W|PS_NET_M|PS_NET_Q|PS_NET_Y)
            ;;
    
            VM_CPU|VM_CPU_H|VM_CPU_D|VM_CPU_W|VM_CPU_M|VM_CPU_Q|VM_CPU_Y)
            ;;
    
            VM_MEM|VM_MEM_H|VM_MEM_D|VM_MEM_W|VM_MEM_M|VM_MEM_Q|VM_MEM_Y)
            ;;
    
            VM_NET|VM_NET_H|VM_NET_D|VM_NET_W|VM_NET_M|VM_NET_Q|VM_NET_Y)
            ;;
    
            VM_DS|VM_DS_H|VM_DS_D|VM_DS_W|VM_DS_M|VM_DS_Q|VM_DS_Y)
            ;;
        
            *)
                echo "Invalid argument:" $ITEM >> $LOG_F_NAME
                usage
                exit 4
        esac

    done
}

################################################################################
# Sets up the federation environment.
################################################################################
process_arguments()
{
    LAST_ERROR=0


    shift 7
    while [ $# -gt 0 ]
    do
        ARG=$1
        
        case $ARG in
            all)

            shift
            ;;

            PS_CPU|PS_CPU_H|PS_CPU_D|PS_CPU_W|PS_CPU_M|PS_CPU_Q|PS_CPU_Y)
    
    	    
            process `echo $ARG | awk '{ sub("PS", "SERVER");print}'`
            shift
            ;;
        
            PS_MEM|PS_MEM_H|PS_MEM_D|PS_MEM_W|PS_MEM_M|PS_MEM_Q|PS_MEM_Y)
    
            NEW_ARG=`echo $ARG | awk '{ sub("PS", "SERVER");print}'`
            process `echo $NEW_ARG | awk '{ sub("MEM", "MEMORY");print}'`
            shift
            ;;
    
            PS_IO|PS_IO_H|PS_IO_D|PS_IO_W|PS_IO_M|PS_IO_Q|PS_IO_Y)
    
            NEW_ARG=`echo $ARG | awk '{ sub("PS", "SERVER");print}'`
            process `echo $NEW_ARG | awk '{ sub("IO", "DISK");print}'`
            shift
            ;;
    
            PS_NET|PS_NET_H|PS_NET_D|PS_NET_W|PS_NET_M|PS_NET_Q|PS_NET_Y)
        
            NEW_ARG=`echo $ARG | awk '{ sub("PS", "SERVER");print}'`
            process `echo $NEW_ARG | awk '{ sub("NET", "NETWORK");print}'`
            shift
            ;;
    
            VM_CPU|VM_CPU_H|VM_CPU_D|VM_CPU_W|VM_CPU_M|VM_CPU_Q|VM_CPU_Y)
        
            process `echo $ARG | awk '{ sub("VM_CPU", "VIRTUAL_MACHINES");print}'`
            shift
            ;;
    
            VM_MEM|VM_MEM_H|VM_MEM_D|VM_MEM_W|VM_MEM_M|VM_MEM_Q|VM_MEM_Y)
        
            process `echo $ARG | awk '{ sub("MEM", "MEMORY");print}'`
            shift
            ;;
    
            VM_NET|VM_NET_H|VM_NET_D|VM_NET_W|VM_NET_M|VM_NET_Q|VM_NET_Y)
        
            process `echo $ARG | awk '{ sub("NET", "NETWORK");print}'`
            shift
            ;;
    
            VM_DS|VM_DS_H|VM_DS_D|VM_DS_W|VM_DS_M|VM_DS_Q|VM_DS_Y)
        
			NICK_SUFFIX=`echo $ARG | awk '{ sub("DS", "DATASTORE_UTIL");print}'`
			NICK_NAME="$FED_TABLE_NAME_PREFIX"_"$NICK_SUFFIX"
			TDW_SUFFIX=`echo $ARG | awk '{ sub("DS", "DATASTORE_UTILIZATION");print}'`
    		TDW_TABLE="$TDW_TABLE_PREFIX"_"$TDW_SUFFIX"
			case $ARG in
        		VM_DS)

        		FED_TABLE_NAME_SUFFIX=VM_DATASTORE_UTILIZATION
				VIEW_NAME=VM_DATA_STORE
        		VIEW_BODY=$VIEW_BODY_VM_DS
        		TABLE_BODY=$TABLE_BODY_VM_DS
        		;;

        		VM_DS_*)

        		FED_TABLE_NAME_SUFFIX=VM_DATASTORE_UTILIZATION_"`echo | awk -v var=$ARG '{print substr(var, length(var), 1);}'`"
			VIEW_NAME=VM_DATA_STORE_"`echo | awk -v var=$ARG '{print substr(var, length(var), 1);}'`"
        		VIEW_BODY=$VIEW_BODY_VM_DS_AGG
        		TABLE_BODY=$TABLE_BODY_VM_DS_AGG
			esac

    		if [ $COMMAND == "-add" ]
    		then

				if [ $DB2_VERSION = "v9.5" ]
				then
					drop_nickname_if_exists $NICK_NAME
					if [ $LAST_ERROR != 0 ]
					then
						return
					fi
				fi

    			DB2CMD="$DB2_CMD_CREATE_NICKNAME $SPACE $NICK_NAME FOR $TDW_TABLE"
    			echo "Running:" $DB2CMD >> $LOG_F_NAME
    			$DB2 "$DB2CMD" 2>&1 >> $LOG_F_NAME	

				LAST_ERROR=$?
				if [ $LAST_ERROR != 0 ]
				then
					echo "Failed to create nick name: $NICK_NAME" >> $LOG_F_NAME
                    echo "................................................................................" >> $LOG_F_NAME
					return
				fi

				drop_table_if_exists "MES"_"$VIEW_NAME"
				if [ $LAST_ERROR != 0 ]
				then
					return
				fi

				if [ $DB2_VERSION = "v9.5" ]
				then
					drop_view_if_exists "$VIEW_NAME"
					if [ $LAST_ERROR != 0 ]
					then
						return
					fi
				fi

    			DB2CMD="$DB2_CMD_CREATE_VIEW $SPACE "$DM_VIEW_NAME_PREFIX"_"$VIEW_NAME" $SPACE AS $VIEW_BODY $SPACE FROM $NICK_NAME $SPACE T"

    			echo $DB2CMD > $TMP_F_NAME
    			echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
    			run_command

                # Update Percentile views.
				if [ $DB2_VERSION = "v9.5" ]
				then
    		        if [ $ARG == "VM_DS_H" ]
                    then
						echo $DB2_CMD_CREATE_VIEW $SPACE "$DM_SCHEMA_NAME"."$VIEW_PERC_DISK_H_V" >> $LOG_F_NAME
						echo $DB2_CMD_CREATE_VIEW $SPACE "$DM_SCHEMA_NAME"."$VIEW_PERC_DISK_H_V" > $TMP_F_NAME
    			        echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
						$DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME

						LAST_ERROR=$?
						if [ $LAST_ERROR != 0 -a $LAST_ERROR != 2 ]
						then
							echo "Failed to create view: $VIEW_PERC_DISK_H_V" >> $LOG_F_NAME
							return
						fi

                    fi
				fi

    		elif [ $COMMAND == "-delete" ]
    		then

				drop_view_if_exists $VIEW_NAME
				if [ $LAST_ERROR != 0 ]
				then
					return
				fi

	            if [ $VIEW_EXISTS -eq 1 ]
	            then
				    create_dm_table $VIEW_NAME "$TABLE_BODY"
				    if [ $LAST_ERROR != 0 ]
				    then
					    return
				    fi

                    # Update Percentile views.
				    if [ $DB2_VERSION = "v9.5" ]
				    then
    		            if [ $ARG == "VM_DS_H" ]
                        then
						    echo $DB2_CMD_CREATE_VIEW $SPACE "$DM_SCHEMA_NAME"."$VIEW_PERC_DISK_H_V" >> $LOG_F_NAME
						    echo $DB2_CMD_CREATE_VIEW $SPACE "$DM_SCHEMA_NAME"."$VIEW_PERC_DISK_H_V" > $TMP_F_NAME
    			            echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
						    $DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME

						    LAST_ERROR=$?
						    if [ $LAST_ERROR != 0 -a $LAST_ERROR != 2 ]
						    then
							    echo "Failed to create view: $VIEW_PERC_DISK_H_V" >> $LOG_F_NAME
							    return
						    fi
    
                        fi
				    fi

				    drop_nickname_if_exists $NICK_NAME
				    if [ $LAST_ERROR != 0 ]
				    then
					    return
				    fi
                fi
    		fi
			echo "................................................................................" >> $LOG_F_NAME
			
            shift
            ;;
        
            *)
                usage
                exit 5
        esac
    done

    # run_commands
}

################################################################################
# Entry point.
################################################################################
main()
{
	
	ARGS=$*
	
	if [ $1 == "-CONFIGSERVER" ] 
	then
		if [ $2 == "SET_AUTO_STATS_PROF_OFF" ] 
		then
			PROFOFF $ARGS
		elif [ $2 == "CREATE_WRAPPER" ] 
		then
			CREATE_WRAPPER $ARGS
		elif [ $2 == "CREATE_SERVER" ] 
		then
			CREATE_SERVER $ARGS
		elif [ $2 == "CREATE_USER_MAPPING" ] 
		then
			CREATE_USER_MAPPING $ARGS
		elif [ $2 == "UPDATE_USER_MAPPING" ] 
		then
			UPDATE_USER_MAPPING $ARGS
		elif [ $2 == "DROP_WRAPPER" ] 
		then
			DROP_WRAPPER $ARGS
		fi
	fi
	
	parse_arguments $ARGS

    if [ $8 == "all" ]
    then
        ARGS="$* $ALL_SUPPORTED"
    fi

    # Handle interrupts gracefully.
    trap "$DB2 terminate 2>&1 >> $LOG_F_NAME" 0 2 3 9 15

    $JAVA $CLASSNAME "ANA01003I"
    init $ARGS

    process_arguments $ARGS

    # "Please check $LOG_F_NAME for details."
    shut_down
    echo FAILED_COUNT=$FAILED_COUNT
    
    exit $LAST_ERROR
}

PROFOFF()
{
	DB_NAME=$3
	USER_NAME=$4
	USER_PASSWORD=$5
	
	$DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD
	$DB2 "update db cfg using AUTO_STATS_PROF OFF"
	
	STATUS=$?
	exit $STATUS
}

CREATE_WRAPPER()
{
	DB_NAME=$3
	USER_NAME=$4
	USER_PASSWORD=$5
	
	$DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD
	$DB2 "CREATE WRAPPER DRDA"
	STATUS=$?
	echo $STATUS
	exit $STATUS
}

DROP_WRAPPER()
{
	DB_NAME=$3
	USER_NAME=$4
	USER_PASSWORD=$5
	
	$DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD
	
	$DB2 "DROP WRAPPER DRDA"
	STATUS=$?
	echo $STATUS
	exit $STATUS
}

CREATE_SERVER()
{

	CONN_STRING=$3
	conn_str_len=${#CONN_STRING}
	delim_index=`expr index "$CONN_STRING" "\:"`
	delim_index=`expr $delim_index + 1`
	num_chars=`expr $conn_str_len - $delim_index + 1`
	CONN_STRING=`expr substr $CONN_STRING $delim_index $num_chars`
	delim_index=`expr index "$CONN_STRING" "\/"`
	num_name_chars=`expr $delim_index - 1`
	DB_NAME=`expr substr $CONN_STRING 1 $num_name_chars`
	
	conn_str_len=${#CONN_STRING}
	delim_index=`expr $delim_index + 1`
	num_chars=`expr $conn_str_len - $delim_index + 1`
	CONN_STRING=`expr substr $CONN_STRING $delim_index $num_chars`
	delim_index=`expr index "$CONN_STRING" "\/"`
	num_name_chars=`expr $delim_index - 1`
	USER_NAME=`expr substr $CONN_STRING 1 $num_name_chars`
	
	conn_str_len=${#CONN_STRING}
	delim_index=`expr $delim_index + 1`
	num_chars=`expr $conn_str_len - $delim_index + 1`
	CONN_STRING=`expr substr $CONN_STRING $delim_index $num_chars`
	delim_index=${#CONN_STRING}
	num_name_chars=`expr $delim_index`
	USER_PASSWORD=`expr substr $CONN_STRING 1 $num_name_chars`
	
	SERVER_NAME=$4
	SERVER_TYPE=$5
	SERVER_VERSION=$6
	REMOTE_USER=$7
	REMOTE_PASSWORD=$8
	TDW_LOCAL_ALIAS=$9
	
	$DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD
	$DB2 "CREATE SERVER $SERVER_NAME TYPE $SERVER_TYPE VERSION $SERVER_VERSION WRAPPER DRDA AUTHORIZATION \"$REMOTE_USER\" PASSWORD \"$REMOTE_PASSWORD\" OPTIONS (DBNAME '$TDW_LOCAL_ALIAS')"

	STATUS=$?
	exit $STATUS
	
}

CREATE_USER_MAPPING()
{

	DB_NAME=$3
	USER_NAME=$4
	USER_PASSWORD=$5
	SERVER_NAME=$6
	REMOTE_USER=$7
	REMOTE_PASSWORD=$8
	
	$DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD
	$DB2 "CREATE USER MAPPING FOR $USER_NAME SERVER $SERVER_NAME OPTIONS (REMOTE_AUTHID '$REMOTE_USER', REMOTE_PASSWORD '$REMOTE_PASSWORD')"
	STATUS=$?
	echo $STATUS
	
	$DB2 SET PASSTHRU $SERVER_NAME
	
	exit $STATUS
	
}

UPDATE_USER_MAPPING()
{

	DB_NAME=$3
	USER_NAME=$4
	USER_PASSWORD=$5
	SERVER_NAME=$6
	REMOTE_USER=$7
	REMOTE_PASSWORD=$8
	
	$DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD
	$DB2 "ALTER USER MAPPING FOR $USER_NAME SERVER $SERVER_NAME OPTIONS (SET REMOTE_AUTHID '$REMOTE_USER', SET REMOTE_PASSWORD '$REMOTE_PASSWORD')"
	
	STATUS=$?
	echo $STATUS
	exit $STATUS
	
}

# Main
main $*
