# *******************************************************************************
# IBM Confidential
# OCO Source Materials
#  Copyright IBM Corp. 2011
#
# The source code for this program is not published or otherwise divested of its trade secrets,
# irrespective of what has been deposited with the U.S. Copyright Office.
# ******************************************************************************/

#!/bin/bash

JAVA=java

CLASSNAME=com.ibm.sunset.common.globalization.Server.MessageRetrieval

export CLASSPATH=./MessageRetrieval.jar:./lib/log4j-1.2.15.jar:$CLASSPATH

DB2=db2

TMP_F_NAME=sql.tmp
TMP_DDL_FILE_NAME=federationqueries.ddl
LOG_F_NAME=federation.log

SPACE=" "
DB2_CMD_SEPARATOR="@"

TDW_SCHEMA_NAME="ITMUSER"
FAILED_VIEW=
SUCCESS_VIEW=
VIEW_NAME=
REM="rm -f"
DB2_CMD_CREATE_NICKNAME="CREATE OR REPLACE NICKNAME"
DB2_CMD_DROP_NICKNAME="DROP NICKNAME"
DB2_CMD_CREATE_VIEW="CREATE OR REPLACE VIEW"
DB2_CMD_DROP_VIEW="DROP VIEW"
DB2_CMD_CREATE_TABLE="CREATE TABLE"
DB2_CMD_DROP_TABLE="DROP TABLE"

VIEW_EXISTS=0
G_LAST_ERROR=0

G_FAILED_COUNT=0
FAILED_VIEWS=""
DBA_MODE=
WRAPPER_NAME=""
################################################################################
# List of supported federated metrices.
################################################################################
ALL_SUPPORTED="PS_CPU PS_CPU_H PS_CPU_D PS_CPU_W PS_CPU_M PS_CPU_Q PS_CPU_Y PS_MEM PS_MEM_H PS_MEM_D PS_MEM_W PS_MEM_M PS_MEM_Q PS_MEM_Y PS_IO PS_IO_H PS_IO_D PS_IO_W PS_IO_M PS_IO_Q PS_IO_Y PS_NET PS_NET_H PS_NET_D PS_NET_W PS_NET_M PS_NET_Q PS_NET_Y VM_CPU VM_CPU_H VM_CPU_D VM_CPU_W VM_CPU_M VM_CPU_Q VM_CPU_Y VM_MEM VM_MEM_H VM_MEM_D VM_MEM_W VM_MEM_M VM_MEM_Q VM_MEM_Y VM_NET VM_NET_H VM_NET_D VM_NET_W VM_NET_M VM_NET_Q VM_NET_Y VM_DS VM_DS_H VM_DS_D VM_DS_W VM_DS_M VM_DS_Q VM_DS_Y"

QC="\""
TRANSMITTED_PKTS_COL_NAME="TPACKPS"

initTableDefs()
{
################################################################################
# List of SQL statements forming bodies of the Datamart views.
################################################################################
VIEW_BODY_SERVER_CPU="SELECT T."$QC"CEC_name"$QC" AS HOST_NAME, -1 AS CPU_NUMBER, T."$QC"CPU_Used_Pct"$QC" AS CPU_UTILIZATION, T."$QC"Timestamp"$QC" AS TIMESTAMP, T."$QC"WRITETIME"$QC" AS WRITETIME"

VIEW_BODY_SERVER_CPU_AGG="SELECT T."$QC"LAT_CEC_name"$QC" AS HOST_NAME, -1 AS CPU_NUMBER, T."$QC"MIN_CPU_Used_Pct"$QC" AS MIN_CPU_UTILIZATION, T."$QC"MAX_CPU_Used_Pct"$QC" AS MAX_CPU_UTILIZATION, T."$QC"SUM_CPU_Used_Pct"$QC" AS SUM_CPU_UTILIZATION, T."$QC"AVG_CPU_Used_Pct"$QC" AS AVG_CPU_UTILIZATION, T."$QC"Timestamp"$QC" AS TIMESTAMP, T."$QC"WRITETIME"$QC" AS WRITETIME"

VIEW_BODY_SERVER_DISK="SELECT 'NA' AS HOST_NAME, T."$QC"Name"$QC" AS DISK_NAME, T."$QC"Name"$QC" AS DATA_STORE_NAME, T."$QC"Read_KB_per_Sec"$QC" AS READ_KBPS, T."$QC"Written_KB_per_Sec"$QC" AS WRITE_KBPS, T."$QC"Read_Transfers_per_Sec"$QC" AS READ_COUNT, T."$QC"Written_KB_per_Sec"$QC" AS WRITE_COUNT, -1 AS BUS_RESET, T."$QC"Transfers_per_Sec"$QC" AS COMMANDS_COUNT, -1 AS COMMANDS_ABORTED_COUNT, -1 AS DEVICE_READ_LATENCY, -1 AS DEVICE_WRITE_LATENCY, -1 AS DEVICE_TOTAL_LATENCY, -1 AS DEVICE_LATENCY, T."$QC"Timestamp"$QC" AS TIMESTAMP, T."$QC"WRITETIME"$QC" AS WRITETIME"

VIEW_BODY_SERVER_DISK_AGG="SELECT 'NA' AS HOST_NAME, T."$QC"Name"$QC" AS DISK_NAME, T."$QC"Name"$QC" AS DATA_STORE_NAME, T."$QC"MIN_Read_KB_per_Sec"$QC" AS MIN_READ_KBPS, T."$QC"MAX_Read_KB_per_Sec"$QC" AS MAX_READ_KBPS, T."$QC"SUM_Read_KB_per_Sec"$QC" AS SUM_READ_KBPS, T."$QC"AVG_Read_KB_per_Sec"$QC" AS	AVG_READ_KBPS, T."$QC"MIN_Written_KB_per_Sec"$QC" AS MIN_WRITE_KBPS, T."$QC"MAX_Written_KB_per_Sec"$QC" AS MAX_WRITE_KBPS, T."$QC"SUM_Written_KB_per_Sec"$QC" AS SUM_WRITE_KBPS, T."$QC"AVG_Written_KB_per_Sec"$QC" AS AVG_WRITE_KBPS, T."$QC"MIN_Read_Transfers_per_Sec"$QC" AS MIN_READ_COUNT, T."$QC"MAX_Read_Transfers_per_Sec"$QC" AS MAX_READ_COUNT, T."$QC"SUM_Read_Transfers_per_Sec"$QC" AS SUM_READ_COUNT, T."$QC"AVG_Read_Transfers_per_Sec"$QC" AS AVG_READ_COUNT, T."$QC"MIN_Write_Transfers_per_Sec"$QC" AS MIN_WRITE_COUNT, T."$QC"MAX_Write_Transfers_per_Sec"$QC" AS MAX_WRITE_COUNT, T."$QC"SUM_Write_Transfers_per_Sec"$QC" AS SUM_WRITE_COUNT, T."$QC"AVG_Write_Transfers_per_Sec"$QC" AS AVG_WRITE_COUNT, -1 AS MIN_BUS_RESET, -1 AS MAX_BUS_RESET, -1 AS SUM_BUS_RESET, -1 AS AVG_BUS_RESET, T."$QC"MIN_Transfers_per_Sec"$QC" AS MIN_COMMANDS_COUNT, T."$QC"MAX_Transfers_per_Sec"$QC" AS	MAX_COMMANDS_COUNT, T."$QC"SUM_Transfers_per_Sec"$QC" AS SUM_COMMANDS_COUNT, T."$QC"AVG_Transfers_per_Sec"$QC" AS AVG_COMMANDS_COUNT, -1 AS MIN_COMMANDS_ABORTED_COUNT, -1 AS MAX_COMMANDS_ABORTED_COUNT, -1 AS SUM_COMMANDS_ABORTED_COUNT, -1 AS AVG_COMMANDS_ABORTED_COUNT, -1 AS MIN_DEVICE_READ_LATENCY, -1 AS MAX_DEVICE_READ_LATENCY, -1 AS SUM_DEVICE_READ_LATENCY, -1 AS AVG_DEVICE_READ_LATENCY, -1 AS MIN_DEVICE_WRITE_LATENCY, -1 AS MAX_DEVICE_WRITE_LATENCY, -1 AS SUM_DEVICE_WRITE_LATENCY, -1 AS AVG_DEVICE_WRITE_LATENCY, -1 AS MIN_DEVICE_TOTAL_LATENCY, -1 AS MAX_DEVICE_TOTAL_LATENCY, -1 AS SUM_DEVICE_TOTAL_LATENCY, -1 AS AVG_DEVICE_TOTAL_LATENCY, -1 AS MIN_DEVICE_LATENCY, -1 AS MAX_DEVICE_LATENCY, -1 AS SUM_DEVICE_LATENCY, -1 AS AVG_DEVICE_LATENCY, T."$QC"Timestamp"$QC" AS TIMESTAMP, T."$QC"WRITETIME"$QC" AS WRITETIME"

VIEW_BODY_SERVER_NET="SELECT 'NA' AS HOST_NAME, T."$QC"Name"$QC" AS NIC_NAME, T."$QC"Bandwidth_Util_Pct"$QC" AS USAGE, T."$QC"Bytes_Sent_per_Sec"$QC"/1000	AS TRANSMITTED_KBPS, T."$QC"Bytes_Recvd_per_Sec"$QC"/1000 AS RECEIVED_KBPS, T."$QC"Pkts_Sent_per_Sec"$QC" AS PKTS_TRANSMITTED, T."$QC"Pkts_Recvd_per_Sec"$QC" AS PKTS_RECEIVED, T."$QC"Timestamp"$QC" AS TIMESTAMP, T."$QC"WRITETIME"$QC" AS WRITETIME"

VIEW_BODY_SERVER_NET_AGG="SELECT 'NA' AS HOST_NAME, T."$QC"Name"$QC" AS NIC_NAME, T."$QC"MIN_Bandwidth_Util_Pct"$QC" AS MIN_USAGE, T."$QC"MAX_Bandwidth_Util_Pct"$QC" AS MAX_USAGE, T."$QC"SUM_Bandwidth_Util_Pct"$QC" AS SUM_USAGE, T."$QC"AVG_Bandwidth_Util_Pct"$QC" AS AVG_USAGE, T."$QC"MIN_Bytes_Sent_per_Sec"$QC"/1000 AS MIN_TRANSMITTED_KBPS, T."$QC"MAX_Bytes_Sent_per_Sec"$QC"/1000 AS MAX_TRANSMITTED_KBPS, T."$QC"SUM_Bytes_Sent_per_Sec"$QC"/1000 AS SUM_TRANSMITTED_KBPS, T."$QC"AVG_Bytes_Sent_per_Sec"$QC"/1000 AS AVG_TRANSMITTED_KBPS, T."$QC"MIN_Bytes_Recvd_per_Sec"$QC"/1000 AS MIN_RECEIVED_KBPS, T."$QC"MAX_Bytes_Recvd_per_Sec"$QC"/1000 AS MAX_RECEIVED_KBPS, T."$QC"SUM_Bytes_Recvd_per_Sec"$QC"/1000 AS SUM_RECEIVED_KBPS, T."$QC"AVG_Bytes_Recvd_per_Sec"$QC"/1000 AS AVG_RECEIVED_KBPS, T."$QC"MIN_Pkts_Sent_per_Sec"$QC" AS MIN_PKTS_TRANSMITTED, T."$QC"MAX_Pkts_Sent_per_Sec"$QC" AS MAX_PKTS_TRANSMITTED, T."$QC"SUM_Pkts_Sent_per_Sec"$QC" AS SUM_PKTS_TRANSMITTED, T."$QC"AVG_Pkts_Sent_per_Sec"$QC" AS AVG_PKTS_TRANSMITTED, T."$QC"MIN_Pkts_Recvd_per_Sec"$QC" AS MIN_PKTS_RECEIVED, T."$QC"MAX_Pkts_Recvd_per_Sec"$QC" AS MAX_PKTS_RECEIVED, T."$QC"SUM_Pkts_Recvd_per_Sec"$QC" AS SUM_PKTS_RECEIVED, T."$QC"AVG_Pkts_Recvd_per_Sec"$QC" AS AVG_PKTS_RECEIVED, T."$QC"Timestamp"$QC" AS TIMESTAMP, T."$QC"WRITETIME"$QC" AS WRITETIME"

VIEW_BODY_VM="SELECT T."$QC"Hostname"$QC" AS HOST_NAME, T."$QC"CEC_name"$QC" AS VM_SERVER_NAME, T."$QC"LPAR_Name"$QC" AS VM_NAME, 'GLOBAL' AS DATA_CENTER_NAME, 'GLOBAL' AS VM_POOL_NAME, T."$QC"Entitled_Capacity_Used_Pct"$QC" AS CPU_UTILIZATION, T."$QC"CPU_Units_Used"$QC" AS USED_CPU_MHZ, T."$QC"Timestamp"$QC" AS TIMESTAMP, T."$QC"WRITETIME"$QC" AS WRITETIME"

VIEW_BODY_VM_AGG="SELECT T."$QC"LAT_Hostname"$QC" AS HOST_NAME, T."$QC"LAT_CEC_name"$QC" AS VM_SERVER_NAME, T."$QC"LAT_LPAR_Name"$QC" AS VM_NAME, 'GLOBAL' AS DATA_CENTER_NAME, 'GLOBAL' AS VM_POOL_NAME, T."$QC"MIN_CPU_Units_Used"$QC" AS MIN_USED_CPU_MHZ, T."$QC"MAX_CPU_Units_Used"$QC" AS MAX_USED_CPU_MHZ, T."$QC"SUM_CPU_Units_Used"$QC" AS SUM_USED_CPU_MHZ, T."$QC"AVG_CPU_Units_Used"$QC" AS AVG_USED_CPU_MHZ, T."$QC"MIN_Entitled_Capacity_Used_Pct"$QC" AS MIN_CPU_UTILIZATION, T."$QC"MAX_Entitled_Capacity_Used_Pct"$QC" AS MAX_CPU_UTILIZATION, T."$QC"SUM_Entitled_Capacity_Used_Pct"$QC" AS SUM_CPU_UTILIZATION, T."$QC"AVG_Entitled_Capacity_Used_Pct"$QC" AS AVG_CPU_UTILIZATION, T."$QC"Timestamp"$QC" AS TIMESTAMP, T."$QC"WRITETIME"$QC" AS WRITETIME"


VIEW_PERC_CPU_H_V="MES_PERCENTILE_CPU_H_V (VM_KEY, VM_NAME, WRITETIME, AVG_CPU_UTILIZATION) AS ( SELECT VM.VIRTUAL_MACHINE_PK, MES.VM_NAME, MES.WRITETIME, MES.AVG_CPU_UTILIZATION FROM MES_VM_CPU_H AS MES , ANL_WORKING_SET_V AS WORKINGSET , ANL_TIME_DIM AS TIME , CFG_USER_CONFIGURATION AS USER_CONFIG , CFG_VIRTUAL_MACHINE AS VM WHERE MES.VM_NAME = VM.VM_NAME AND VM.PHYSICAL_SERVER_PK = WORKINGSET.PHYSICAL_SERVER_PK AND MES.WRITETIME = TIME.CANDLETIMESTAMP AND TIME.TIME_RANGE_START BETWEEN USER_CONFIG.START_TIME AND USER_CONFIG.END_TIME AND MES.AVG_CPU_UTILIZATION >=0)"

VIEW_PERC_DISK_H_V="MES_PERCENTILE_DISK_H_V (VM_KEY, VM_NAME, WRITETIME, AVG_TOTAL_IO) AS ( SELECT VM.VIRTUAL_MACHINE_PK, MES.VM_NAME, MES.WRITETIME, MES.AVG_TOTAL_IO FROM MES_VM_DATA_STORE_H AS MES , ANL_WORKING_SET_V AS WORKINGSET , ANL_TIME_DIM AS TIME , CFG_USER_CONFIGURATION AS USER_CONFIG , CFG_VIRTUAL_MACHINE AS VM WHERE MES.VM_NAME = VM.VM_NAME AND VM.PHYSICAL_SERVER_PK = WORKINGSET.PHYSICAL_SERVER_PK AND MES.WRITETIME = TIME.CANDLETIMESTAMP AND TIME.TIME_RANGE_START BETWEEN USER_CONFIG.START_TIME AND USER_CONFIG.END_TIME AND MES.AVG_TOTAL_IO >=0)"

VIEW_PERC_MEM_H_V="MES_PERCENTILE_MEM_H_V (VM_KEY, VM_NAME, WRITETIME, AVG_GUEST_UTILIZATION) AS ( SELECT VM.VIRTUAL_MACHINE_PK, MES.VM_NAME, MES.WRITETIME, MES.AVG_GUEST_UTILIZATION FROM MES_VM_MEM_H AS MES , ANL_WORKING_SET_V AS WORKINGSET , ANL_TIME_DIM AS TIME , CFG_USER_CONFIGURATION AS USER_CONFIG , CFG_VIRTUAL_MACHINE AS VM WHERE MES.VM_NAME = VM.VM_NAME AND VM.PHYSICAL_SERVER_PK = WORKINGSET.PHYSICAL_SERVER_PK AND MES.WRITETIME = TIME.CANDLETIMESTAMP AND TIME.TIME_RANGE_START BETWEEN USER_CONFIG.START_TIME AND USER_CONFIG.END_TIME AND MES.AVG_GUEST_UTILIZATION >=0)"

VIEW_PERC_NW_H_V="MES_PERCENTILE_NW_H_V (VM_KEY, VM_NAME, WRITETIME, AVG_TOTAL_KBPS) AS ( SELECT VM.VIRTUAL_MACHINE_PK, MES.VM_NAME, MES.WRITETIME, (MES.AVG_RECEIVED_KBPS + MES.AVG_TRANSMITTED_KBPS) FROM MES_VM_NETWORK_H AS MES , ANL_WORKING_SET_V AS WORKINGSET , ANL_TIME_DIM AS TIME , CFG_USER_CONFIGURATION AS USER_CONFIG , CFG_VIRTUAL_MACHINE AS VM WHERE MES.VM_NAME = VM.VM_NAME AND VM.PHYSICAL_SERVER_PK = WORKINGSET.PHYSICAL_SERVER_PK AND MES.WRITETIME = TIME.CANDLETIMESTAMP AND TIME.TIME_RANGE_START BETWEEN USER_CONFIG.START_TIME AND USER_CONFIG.END_TIME AND MES.AVG_RECEIVED_KBPS >=0 AND MES.AVG_TRANSMITTED_KBPS >=0)"
################################################################################

################################################################################
# List of SQL statements forming bodies of the Datamart tables.
################################################################################
TABLE_BODY_SERVER_CPU="( 		PS_CPU_PK BIGINT NOT NULL, 		HOST_NAME VARCHAR(256), 		CPU_NUMBER INTEGER, 		CPU_UTILIZATION BIGINT, 		PHYSICAL_SERVER_PK BIGINT, 		TIMESTAMP TIMESTAMP 	) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_CPU_AGG="( 		PS_CPU_PK BIGINT NOT NULL, 		HOST_NAME VARCHAR(256), 		CPU_NUMBER INTEGER, 		MIN_CPU_UTILIZATION BIGINT, 		MAX_CPU_UTILIZATION BIGINT, 		SUM_CPU_UTILIZATION BIGINT, 		AVG_CPU_UTILIZATION BIGINT, 		PHYSICAL_SERVER_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_MEM="( 		PS_MEM_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		HOST_NAME VARCHAR(256), 		PHYSICAL_MEMORY BIGINT, 		MEMORY_USAGE BIGINT, 		MEMORY_UTILIZATION BIGINT, 		ACTIVE_MEMORY BIGINT, 		GRANTED_MEMORY BIGINT, 		SWAP_USED BIGINT, 		FREE_MEM BIGINT, 		BALLOON_USED BIGINT, 		SWAP_IN_RATE BIGINT, 		SWAP_OUT_RATE BIGINT, 		SWAP_TOTAL_RATE BIGINT, 		PHYSICAL_SERVER_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_MEM_AGG="( 		PS_MEM_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		HOST_NAME VARCHAR(256), 		PHYSICAL_MEMORY BIGINT, 		MIN_MEMORY_USAGE BIGINT, 		MAX_MEMORY_USAGE BIGINT, 		SUM_MEMORY_USAGE BIGINT, 		AVG_MEMORY_USAGE BIGINT, 		MIN_MEMORY_UTILIZATION BIGINT, 		MAX_MEMORY_UTILIZATION BIGINT, 		SUM_MEMORY_UTILIZATION BIGINT, 		AVG_MEMORY_UTILIZATION BIGINT, 		MIN_ACTIVE_MEMORY BIGINT, 		MAX_ACTIVE_MEMORY BIGINT, 		SUM_ACTIVE_MEMORY BIGINT, 		AVG_ACTIVE_MEMORY BIGINT, 		MIN_GRANTED_MEMORY BIGINT, 		MAX_GRANTED_MEMORY BIGINT, 		SUM_GRANTED_MEMORY BIGINT, 		AVG_GRANTED_MEMORY BIGINT, 		MIN_SWAP_USED BIGINT, 		MAX_SWAP_USED BIGINT, 		SUM_SWAP_USED BIGINT, 		AVG_SWAP_USED BIGINT, 		MIN_FREE_MEM BIGINT, 		MAX_FREE_MEM BIGINT, 		SUM_FREE_MEM BIGINT, 		AVG_FREE_MEM BIGINT, 		MIN_BALLOON_USED BIGINT, 		MAX_BALLOON_USED BIGINT, 		SUM_BALLOON_USED BIGINT, 		AVG_BALLOON_USED BIGINT, 		MIN_SWAP_IN_RATE BIGINT, 		MAX_SWAP_IN_RATE BIGINT, 		SUM_SWAP_IN_RATE BIGINT, 		AVG_SWAP_IN_RATE BIGINT, 		MIN_SWAP_OUT_RATE BIGINT, 		MAX_SWAP_OUT_RATE BIGINT, 		SUM_SWAP_OUT_RATE BIGINT, 		AVG_SWAP_OUT_RATE BIGINT, 		MIN_SWAP_TOTAL_RATE BIGINT, 		MAX_SWAP_TOTAL_RATE BIGINT, 		SUM_SWAP_TOTAL_RATE BIGINT, 		AVG_SWAP_TOTAL_RATE BIGINT, 		PHYSICAL_SERVER_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_DISK="( 		HOST_NAME VARCHAR(256), 		PS_DISK_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		DISK_NAME VARCHAR(256), 		DATA_STORE_NAME VARCHAR(256), 		READ_KBPS BIGINT, 		WRITE_KBPS BIGINT, 		READ_COUNT BIGINT, 		WRITE_COUNT BIGINT, 		BUS_RESET BIGINT, 		COMMANDS_COUNT BIGINT, 		COMMANDS_ABORTED_COUNT BIGINT, 		DEVICE_READ_LATENCY BIGINT, 		DEVICE_WRITE_LATENCY BIGINT, 		DEVICE_TOTAL_LATENCY BIGINT, 		DEVICE_LATENCY BIGINT, 		PHYSICAL_SERVER_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_DISK_AGG="( 		HOST_NAME VARCHAR(256), 		PS_DISK_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		DISK_NAME VARCHAR(256), 		DATA_STORE_NAME VARCHAR(256), 		MIN_READ_KBPS BIGINT, 		MAX_READ_KBPS BIGINT, 		SUM_READ_KBPS BIGINT, 		AVG_READ_KBPS BIGINT, 		MIN_WRITE_KBPS BIGINT, 		MAX_WRITE_KBPS BIGINT, 		SUM_WRITE_KBPS BIGINT, 		AVG_WRITE_KBPS BIGINT, 		MIN_READ_COUNT BIGINT, 		MAX_READ_COUNT BIGINT, 		SUM_READ_COUNT BIGINT, 		AVG_READ_COUNT BIGINT, 		MIN_WRITE_COUNT BIGINT, 		MAX_WRITE_COUNT BIGINT, 		SUM_WRITE_COUNT BIGINT, 		AVG_WRITE_COUNT BIGINT, 		MIN_BUS_RESET BIGINT, 		MAX_BUS_RESET BIGINT, 		SUM_BUS_RESET BIGINT, 		AVG_BUS_RESET BIGINT, 		MIN_COMMANDS_COUNT BIGINT, 		MAX_COMMANDS_COUNT BIGINT, 		SUM_COMMANDS_COUNT BIGINT, 		AVG_COMMANDS_COUNT BIGINT, 		MIN_COMMANDS_ABORTED_COUNT BIGINT, 		MAX_COMMANDS_ABORTED_COUNT BIGINT, 		SUM_COMMANDS_ABORTED_COUNT BIGINT, 		AVG_COMMANDS_ABORTED_COUNT BIGINT, 		MIN_DEVICE_READ_LATENCY BIGINT, 		MAX_DEVICE_READ_LATENCY BIGINT, 		SUM_DEVICE_READ_LATENCY BIGINT, 		AVG_DEVICE_READ_LATENCY BIGINT, 		MIN_DEVICE_WRITE_LATENCY BIGINT, 		MAX_DEVICE_WRITE_LATENCY BIGINT, 		SUM_DEVICE_WRITE_LATENCY BIGINT, 		AVG_DEVICE_WRITE_LATENCY BIGINT, 		MIN_DEVICE_TOTAL_LATENCY BIGINT, 		MAX_DEVICE_TOTAL_LATENCY BIGINT, 		SUM_DEVICE_TOTAL_LATENCY BIGINT, 		AVG_DEVICE_TOTAL_LATENCY BIGINT, 		MIN_DEVICE_LATENCY BIGINT, 		MAX_DEVICE_LATENCY BIGINT, 		SUM_DEVICE_LATENCY BIGINT, 		AVG_DEVICE_LATENCY BIGINT, 		PHYSICAL_SERVER_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_NET="( 		PS_NETWORK_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		HOST_NAME VARCHAR(256), 		NIC_NAME VARCHAR(256), 		USAGE BIGINT, 		TRANSMITTED_KBPS BIGINT, 		RECEIVED_KBPS BIGINT, 		PKTS_TRANSMITTED BIGINT, 		PKTS_RECEIVED BIGINT, 		PHYSICAL_SERVER_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_SERVER_NET_AGG="( 		PS_NETWORK_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		HOST_NAME VARCHAR(256), 		NIC_NAME VARCHAR(256), 		MIN_USAGE BIGINT, 		MAX_USAGE BIGINT, 		SUM_USAGE BIGINT, 		AVG_USAGE BIGINT, 		MIN_TRANSMITTED_KBPS BIGINT, 		MAX_TRANSMITTED_KBPS BIGINT, 		SUM_TRANSMITTED_KBPS BIGINT, 		AVG_TRANSMITTED_KBPS BIGINT, 		MIN_RECEIVED_KBPS BIGINT, 		MAX_RECEIVED_KBPS BIGINT, 		SUM_RECEIVED_KBPS BIGINT, 		AVG_RECEIVED_KBPS BIGINT, 		MIN_PKTS_TRANSMITTED BIGINT, 		MAX_PKTS_TRANSMITTED BIGINT, 		SUM_PKTS_TRANSMITTED BIGINT, 		AVG_PKTS_TRANSMITTED BIGINT, 		MIN_PKTS_RECEIVED BIGINT, 		MAX_PKTS_RECEIVED BIGINT, 		SUM_PKTS_RECEIVED BIGINT, 		AVG_PKTS_RECEIVED BIGINT, 		PHYSICAL_SERVER_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM="( 		VM_CPU_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		VM_CPU_NUMBER INTEGER, 		WAIT_TIME BIGINT, 		USED_TIME BIGINT, 		READY_TIME BIGINT, 		SYS_TIME BIGINT, 		CPU_UTILIZATION BIGINT, 		PERCENT_READY INTEGER, 		USER_TIME BIGINT, 		VIRTUAL_MACHINE_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_AGG="( 		VM_CPU_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		VM_CPU_NUMBER INTEGER, 		MIN_WAIT_TIME BIGINT, 		MAX_WAIT_TIME BIGINT, 		SUM_WAIT_TIME BIGINT, 		AVG_WAIT_TIME BIGINT, 		MIN_USED_TIME BIGINT, 		MAX_USED_TIME BIGINT, 		SUM_USED_TIME BIGINT, 		AVG_USED_TIME BIGINT, 		MIN_READY_TIME BIGINT, 		MAX_READY_TIME BIGINT, 		SUM_READY_TIME BIGINT, 		AVG_READY_TIME BIGINT, 		MIN_SYS_TIME BIGINT, 		MAX_SYS_TIME BIGINT, 		SUM_SYS_TIME BIGINT, 		AVG_SYS_TIME BIGINT, 		MIN_CPU_UTILIZATION BIGINT, 		MAX_CPU_UTILIZATION BIGINT, 		SUM_CPU_UTILIZATION BIGINT, 		AVG_CPU_UTILIZATION BIGINT, 		MIN_PERCENT_READY INTEGER, 		MAX_PERCENT_READY INTEGER, 		SUM_PERCENT_READY INTEGER, 		AVG_PERCENT_READY INTEGER, 		IN_USER_TIME BIGINT, 		MAX_USER_TIME BIGINT, 		SUM_USER_TIME BIGINT, 		AVG_USER_TIME BIGINT, 		VIRTUAL_MACHINE_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_MEM="( 		VM_MEM_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		HOST_USAGE BIGINT, 		GUEST_USAGE BIGINT, 		HOST_UTILIZATION BIGINT, 		GUEST_UTILIZATION BIGINT, 		HOST_FREE BIGINT, 		GUEST_FREE BIGINT, 		BALLOON_USAGE BIGINT, 		SWAP_TO_FILE BIGINT, 		VIRTUAL_MACHINE_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_MEM_AGG="( 		VM_MEM_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		MIN_HOST_USAGE BIGINT, 		MAX_HOST_USAGE BIGINT, 		SUM_HOST_USAGE BIGINT, 		AVG_HOST_USAGE BIGINT, 		MIN_GUEST_USAGE BIGINT, 		MAX_GUEST_USAGE BIGINT, 		SUM_GUEST_USAGE BIGINT, 		AVG_GUEST_USAGE BIGINT, 		MIN_HOST_UTILIZATION BIGINT, 		MAX_HOST_UTILIZATION BIGINT, 		SUM_HOST_UTILIZATION BIGINT, 		AVG_HOST_UTILIZATION BIGINT, 		MIN_GUEST_UTILIZATION BIGINT, 		MAX_GUEST_UTILIZATION BIGINT, 		SUM_GUEST_UTILIZATION BIGINT, 		AVG_GUEST_UTILIZATION BIGINT, 		MIN_HOST_FREE BIGINT, 		MAX_HOST_FREE BIGINT, 		SUM_HOST_FREE BIGINT, 		AVG_HOST_FREE BIGINT, 		MIN_GUEST_FREE BIGINT, 		MAX_GUEST_FREE BIGINT, 		SUM_GUEST_FREE BIGINT, 		AVG_GUEST_FREE BIGINT, 		MIN_BALLOON_USAGE BIGINT, 		MAX_BALLOON_USAGE BIGINT, 		SUM_BALLOON_USAGE BIGINT, 		AVG_BALLOON_USAGE BIGINT, 		MIN_SWAP_TO_FILE BIGINT, 		MAX_SWAP_TO_FILE BIGINT, 		SUM_SWAP_TO_FILE BIGINT, 		AVG_SWAP_TO_FILE BIGINT, 		VIRTUAL_MACHINE_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_NET="( 		VM_NETWORK_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		TRANSMITTED_KBPS BIGINT, 		RECEIVED_KBPS BIGINT, 		PKTS_TRANSMITTED BIGINT, 		PKTS_RECEIVED BIGINT, 		VIRTUAL_MACHINE_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_NET_AGG="( 		VM_NETWORK_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		NIC_NAME VARCHAR(256), 		MIN_USAGE BIGINT, 		MAX_USAGE BIGINT, 		SUM_USAGE BIGINT, 		AVG_USAGE BIGINT, 		MIN_TRANSMITTED_KBPS BIGINT, 		MAX_TRANSMITTED_KBPS BIGINT, 		SUM_TRANSMITTED_KBPS BIGINT, 		AVG_TRANSMITTED_KBPS BIGINT, 		MIN_RECEIVED_KBPS BIGINT, 		MAX_RECEIVED_KBPS BIGINT, 		SUM_RECEIVED_KBPS BIGINT, 		AVG_RECEIVED_KBPS BIGINT, 		MIN_PKTS_TRANSMITTED BIGINT, 		MAX_PKTS_TRANSMITTED BIGINT, 		SUM_PKTS_TRANSMITTED BIGINT, 		AVG_PKTS_TRANSMITTED BIGINT, 		MIN_PKTS_RECEIVED BIGINT, 		MAX_PKTS_RECEIVED BIGINT, 		SUM_PKTS_RECEIVED BIGINT, 		AVG_PKTS_RECEIVED BIGINT, 		PHYSICAL_SERVER_PK BIGINT 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_DS="( 		VM_DATA_STORE_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		DATA_STORE_NAME VARCHAR(256), VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		TOTAL_READ BIGINT, 		TOTAL_WRITE BIGINT, 		TOTAL_IO BIGINT, 		VIRTUAL_MACHINE_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"

TABLE_BODY_VM_DS_AGG="( 		VM_DATA_STORE_PK BIGINT NOT NULL GENERATED BY DEFAULT AS IDENTITY ( START WITH 1 INCREMENT BY 1 MINVALUE 1 MAXVALUE 9223372036854775807 NO CYCLE CACHE 20), 		DATA_STORE_NAME VARCHAR(256), VM_NAME VARCHAR(128), HOST_NAME VARCHAR(256), 		MIN_TOTAL_READ BIGINT, 		MAX_TOTAL_READ BIGINT, 		SUM_TOTAL_READ BIGINT, 		AVG_TOTAL_READ BIGINT, 		MIN_TOTAL_WRITE BIGINT, 		MAX_TOTAL_WRITE BIGINT, 		SUM_TOTAL_WRITE BIGINT, 		AVG_TOTAL_WRITE BIGINT, 		MIN_TOTAL_IO BIGINT, 		MAX_TOTAL_IO BIGINT, 		SUM_TOTAL_IO BIGINT, 		AVG_TOTAL_IO BIGINT, 		VIRTUAL_MACHINE_PK BIGINT, 		TIMESTAMP TIMESTAMP 	, WRITETIME CHAR(16)) 	DATA CAPTURE NONE@"
}




################################################################################
# Runs a DB2 command contained in $TMP_F_NAME.
################################################################################
run_command()
{
    G_LAST_ERROR=0
    
	if [ $DBA_MODE != "DBAMODE" ]
	then
	echo "Running command: " "`cat $TMP_F_NAME`" >> $LOG_F_NAME
    $DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME
    G_LAST_ERROR=$?
	fi
    
}

################################################################################
# Creates nickname for a given argument.
# Arguments:
#   $1 (Mandatory)  :   TDW table name
#   $2 (Optional)   :   Context in which to create a nick name - useful when
#                       separate nicknames need to be created for the same TDW
#                       table.
################################################################################
create_nickname()
{
	CN_CONTEXT=""
    if [ $# == 2 ]
    then
        CN_CONTEXT=_$2
    fi

    G_LAST_ERROR=0

    CN_TDW_TABLE="$TDW_TABLE_PREFIX".""$QC"$1"$QC""
    CN_NICK_NAME="$NICK_NAME_PREFIX"_"$1""$CN_CONTEXT"

	if [ $DB2_VERSION = "v9.5" ]
	then
		drop_nickname_if_exists $CN_NICK_NAME
		if [ $G_LAST_ERROR != 0 ]
		then
			return
		fi
	fi
	CN_DB2CMD="$DB2_CMD_CREATE_NICKNAME $SPACE $CN_NICK_NAME FOR $CN_TDW_TABLE"
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo "$DB2 $CN_DB2CMD" >> $TMP_DDL_FILE_NAME
	G_LAST_ERROR=0
	else
    echo "Creating nick name: " $CN_NICK_NAME >> $LOG_F_NAME
    echo "Running:" $CN_DB2CMD >> $LOG_F_NAME
	$DB2 "$CN_DB2CMD" 2>&1 >> $LOG_F_NAME
	G_LAST_ERROR=$?
	fi
	
	if [ $G_LAST_ERROR != 0 ]
	then
		echo "Failed to create nick name: $CN_NICK_NAME." >> $LOG_F_NAME
        echo "................................................................................" >> $LOG_F_NAME
        return
    else
	    if [ $DBA_MODE != "DBAMODE" ]
		then
	    echo "Nick name $CN_NICK_NAME created successfully. ">> $LOG_F_NAME
	    fi
	fi
}

################################################################################
# Creates Datamart view for a given argument.
################################################################################
create_dm_view()
{
	G_LAST_ERROR=0
    CDM_DB2CMD=""

    case $2 in
        SERVER_CPU)

        FED_TABLE_NAME_SUFFIX=`echo $2 | awk '{ sub("SERVER", "PS");print}'`
	    CDV_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        CDV_VIEW_BODY=$VIEW_BODY_SERVER_CPU
        ;;

        SERVER_CPU_*)

        FED_TABLE_NAME_SUFFIX=`echo $2 | awk '{ sub("SERVER", "PS");print}'`
	    CDV_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        CDV_VIEW_BODY=$VIEW_BODY_SERVER_CPU_AGG
        ;;

        SERVER_DISK)

        FED_TABLE_NAME_SUFFIX=`echo $2 | awk '{ sub("SERVER", "PS");print}'`
	    CDV_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        CDV_VIEW_BODY=$VIEW_BODY_SERVER_DISK
        ;;

        SERVER_DISK_*)

        FED_TABLE_NAME_SUFFIX=`echo $2 | awk '{ sub("SERVER", "PS");print}'`
	    CDV_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        CDV_VIEW_BODY=$VIEW_BODY_SERVER_DISK_AGG
        ;;

        SERVER_NETWORK)

        FED_TABLE_NAME_SUFFIX=`echo $2 | awk '{ sub("SERVER", "PS");print}'`
	    CDV_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        CDV_VIEW_BODY=$VIEW_BODY_SERVER_NET
        ;;

        SERVER_NETWORK_*)

        FED_TABLE_NAME_SUFFIX=`echo $2 | awk '{ sub("SERVER", "PS");print}'`
	    CDV_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        CDV_VIEW_BODY=$VIEW_BODY_SERVER_NET_AGG
        ;;

        VIRTUAL_MACHINES)

        FED_TABLE_NAME_SUFFIX=`echo $2 | awk '{ sub("VIRTUAL_MACHINES", "VM_CPU");print}'`
	    CDV_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        CDV_VIEW_BODY=$VIEW_BODY_VM
        ;;

        VIRTUAL_MACHINES_*)

        FED_TABLE_NAME_SUFFIX=`echo $2 | awk '{ sub("VIRTUAL_MACHINES", "VM_CPU");print}'`
	    CDV_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        CDV_VIEW_BODY=$VIEW_BODY_VM_AGG
        ;;

        *)
            $JAVA $CLASSNAME "ANA01002E"
			G_LAST_ERROR=9
            return
    esac

	drop_table_if_exists "MES"_"$CDV_VIEW_NAME"
	if [ $G_LAST_ERROR != 0 ]
	then
		return
	fi

	if [ $DB2_VERSION = "v9.5" ]
	then
		drop_view_if_exists "$CDV_VIEW_NAME"
		if [ $G_LAST_ERROR != 0 ]
		then
			return
		fi
	fi

    if [ -z "$CDM_DB2CMD" ]
    then
        CDM_DB2CMD="$DB2_CMD_CREATE_VIEW $SPACE "$DM_VIEW_NAME_PREFIX"_"$CDV_VIEW_NAME" $SPACE AS $CDV_VIEW_BODY $SPACE FROM "$NICK_NAME_PREFIX"_"$1" $SPACE T"
    fi
	if [ $DBA_MODE == "DBAMODE" ]
	then
		echo "$DB2 $CDM_DB2CMD ">>  $TMP_DDL_FILE_NAME
	else
		echo $CDM_DB2CMD > $TMP_F_NAME
		echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
	fi
	VIEW_NAME="MES_"$CDV_VIEW_NAME
	if [ $DBA_MODE != "DBAMODE" ]
	then
	echo "Creating a view $VIEW_NAME." >> $LOG_F_NAME
	fi
    run_command
}

################################################################################
# Removes table corresponding to the argument.
################################################################################
drop_table_if_exists()
{
	G_LAST_ERROR=0

	# Drop the measurements table if it exists.
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo "db2 -x select tabname from syscat.tables where tabname = '$1' and type = 'T' and tabschema = '$DM_SCHEMA_NAME' "  >> $TMP_DDL_FILE_NAME
	ORIG_TABLE=$1
	G_LAST_ERROR=0
	else
	ORIG_TABLE=`db2 -x "select tabname from syscat.tables where tabname = '$1' and type = 'T' and tabschema = '$DM_SCHEMA_NAME'"`
	G_LAST_ERROR=$?
	fi
	
	if [ $G_LAST_ERROR != 0 -a $G_LAST_ERROR != 1 ]
	then
		echo "Failed to query system catalog for table: $1." >> $LOG_F_NAME
		return
	fi

    G_LAST_ERROR=0
	if [ ! -z $ORIG_TABLE ]
	then
		DTIE_DB2CMD="$DB2_CMD_DROP_TABLE $SPACE "$DM_SCHEMA_NAME"."$1""
		if [ $DBA_MODE == "DBAMODE" ]
			then 
			echo "$DB2 $DTIE_DB2CMD" >> $TMP_DDL_FILE_NAME
			G_LAST_ERROR=0
			else
			echo "Dropping Datamart table: " "$DM_SCHEMA_NAME"."$1" >> $LOG_F_NAME
			echo "Running:" $DTIE_DB2CMD >> $LOG_F_NAME
			$DB2 "$DTIE_DB2CMD" 2>&1 >> $LOG_F_NAME
			G_LAST_ERROR=$?
		fi
		if [ $G_LAST_ERROR != 0 ]
		then
			echo "Failed to drop Datamart table: $1." >> $LOG_F_NAME
			return
		fi
	fi
}

################################################################################
# Removes nickname corresponding to the argument.
# Arguments:
#   $1 (Mandatory)  :   TDW table name
#   $2 (Optional)   :   Context in which to create a nick name - useful when
#                       separate nicknames need to be created for the same TDW
#                       table.
################################################################################
delete_nickname()
{
    DN_CONTEXT=""
    if [ $# == 2 ]
    then
        DN_CONTEXT=_$2
    fi

    G_LAST_ERROR=0

    DEL_N_NICK_NAME="$NICK_NAME_PREFIX"_"$1""$DN_CONTEXT"
	drop_nickname_if_exists $DEL_N_NICK_NAME
    if [ $G_LAST_ERROR != 0 ]
    then
        return
    fi
}

################################################################################
# Removes view corresponding to a given argument.
################################################################################
delete_dm_view()
{
    G_LAST_ERROR=0

    CHANGE_FED_TABLE_SUFFIX=0
	DEL_V_VIEW_NAME=$1
    case $1 in
        SERVER_CPU)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	    DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_CPU
        ;;

        SERVER_CPU_*)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
		DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_CPU_AGG
        ;;

        SERVER_DISK)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	    DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_DISK
        ;;

        SERVER_DISK_*)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	    DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_DISK_AGG
        ;;

        SERVER_NETWORK)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
	    DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_NET
        ;;

        SERVER_NETWORK_*)

        CHANGE_FED_TABLE_SUFFIX=1
        FED_TABLE_NAME_SUFFIX=`echo $1 | awk '{ sub("SERVER", "PS");print}'`
		DEL_V_VIEW_NAME=$FED_TABLE_NAME_SUFFIX
        TABLE_BODY=$TABLE_BODY_SERVER_NET_AGG
        ;;

        VIRTUAL_MACHINES)

        FED_TABLE_NAME_SUFFIX=$1
	    DEL_V_VIEW_NAME=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("VIRTUAL_MACHINES", "VM_CPU");print}'`
        TABLE_BODY=$TABLE_BODY_VM
        ;;

		VIRTUAL_MACHINES_*)

        FED_TABLE_NAME_SUFFIX=$1
		DEL_V_VIEW_NAME=`echo $FED_TABLE_NAME_SUFFIX | awk '{ sub("VIRTUAL_MACHINES", "VM_CPU");print}'`
        TABLE_BODY=$TABLE_BODY_VM_AGG
        ;;

        *)
            # "Invalid argument:" $1
            $JAVA $CLASSNAME "ANA01002E"
            return
    esac

	drop_view_if_exists $DEL_V_VIEW_NAME
    if [ $G_LAST_ERROR != 0 ]
    then
        return
    fi

	if [ $VIEW_EXISTS -eq 1 ]
	then
		create_dm_table $DEL_V_VIEW_NAME "$TABLE_BODY"
        if [ $G_LAST_ERROR != 0 ]
        then
            return
        fi

		PERC_VIEW=""
		# Update Percentile views. 
		# As we are not supporting DB2 version 9.5 , DBA MODE case is not handled here
        if [ $DB2_VERSION = "v9.5" ]
        then
            if [ $1 == "VIRTUAL_MACHINES_H" ]
            then
                PERC_VIEW="$DM_SCHEMA_NAME"."$VIEW_PERC_CPU_H_V"
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" >> $LOG_F_NAME
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" > $TMP_F_NAME
            	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
				$DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME
                G_LAST_ERROR=$?
            elif [ $1 == "VM_MEMORY_H" ]
            then
                PERC_VIEW="$DM_SCHEMA_NAME"."$VIEW_PERC_MEM_H_V"
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" >> $LOG_F_NAME
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" > $TMP_F_NAME
            	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
				$DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME
                G_LAST_ERROR=$?
            elif [ $1 == "VM_NETWORK_H" ]
            then
                PERC_VIEW="$DM_SCHEMA_NAME"."$VIEW_PERC_NW_H_V"
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" >> $LOG_F_NAME
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" > $TMP_F_NAME
            	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
				$DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME
                G_LAST_ERROR=$?
            fi

		    if [ $G_LAST_ERROR != 0 -a $G_LAST_ERROR != 2 ]
		    then
                echo "Failed to re-create view: $PERC_VIEW" >> $LOG_F_NAME
			    return
		    fi
        fi
	fi
}

################################################################################
# Drops a given view if it exists.
################################################################################
drop_view_if_exists()
{
    G_LAST_ERROR=0
	DROP_V_VIEW_NAME="MES"_"$1"
	# Drop the view if it exists.
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo "db2 select tabname from syscat.tables where tabname = '$DROP_V_VIEW_NAME' and type = 'V' and tabschema = '$DM_SCHEMA_NAME'" >> $TMP_DDL_FILE_NAME
	E_VIEW=$DROP_V_VIEW_NAME
	G_LAST_ERROR=0
	else
	E_VIEW=`db2 -x "select tabname from syscat.tables where tabname = '$DROP_V_VIEW_NAME' and type = 'V' and tabschema = '$DM_SCHEMA_NAME'"`
    G_LAST_ERROR=$?
	fi
    if [ $G_LAST_ERROR != 0 -a $G_LAST_ERROR != 1 ]
    then
        echo "Failed to query system catalog for view name: $DROP_V_VIEW_NAME" >> $LOG_F_NAME
        return
    fi
	if [ ! -z $E_VIEW ]
	then
    	DVIE_DB2CMD="$DB2_CMD_DROP_VIEW $SPACE "$DM_VIEW_NAME_PREFIX"_"$1""
		if [ $DBA_MODE == "DBAMODE" ]
		then
			echo "$DB2 $DVIE_DB2CMD" >> $TMP_DDL_FILE_NAME
			G_LAST_ERROR=0
		else
    	echo "Dropping Datamart view if exists: " "$DM_VIEW_NAME_PREFIX"_"$1" >> $LOG_F_NAME
    	echo "Running: " $DVIE_DB2CMD >> $LOG_F_NAME
    	$DB2 "$DVIE_DB2CMD" 2>&1 >> $LOG_F_NAME
		G_LAST_ERROR=$?
		fi
		if [ $G_LAST_ERROR != 0 ]
		then
			echo "Failed to drop view: " "$DM_VIEW_NAME_PREFIX"_"$1" >> $LOG_F_NAME
			return
		fi
		VIEW_EXISTS=1
	else
        G_LAST_ERROR=0
    	echo "View:" "$DM_VIEW_NAME_PREFIX"_"$1" "does not exist." >> $LOG_F_NAME
		VIEW_EXISTS=0
	fi
}

################################################################################
# Creates a table once its view was dropped. Analytics reports need either the
# table of the view to work for each of the metrics tables.
################################################################################
create_dm_table()
{
   G_LAST_ERROR=0

	TABLE_NAME=$1
	TABLE_BODY=$2

	# Check if the table already exists.
	if [ $DBA_MODE == "DBAMODE" ]
	then
		echo "select tabname from syscat.tables where tabname = 'MES_$TABLE_NAME' and type = 'T' and tabschema = '$DM_SCHEMA_NAME'" >> $TMP_DDL_FILE_NAME
		G_LAST_ERROR=0
	else
	E_TABLE=`db2 -x "select tabname from syscat.tables where tabname = 'MES_$TABLE_NAME' and type = 'T' and tabschema = '$DM_SCHEMA_NAME'"`
    G_LAST_ERROR=$?
	fi
    if [ $G_LAST_ERROR != 0 -a $G_LAST_ERROR != 1 ]
    then
        echo "Failed to query system catalog for table name: $TABLE_NAME" >> $LOG_F_NAME
        return
    fi
	
	if [ -z "$E_TABLE" ]
	then
		
    	CDT_DB2CMD="$DB2_CMD_CREATE_TABLE $SPACE "$DM_SCHEMA_NAME"."MES_$TABLE_NAME" "$TABLE_BODY""
		if [ $DBA_MODE == "DBAMODE" ]
		then
		echo "$DB2 $CDT_DB2CMD" >> $TMP_DDL_FILE_NAME
		else
    	echo $CDT_DB2CMD > $TMP_F_NAME
    	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
		fi
    	run_command
	fi
}

################################################################################
# Drops a given nick name if it exists.
################################################################################
drop_nickname_if_exists()
{
    G_LAST_ERROR=0
	DN_NICK_NAME=`echo $1 | awk -v var="$DM_SCHEMA_NAME." '{ sub(var, "");print}'`
	DN_NICK_NAME=`echo "$DN_NICK_NAME" | tr '[a-z]' '[A-Z]'`
	# Drop the nick name if it exists.
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo "select tabname from syscat.tables where tabname = '$DN_NICK_NAME' and type = 'N' and tabschema = '$DM_SCHEMA_NAME'" $TMP_DDL_FILE_NAME
	E_NICK=$DN_NICK_NAME
	G_LAST_ERROR=0
	else
	E_NICK=`db2 -x "select tabname from syscat.tables where tabname = '$DN_NICK_NAME' and type = 'N' and tabschema = '$DM_SCHEMA_NAME'"`
	G_LAST_ERROR=$?
	fi
	if [ $G_LAST_ERROR != 0 -a $G_LAST_ERROR != 1 ]
	then
		echo "Failed to query system catalog for nick name: $DN_NICK_NAME." >> $LOG_F_NAME
		return
	fi

	if [ ! -z $E_NICK ]
	then
    	DNIE_DB2CMD="$DB2_CMD_DROP_NICKNAME $SPACE $1"
		if [ $DBA_MODE == "DBAMODE" ]
		then
		echo $DB2 "$DNIE_DB2CMD" >> $TMP_DDL_FILE_NAME
		G_LAST_ERROR=0
		else
		echo "Dropping nick name if exists: " $1 >> $LOG_F_NAME
    	echo $DNIE_DB2CMD >> $LOG_F_NAME
    	$DB2 "$DNIE_DB2CMD" 2>&1 >> $LOG_F_NAME
		G_LAST_ERROR=$?
		fi
		if [ $G_LAST_ERROR != 0 ]
		then
			echo "Failed to drop nick name: $1." >> $LOG_F_NAME
			return
		fi

	else
        G_LAST_ERROR=0
    	echo "Nick name:" "$1" "does not exist." >> $LOG_F_NAME
	fi
}

################################################################################
# Handles all the required processing.
################################################################################
process()
{
    G_LAST_ERROR=0
	if [ $COMMAND == "-add" ]
    then
        create_nickname $1
		if [ $G_LAST_ERROR != 0 ]
		then
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi
		
		create_dm_view $1 $2
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","$VIEW_NAME
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			echo "Failed to create a view  $VIEW_NAME" >> $LOG_F_NAME
			echo "................................................................................" >> $LOG_F_NAME
			return
			else
			SUCCESS_VIEW=$SUCCESS_VIEW","$VIEW_NAME
			if [ $DBA_MODE != "DBAMODE" ]
			then
			echo "View $VIEW_NAME created successfully " >> $LOG_F_NAME 
			fi	
		fi

		PERC_VIEW=""
		# Update Percentile views.
		# As we are not supporting DB2 9.5 the DBA_MODE implementation is not done for this part
        if [ $DB2_VERSION = "v9.5" ]
        then
            if [ $2 == "VIRTUAL_MACHINES_H" ]
            then
                PERC_VIEW="$DM_SCHEMA_NAME"."$VIEW_PERC_CPU_H_V"
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" >> $LOG_F_NAME
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" > $TMP_F_NAME
            	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
				$DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME
                G_LAST_ERROR=$?
            elif [ $2 == "VM_MEMORY_H" ]
            then
                PERC_VIEW="$DM_SCHEMA_NAME"."$VIEW_PERC_MEM_H_V"
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" >> $LOG_F_NAME
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" > $TMP_F_NAME
            	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
				$DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME
                G_LAST_ERROR=$?
            elif [ $2 == "VM_NETWORK_H" ]
            then
                PERC_VIEW="$DM_SCHEMA_NAME"."$VIEW_PERC_NW_H_V"
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" >> $LOG_F_NAME
            	echo "$DB2_CMD_CREATE_VIEW $SPACE $PERC_VIEW" > $TMP_F_NAME
            	echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
				$DB2 -td@ -sf $TMP_F_NAME 2>&1 >> $LOG_F_NAME
                G_LAST_ERROR=$?
            fi

		    if [ $G_LAST_ERROR != 0 -a $G_LAST_ERROR != 2 ]
		    then
                echo "Failed to re-create view: $PERC_VIEW" >> $LOG_F_NAME
			    return
		    fi
        fi

    elif [ $COMMAND == "-delete" ]
    then
        delete_dm_view $2
		if [ $G_LAST_ERROR != 0 ]
		then
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        if [ $VIEW_EXISTS -eq 1 ]
	    then
            delete_nickname $1
		    if [ $G_LAST_ERROR != 0 ]
		    then
		    	G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

        fi

    fi
    if [ $DBA_MODE != "DBAMODE" ]
	then
    echo "................................................................................" >> $LOG_F_NAME
    fi
}

################################################################################
# Removes view MES_PS_MEM_*
################################################################################
PS_MEM_delete_dm_view()
{
    G_LAST_ERROR=0

    PMDM_SUMM_L=$1
    TABLE_BODY=$TABLE_BODY_SERVER_MEM

    if [ ! -z $PMDM_SUMM_L ]
    then
        TABLE_BODY=$TABLE_BODY_SERVER_MEM_AGG
    fi


	drop_view_if_exists "PS_MEM""$PMDM_SUMM_L"
    if [ $G_LAST_ERROR != 0 ]
    then
        return
    fi

	if [ $VIEW_EXISTS -eq 1 ]
	then
		create_dm_table "PS_MEM""$PMDM_SUMM_L" "$TABLE_BODY"
        if [ $G_LAST_ERROR != 0 ]
        then
            return
        fi
	fi
}

################################################################################
# Creates Datamart view: MES_PS_MEM*
# Arguments:
#   $1 (Mandatory)  :   Summarization level
################################################################################
PS_MEM_create_dm_view()
{
    G_LAST_ERROR=0
    CDM_DB2CMD=""

    PM_CDM_SUMM_L=$1
	drop_table_if_exists "MES_PS_MEM""$PM_CDM_SUMM_L"
	if [ $G_LAST_ERROR != 0 ]
	then
		return
	fi

	if [ $DB2_VERSION = "v9.5" ]
	then
		drop_view_if_exists "PS_MEM""$PM_CDM_SUMM_L"
		if [ $G_LAST_ERROR != 0 ]
		then
			return
		fi
	fi

    PS_MEM_VIEW_DEF="(HOST_NAME, PHYSICAL_MEMORY, MEMORY_USAGE, MEMORY_UTILIZATION, ACTIVE_MEMORY, GRANTED_MEMORY, SWAP_USED, FREE_MEM, BALLOON_USED, SWAP_IN_RATE, SWAP_OUT_RATE, SWAP_TOTAL_RATE, TIMESTAMP, WRITETIME) AS ( SELECT X.HOST_NAME, X.PHYSICAL_MEMORY, X.MEMORY_USAGE, (X.MEMORY_UTILIZATION + Z.MEMORY_UTILIZATION), X.ACTIVE_MEMORY, X.GRANTED_MEMORY, X.SWAP_USED, X.FREE_MEM, X.BALLOON_USED, X.SWAP_IN_RATE, X.SWAP_OUT_RATE, X.SWAP_TOTAL_RATE, X.TIMESTAMP, X.WRITETIME FROM (SELECT Q."$QC"CEC_name"$QC" AS HOST_NAME, -1 AS PHYSICAL_MEMORY, -1 AS MEMORY_USAGE, P."$QC"USED_MEMORY_MB"$QC" AS MEMORY_UTILIZATION, -1 AS ACTIVE_MEMORY, -1 AS GRANTED_MEMORY, -1 AS SWAP_USED, -1 AS FREE_MEM, -1 AS BALLOON_USED, -1 AS SWAP_IN_RATE, -1 AS SWAP_OUT_RATE, -1 AS SWAP_TOTAL_RATE, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" AS WRITETIME FROM (SELECT "$QC"System_Name"$QC", "$QC"WRITETIME"$QC", SUM("$QC"Used_Real_Mem_MB"$QC") AS USED_MEMORY_MB FROM FED_Unix_Memory"$PM_CDM_SUMM_L""_PS_MEM" GROUP BY "$QC"System_Name"$QC", "$QC"WRITETIME"$QC") P INNER JOIN (SELECT MI."$QC"System_Name"$QC", MI."$QC"WRITETIME"$QC", KSL."$QC"CEC_name"$QC" FROM FED_Machine_Information"$PM_CDM_SUMM_L""_PS_MEM" MI, FED_KPH_SERVER_LPARS"$PM_CDM_SUMM_L""_PS_MEM" KSL WHERE MI."$QC"Hardware_Model"$QC" = KSL."$QC"CEC_Model"$QC" AND SUBSTR(MI."$QC"Machine_Serial"$QC", 7) = KSL."$QC"CEC_SN"$QC" AND MI."$QC"WRITETIME"$QC" = KSL."$QC"WRITETIME"$QC") Q ON P."$QC"System_Name"$QC" = Q."$QC"System_Name"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC") X, (SELECT Q."$QC"CEC_name"$QC" AS HOST_NAME, -1 AS PHYSICAL_MEMORY, -1 AS MEMORY_USAGE, P."$QC"USED_MEMORY_MB"$QC" AS MEMORY_UTILIZATION, -1 AS ACTIVE_MEMORY, -1 AS GRANTED_MEMORY, -1 AS SWAP_USED, -1 AS FREE_MEM, -1 AS BALLOON_USED, -1 AS SWAP_IN_RATE, -1 AS SWAP_OUT_RATE, -1 AS SWAP_TOTAL_RATE, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" AS WRITETIME FROM (SELECT "$QC"Node"$QC", "$QC"WRITETIME"$QC", "$QC"Used_Memory_MB"$QC" AS USED_MEMORY_MB FROM FED_KVA_PHYSICAL_MEMORY"$PM_CDM_SUMM_L""_PS_MEM") P INNER JOIN (SELECT KSL."$QC"CEC_name"$QC", KT."$QC"Node"$QC", KT."$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$PM_CDM_SUMM_L""_PS_MEM" KSL, FED_KVA_TADDM"$PM_CDM_SUMM_L""_PS_MEM" KT WHERE KSL."$QC"CEC_Model"$QC" = KT."$QC"CEC_Model"$QC" AND KSL."$QC"CEC_SN"$QC" = KT."$QC"CEC_SN"$QC") Q ON P."$QC"Node"$QC" = Q."$QC"Node"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC") Z WHERE X."$QC"WRITETIME"$QC" = Z."$QC"WRITETIME"$QC")"

    PS_MEM_VIEW_DEF_AGG="(HOST_NAME, PHYSICAL_MEMORY, MIN_MEMORY_USAGE, MAX_MEMORY_USAGE, AVG_MEMORY_USAGE, SUM_MEMORY_USAGE, MIN_MEMORY_UTILIZATION, MAX_MEMORY_UTILIZATION, AVG_MEMORY_UTILIZATION, SUM_MEMORY_UTILIZATION, MIN_ACTIVE_MEMORY, MAX_ACTIVE_MEMORY, SUM_ACTIVE_MEMORY, AVG_ACTIVE_MEMORY, MIN_GRANTED_MEMORY, MAX_GRANTED_MEMORY, AVG_GRANTED_MEMORY, SUM_GRANTED_MEMORY, MIN_SWAP_USED, MAX_SWAP_USED, AVG_SWAP_USED, SUM_SWAP_USED, MIN_FREE_MEM, MAX_FREE_MEM, SUM_FREE_MEM, AVG_FREE_MEM, MIN_BALLOON_USED, MAX_BALLOON_USED, AVG_BALLOON_USED, SUM_BALLOON_USED, MIN_SWAP_IN_RATE, MAX_SWAP_IN_RATE, AVG_SWAP_IN_RATE, SUM_SWAP_IN_RATE, MIN_SWAP_OUT_RATE, MAX_SWAP_OUT_RATE, AVG_SWAP_OUT_RATE, SUM_SWAP_OUT_RATE, MIN_SWAP_TOTAL_RATE, MAX_SWAP_TOTAL_RATE, AVG_SWAP_TOTAL_RATE, SUM_SWAP_TOTAL_RATE, TIMESTAMP, WRITETIME) AS (SELECT X.HOST_NAME, X.PHYSICAL_MEMORY, X.MIN_MEMORY_USAGE, X.MAX_MEMORY_USAGE, X.AVG_MEMORY_USAGE, X.SUM_MEMORY_USAGE, (X.MIN_MEMORY_UTILIZATION + Z.MIN_MEMORY_UTILIZATION), (X.MAX_MEMORY_UTILIZATION + Z.MAX_MEMORY_UTILIZATION), (X.AVG_MEMORY_UTILIZATION + Z.AVG_MEMORY_UTILIZATION), (X.SUM_MEMORY_UTILIZATION + Z.SUM_MEMORY_UTILIZATION), X.MIN_ACTIVE_MEMORY,  X.MAX_ACTIVE_MEMORY,  X.AVG_ACTIVE_MEMORY,  X.SUM_ACTIVE_MEMORY, X.MIN_GRANTED_MEMORY, X.MAX_GRANTED_MEMORY, X.AVG_GRANTED_MEMORY, X.SUM_GRANTED_MEMORY, X.MIN_SWAP_USED, X.MAX_SWAP_USED, X.AVG_SWAP_USED, X.SUM_SWAP_USED, X.MIN_FREE_MEM, X.MAX_FREE_MEM, X.AVG_FREE_MEM, X.SUM_FREE_MEM, X.MIN_BALLOON_USED, X.MAX_BALLOON_USED, X.AVG_BALLOON_USED, X.SUM_BALLOON_USED, X.MIN_SWAP_IN_RATE, X.MAX_SWAP_IN_RATE, X.AVG_SWAP_IN_RATE, X.SUM_SWAP_IN_RATE, X.MIN_SWAP_OUT_RATE, X.MAX_SWAP_OUT_RATE, X.AVG_SWAP_OUT_RATE, X.SUM_SWAP_OUT_RATE, X.MIN_SWAP_TOTAL_RATE, X.MAX_SWAP_TOTAL_RATE, X.AVG_SWAP_TOTAL_RATE, X.SUM_SWAP_TOTAL_RATE, X.TIMESTAMP, X.WRITETIME FROM (SELECT Q."$QC"LAT_CEC_name"$QC" AS HOST_NAME, -1 AS PHYSICAL_MEMORY, -1 AS MIN_MEMORY_USAGE, -1 AS MAX_MEMORY_USAGE, -1 AS AVG_MEMORY_USAGE, -1 AS SUM_MEMORY_USAGE, P."$QC"MIN_USED_MEMORY_MB"$QC" AS MIN_MEMORY_UTILIZATION, P."$QC"MAX_USED_MEMORY_MB"$QC" AS MAX_MEMORY_UTILIZATION, P."$QC"AVG_USED_MEMORY_MB"$QC" AS AVG_MEMORY_UTILIZATION, P."$QC"SUM_USED_MEMORY_MB"$QC" AS SUM_MEMORY_UTILIZATION, -1 AS MIN_ACTIVE_MEMORY, -1 AS MAX_ACTIVE_MEMORY, -1 AS AVG_ACTIVE_MEMORY, -1 AS SUM_ACTIVE_MEMORY, -1 AS MIN_GRANTED_MEMORY, -1 AS MAX_GRANTED_MEMORY, -1 AS AVG_GRANTED_MEMORY, -1 AS SUM_GRANTED_MEMORY, -1 AS MIN_SWAP_USED, -1 AS MAX_SWAP_USED, -1 AS AVG_SWAP_USED, -1 AS SUM_SWAP_USED, -1 AS MIN_FREE_MEM, -1 AS MAX_FREE_MEM, -1 AS AVG_FREE_MEM, -1 AS SUM_FREE_MEM, -1 AS MIN_BALLOON_USED, -1 AS MAX_BALLOON_USED, -1 AS AVG_BALLOON_USED, -1 AS SUM_BALLOON_USED, -1 AS MIN_SWAP_IN_RATE, -1 AS MAX_SWAP_IN_RATE, -1 AS AVG_SWAP_IN_RATE, -1 AS SUM_SWAP_IN_RATE, -1 AS MIN_SWAP_OUT_RATE, -1 AS MAX_SWAP_OUT_RATE, -1 AS AVG_SWAP_OUT_RATE, -1 AS SUM_SWAP_OUT_RATE, -1 AS MIN_SWAP_TOTAL_RATE, -1 AS MAX_SWAP_TOTAL_RATE, -1 AS AVG_SWAP_TOTAL_RATE, -1 AS SUM_SWAP_TOTAL_RATE, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" AS WRITETIME FROM (SELECT "$QC"System_Name"$QC", "$QC"WRITETIME"$QC", SUM("$QC"MIN_Used_Real_Mem_MB"$QC") AS MIN_USED_MEMORY_MB, SUM("$QC"MAX_Used_Real_Mem_MB"$QC") AS MAX_USED_MEMORY_MB, SUM("$QC"AVG_Used_Real_Mem_MB"$QC") AS AVG_USED_MEMORY_MB, SUM("$QC"SUM_Used_Real_Mem_MB"$QC") AS SUM_USED_MEMORY_MB FROM FED_Unix_Memory"$PM_CDM_SUMM_L""_PS_MEM" GROUP BY "$QC"System_Name"$QC", "$QC"WRITETIME"$QC") P INNER JOIN (SELECT MI."$QC"System_Name"$QC", MI."$QC"WRITETIME"$QC", KSL."$QC"LAT_CEC_name"$QC" FROM FED_Machine_Information"$PM_CDM_SUMM_L""_PS_MEM" MI, FED_KPH_SERVER_LPARS"$PM_CDM_SUMM_L""_PS_MEM" KSL WHERE MI."$QC"LAT_Hardware_Model"$QC" = KSL."$QC"CEC_Model"$QC" AND SUBSTR(MI."$QC"LAT_Machine_Serial"$QC", 7) = KSL."$QC"CEC_SN"$QC" AND MI."$QC"WRITETIME"$QC" = KSL."$QC"WRITETIME"$QC") Q ON P."$QC"System_Name"$QC" = Q."$QC"System_Name"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC") X, (SELECT Q."$QC"LAT_CEC_name"$QC" AS HOST_NAME, -1 AS PHYSICAL_MEMORY, -1 AS MIN_MEMORY_USAGE, -1 AS MAX_MEMORY_USAGE, -1 AS AVG_MEMORY_USAGE, -1 AS SUM_MEMORY_USAGE, P."$QC"MIN_USED_MEMORY_MB"$QC" AS MIN_MEMORY_UTILIZATION, P."$QC"MAX_USED_MEMORY_MB"$QC" AS MAX_MEMORY_UTILIZATION, P."$QC"AVG_USED_MEMORY_MB"$QC" AS AVG_MEMORY_UTILIZATION, P."$QC"SUM_USED_MEMORY_MB"$QC" AS SUM_MEMORY_UTILIZATION, -1 AS MIN_ACTIVE_MEMORY, -1 AS MAX_ACTIVE_MEMORY, -1 AS AVG_ACTIVE_MEMORY, -1 AS SUM_ACTIVE_MEMORY, -1 AS MIN_GRANTED_MEMORY, -1 AS MAX_GRANTED_MEMORY, -1 AS AVG_GRANTED_MEMORY, -1 AS SUM_GRANTED_MEMORY, -1 AS MIN_SWAP_USED, -1 AS MAX_SWAP_USED, -1 AS AVG_SWAP_USED, -1 AS SUM_SWAP_USED, -1 AS MIN_FREE_MEM, -1 AS MAX_FREE_MEM, -1 AS AVG_FREE_MEM, -1 AS SUM_FREE_MEM, -1 AS MIN_BALLOON_USED, -1 AS MAX_BALLOON_USED, -1 AS AVG_BALLOON_USED, -1 AS SUM_BALLOON_USED, -1 AS MIN_SWAP_IN_RATE, -1 AS MAX_SWAP_IN_RATE, -1 AS AVG_SWAP_IN_RATE, -1 AS SUM_SWAP_IN_RATE, -1 AS MIN_SWAP_OUT_RATE, -1 AS MAX_SWAP_OUT_RATE, -1 AS AVG_SWAP_OUT_RATE, -1 AS SUM_SWAP_OUT_RATE, -1 AS MIN_SWAP_TOTAL_RATE, -1 AS MAX_SWAP_TOTAL_RATE, -1 AS AVG_SWAP_TOTAL_RATE, -1 AS SUM_SWAP_TOTAL_RATE, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" AS WRITETIME FROM (SELECT "$QC"Node"$QC", "$QC"WRITETIME"$QC", "$QC"MIN_Used_Memory_MB"$QC" AS MIN_USED_MEMORY_MB, "$QC"MAX_Used_Memory_MB"$QC" AS MAX_USED_MEMORY_MB, "$QC"AVG_Used_Memory_MB"$QC" AS AVG_USED_MEMORY_MB, "$QC"SUM_Used_Memory_MB"$QC" AS SUM_USED_MEMORY_MB FROM FED_KVA_PHYSICAL_MEMORY"$PM_CDM_SUMM_L""_PS_MEM") P INNER JOIN (SELECT KSL."$QC"LAT_CEC_name"$QC", KT."$QC"Node"$QC", KT."$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$PM_CDM_SUMM_L""_PS_MEM" KSL, FED_KVA_TADDM"$PM_CDM_SUMM_L""_PS_MEM" KT WHERE KSL."$QC"CEC_Model"$QC" = KT."$QC"LAT_CEC_Model"$QC" AND KSL."$QC"CEC_SN"$QC" = KT."$QC"LAT_CEC_SN"$QC") Q ON P."$QC"Node"$QC" = Q."$QC"Node"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC") Z WHERE X."$QC"WRITETIME"$QC" = Z."$QC"WRITETIME"$QC")"

    if [ ! -z "$LINUX_ENV" ]
    then
        PS_MEM_VIEW_DEF="(HOST_NAME, PHYSICAL_MEMORY, MEMORY_USAGE, MEMORY_UTILIZATION, ACTIVE_MEMORY, GRANTED_MEMORY, SWAP_USED, FREE_MEM, BALLOON_USED, SWAP_IN_RATE, SWAP_OUT_RATE, SWAP_TOTAL_RATE, TIMESTAMP, WRITETIME) AS ( SELECT X.HOST_NAME, X.PHYSICAL_MEMORY, X.MEMORY_USAGE, (X.MEMORY_UTILIZATION + Y.MEMORY_UTILIZATION + Z.MEMORY_UTILIZATION), X.ACTIVE_MEMORY, X.GRANTED_MEMORY, X.SWAP_USED, X.FREE_MEM, X.BALLOON_USED, X.SWAP_IN_RATE, X.SWAP_OUT_RATE, X.SWAP_TOTAL_RATE, X.TIMESTAMP, X.WRITETIME FROM (SELECT Q."$QC"CEC_name"$QC" AS HOST_NAME, -1 AS PHYSICAL_MEMORY, -1 AS MEMORY_USAGE, P."$QC"USED_MEMORY_MB"$QC" AS MEMORY_UTILIZATION, -1 AS ACTIVE_MEMORY, -1 AS GRANTED_MEMORY, -1 AS SWAP_USED, -1 AS FREE_MEM, -1 AS BALLOON_USED, -1 AS SWAP_IN_RATE, -1 AS SWAP_OUT_RATE, -1 AS SWAP_TOTAL_RATE, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" AS WRITETIME FROM (SELECT "$QC"System_Name"$QC", "$QC"WRITETIME"$QC", SUM("$QC"Used_Real_Mem_MB"$QC") AS USED_MEMORY_MB FROM FED_Unix_Memory"$PM_CDM_SUMM_L""_PS_MEM" GROUP BY "$QC"System_Name"$QC", "$QC"WRITETIME"$QC") P INNER JOIN (SELECT MI."$QC"System_Name"$QC", MI."$QC"WRITETIME"$QC", KSL."$QC"CEC_name"$QC" FROM FED_Machine_Information"$PM_CDM_SUMM_L""_PS_MEM" MI, FED_KPH_SERVER_LPARS"$PM_CDM_SUMM_L""_PS_MEM" KSL WHERE MI."$QC"Hardware_Model"$QC" = KSL."$QC"CEC_Model"$QC" AND SUBSTR(MI."$QC"Machine_Serial"$QC", 7) = KSL."$QC"CEC_SN"$QC" AND MI."$QC"WRITETIME"$QC" = KSL."$QC"WRITETIME"$QC") Q ON P."$QC"System_Name"$QC" = Q."$QC"System_Name"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC") X, (SELECT Q."$QC"CEC_name"$QC" AS HOST_NAME, -1 AS PHYSICAL_MEMORY, -1 AS MEMORY_USAGE, P."$QC"USED_MEMORY_MB"$QC" AS MEMORY_UTILIZATION, -1 AS ACTIVE_MEMORY, -1 AS GRANTED_MEMORY, -1 AS SWAP_USED, -1 AS FREE_MEM, -1 AS BALLOON_USED, -1 AS SWAP_IN_RATE, -1 AS SWAP_OUT_RATE, -1 AS SWAP_TOTAL_RATE, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" AS WRITETIME FROM (SELECT "$QC"System_Name"$QC", "$QC"WRITETIME"$QC", SUM("$QC"Memory_Used"$QC") AS USED_MEMORY_MB FROM FED_KLZ_VM_Stats"$PM_CDM_SUMM_L""_PS_MEM" GROUP BY "$QC"System_Name"$QC", "$QC"WRITETIME"$QC") P INNER JOIN (SELECT LMI."$QC"System_Name"$QC", LMI."$QC"WRITETIME"$QC", KSL."$QC"CEC_name"$QC" FROM FED_Linux_Machine_Information"$PM_CDM_SUMM_L""_PS_MEM" LMI, FED_KPH_SERVER_LPARS"$PM_CDM_SUMM_L""_PS_MEM" KSL WHERE LMI."$QC"Hardware_Model"$QC" = KSL."$QC"CEC_Model"$QC" AND LMI."$QC"Machine_Serial"$QC" = KSL."$QC"CEC_SN"$QC" AND LMI."$QC"WRITETIME"$QC" = KSL."$QC"WRITETIME"$QC") Q ON P."$QC"System_Name"$QC" = Q."$QC"System_Name"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC") Y, (SELECT Q."$QC"CEC_name"$QC" AS HOST_NAME, -1 AS PHYSICAL_MEMORY, -1 AS MEMORY_USAGE, P."$QC"USED_MEMORY_MB"$QC" AS MEMORY_UTILIZATION, -1 AS ACTIVE_MEMORY, -1 AS GRANTED_MEMORY, -1 AS SWAP_USED, -1 AS FREE_MEM, -1 AS BALLOON_USED, -1 AS SWAP_IN_RATE, -1 AS SWAP_OUT_RATE, -1 AS SWAP_TOTAL_RATE, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" AS WRITETIME FROM (SELECT "$QC"Node"$QC", "$QC"WRITETIME"$QC", "$QC"Used_Memory_MB"$QC" AS USED_MEMORY_MB FROM FED_KVA_PHYSICAL_MEMORY"$PM_CDM_SUMM_L""_PS_MEM") P INNER JOIN (SELECT KSL."$QC"CEC_name"$QC", KT."$QC"Node"$QC", KT."$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$PM_CDM_SUMM_L""_PS_MEM" KSL, FED_KVA_TADDM"$PM_CDM_SUMM_L""_PS_MEM" KT WHERE KSL."$QC"CEC_Model"$QC" = KT."$QC"CEC_Model"$QC" AND KSL."$QC"CEC_SN"$QC" = KT."$QC"CEC_SN"$QC") Q ON P."$QC"Node"$QC" = Q."$QC"Node"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC") Z WHERE X."$QC"WRITETIME"$QC" = Y."$QC"WRITETIME"$QC" AND Y."$QC"WRITETIME"$QC" = Z."$QC"WRITETIME"$QC")"
    PS_MEM_VIEW_DEF_AGG="(HOST_NAME, PHYSICAL_MEMORY, MIN_MEMORY_USAGE, MAX_MEMORY_USAGE, AVG_MEMORY_USAGE, SUM_MEMORY_USAGE, MIN_MEMORY_UTILIZATION, MAX_MEMORY_UTILIZATION, AVG_MEMORY_UTILIZATION, SUM_MEMORY_UTILIZATION, MIN_ACTIVE_MEMORY, MAX_ACTIVE_MEMORY, SUM_ACTIVE_MEMORY, AVG_ACTIVE_MEMORY, MIN_GRANTED_MEMORY, MAX_GRANTED_MEMORY, AVG_GRANTED_MEMORY, SUM_GRANTED_MEMORY, MIN_SWAP_USED, MAX_SWAP_USED, AVG_SWAP_USED, SUM_SWAP_USED, MIN_FREE_MEM, MAX_FREE_MEM, SUM_FREE_MEM, AVG_FREE_MEM, MIN_BALLOON_USED, MAX_BALLOON_USED, AVG_BALLOON_USED, SUM_BALLOON_USED, MIN_SWAP_IN_RATE, MAX_SWAP_IN_RATE, AVG_SWAP_IN_RATE, SUM_SWAP_IN_RATE, MIN_SWAP_OUT_RATE, MAX_SWAP_OUT_RATE, AVG_SWAP_OUT_RATE, SUM_SWAP_OUT_RATE, MIN_SWAP_TOTAL_RATE, MAX_SWAP_TOTAL_RATE, AVG_SWAP_TOTAL_RATE, SUM_SWAP_TOTAL_RATE, TIMESTAMP, WRITETIME) AS (SELECT X.HOST_NAME, X.PHYSICAL_MEMORY, X.MIN_MEMORY_USAGE, X.MAX_MEMORY_USAGE, X.AVG_MEMORY_USAGE, X.SUM_MEMORY_USAGE, (X.MIN_MEMORY_UTILIZATION + Y.MIN_MEMORY_UTILIZATION + Z.MIN_MEMORY_UTILIZATION), (X.MAX_MEMORY_UTILIZATION + Y.MAX_MEMORY_UTILIZATION + Z.MAX_MEMORY_UTILIZATION), (X.AVG_MEMORY_UTILIZATION + Y.AVG_MEMORY_UTILIZATION + Z.AVG_MEMORY_UTILIZATION), (X.SUM_MEMORY_UTILIZATION + Y.SUM_MEMORY_UTILIZATION + Z.SUM_MEMORY_UTILIZATION), X.MIN_ACTIVE_MEMORY,  X.MAX_ACTIVE_MEMORY,  X.AVG_ACTIVE_MEMORY,  X.SUM_ACTIVE_MEMORY, X.MIN_GRANTED_MEMORY, X.MAX_GRANTED_MEMORY, X.AVG_GRANTED_MEMORY, X.SUM_GRANTED_MEMORY, X.MIN_SWAP_USED, X.MAX_SWAP_USED, X.AVG_SWAP_USED, X.SUM_SWAP_USED, X.MIN_FREE_MEM, X.MAX_FREE_MEM, X.AVG_FREE_MEM, X.SUM_FREE_MEM, X.MIN_BALLOON_USED, X.MAX_BALLOON_USED, X.AVG_BALLOON_USED, X.SUM_BALLOON_USED, X.MIN_SWAP_IN_RATE, X.MAX_SWAP_IN_RATE, X.AVG_SWAP_IN_RATE, X.SUM_SWAP_IN_RATE, X.MIN_SWAP_OUT_RATE, X.MAX_SWAP_OUT_RATE, X.AVG_SWAP_OUT_RATE, X.SUM_SWAP_OUT_RATE, X.MIN_SWAP_TOTAL_RATE, X.MAX_SWAP_TOTAL_RATE, X.AVG_SWAP_TOTAL_RATE, X.SUM_SWAP_TOTAL_RATE, X.TIMESTAMP, X.WRITETIME FROM (SELECT Q."$QC"LAT_CEC_name"$QC" AS HOST_NAME, -1 AS PHYSICAL_MEMORY, -1 AS MIN_MEMORY_USAGE, -1 AS MAX_MEMORY_USAGE, -1 AS AVG_MEMORY_USAGE, -1 AS SUM_MEMORY_USAGE, P."$QC"MIN_USED_MEMORY_MB"$QC" AS MIN_MEMORY_UTILIZATION, P."$QC"MAX_USED_MEMORY_MB"$QC" AS MAX_MEMORY_UTILIZATION, P."$QC"AVG_USED_MEMORY_MB"$QC" AS AVG_MEMORY_UTILIZATION, P."$QC"SUM_USED_MEMORY_MB"$QC" AS SUM_MEMORY_UTILIZATION, -1 AS MIN_ACTIVE_MEMORY, -1 AS MAX_ACTIVE_MEMORY, -1 AS AVG_ACTIVE_MEMORY, -1 AS SUM_ACTIVE_MEMORY, -1 AS MIN_GRANTED_MEMORY, -1 AS MAX_GRANTED_MEMORY, -1 AS AVG_GRANTED_MEMORY, -1 AS SUM_GRANTED_MEMORY, -1 AS MIN_SWAP_USED, -1 AS MAX_SWAP_USED, -1 AS AVG_SWAP_USED, -1 AS SUM_SWAP_USED, -1 AS MIN_FREE_MEM, -1 AS MAX_FREE_MEM, -1 AS AVG_FREE_MEM, -1 AS SUM_FREE_MEM, -1 AS MIN_BALLOON_USED, -1 AS MAX_BALLOON_USED, -1 AS AVG_BALLOON_USED, -1 AS SUM_BALLOON_USED, -1 AS MIN_SWAP_IN_RATE, -1 AS MAX_SWAP_IN_RATE, -1 AS AVG_SWAP_IN_RATE, -1 AS SUM_SWAP_IN_RATE, -1 AS MIN_SWAP_OUT_RATE, -1 AS MAX_SWAP_OUT_RATE, -1 AS AVG_SWAP_OUT_RATE, -1 AS SUM_SWAP_OUT_RATE, -1 AS MIN_SWAP_TOTAL_RATE, -1 AS MAX_SWAP_TOTAL_RATE, -1 AS AVG_SWAP_TOTAL_RATE, -1 AS SUM_SWAP_TOTAL_RATE, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" AS WRITETIME FROM (SELECT "$QC"System_Name"$QC", "$QC"WRITETIME"$QC", SUM("$QC"MIN_Used_Real_Mem_MB"$QC") AS MIN_USED_MEMORY_MB, SUM("$QC"MAX_Used_Real_Mem_MB"$QC") AS MAX_USED_MEMORY_MB, SUM("$QC"AVG_Used_Real_Mem_MB"$QC") AS AVG_USED_MEMORY_MB, SUM("$QC"SUM_Used_Real_Mem_MB"$QC") AS SUM_USED_MEMORY_MB FROM FED_Unix_Memory"$PM_CDM_SUMM_L""_PS_MEM" GROUP BY "$QC"System_Name"$QC", "$QC"WRITETIME"$QC") P INNER JOIN (SELECT MI."$QC"System_Name"$QC", MI."$QC"WRITETIME"$QC", KSL."$QC"LAT_CEC_name"$QC" FROM FED_Machine_Information"$PM_CDM_SUMM_L""_PS_MEM" MI, FED_KPH_SERVER_LPARS"$PM_CDM_SUMM_L""_PS_MEM" KSL WHERE MI."$QC"LAT_Hardware_Model"$QC" = KSL."$QC"CEC_Model"$QC" AND SUBSTR(MI."$QC"LAT_Machine_Serial"$QC", 7) = KSL."$QC"CEC_SN"$QC" AND MI."$QC"WRITETIME"$QC" = KSL."$QC"WRITETIME"$QC") Q ON P."$QC"System_Name"$QC" = Q."$QC"System_Name"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC") X, (SELECT Q."$QC"LAT_CEC_name"$QC" AS HOST_NAME, -1 AS PHYSICAL_MEMORY, -1 AS MIN_MEMORY_USAGE, -1 AS MAX_MEMORY_USAGE, -1 AS AVG_MEMORY_USAGE, -1 AS SUM_MEMORY_USAGE, P."$QC"MIN_USED_MEMORY_MB"$QC" AS MIN_MEMORY_UTILIZATION, P."$QC"MAX_USED_MEMORY_MB"$QC" AS MAX_MEMORY_UTILIZATION, P."$QC"AVG_USED_MEMORY_MB"$QC" AS AVG_MEMORY_UTILIZATION, P."$QC"SUM_USED_MEMORY_MB"$QC" AS SUM_MEMORY_UTILIZATION, -1 AS MIN_ACTIVE_MEMORY, -1 AS MAX_ACTIVE_MEMORY, -1 AS AVG_ACTIVE_MEMORY, -1 AS SUM_ACTIVE_MEMORY, -1 AS MIN_GRANTED_MEMORY, -1 AS MAX_GRANTED_MEMORY, -1 AS AVG_GRANTED_MEMORY, -1 AS SUM_GRANTED_MEMORY, -1 AS MIN_SWAP_USED, -1 AS MAX_SWAP_USED, -1 AS AVG_SWAP_USED, -1 AS SUM_SWAP_USED, -1 AS MIN_FREE_MEM, -1 AS MAX_FREE_MEM, -1 AS AVG_FREE_MEM, -1 AS SUM_FREE_MEM, -1 AS MIN_BALLOON_USED, -1 AS MAX_BALLOON_USED, -1 AS AVG_BALLOON_USED, -1 AS SUM_BALLOON_USED, -1 AS MIN_SWAP_IN_RATE, -1 AS MAX_SWAP_IN_RATE, -1 AS AVG_SWAP_IN_RATE, -1 AS SUM_SWAP_IN_RATE, -1 AS MIN_SWAP_OUT_RATE, -1 AS MAX_SWAP_OUT_RATE, -1 AS AVG_SWAP_OUT_RATE, -1 AS SUM_SWAP_OUT_RATE, -1 AS MIN_SWAP_TOTAL_RATE, -1 AS MAX_SWAP_TOTAL_RATE, -1 AS AVG_SWAP_TOTAL_RATE, -1 AS SUM_SWAP_TOTAL_RATE, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" AS WRITETIME FROM (SELECT "$QC"System_Name"$QC", "$QC"WRITETIME"$QC", SUM("$QC"MIN_Memory_Used"$QC") AS MIN_USED_MEMORY_MB, SUM("$QC"MAX_Memory_Used"$QC") AS MAX_USED_MEMORY_MB, SUM("$QC"AVG_Memory_Used"$QC") AS AVG_USED_MEMORY_MB, SUM("$QC"SUM_Memory_Used"$QC") AS SUM_USED_MEMORY_MB FROM FED_KLZ_VM_Stats"$PM_CDM_SUMM_L""_PS_MEM" GROUP BY "$QC"System_Name"$QC", "$QC"WRITETIME"$QC") P INNER JOIN (SELECT LMI."$QC"System_Name"$QC", LMI."$QC"WRITETIME"$QC", KSL."$QC"LAT_CEC_name"$QC" FROM FED_Linux_Machine_Information"$PM_CDM_SUMM_L""_PS_MEM" LMI, FED_KPH_SERVER_LPARS"$PM_CDM_SUMM_L""_PS_MEM" KSL WHERE LMI."$QC"LAT_Hardware_Model"$QC" = KSL."$QC"CEC_Model"$QC" AND LMI."$QC"LAT_Machine_Serial"$QC" = KSL."$QC"CEC_SN"$QC" AND LMI."$QC"WRITETIME"$QC" = KSL."$QC"WRITETIME"$QC") Q ON P."$QC"System_Name"$QC" = Q."$QC"System_Name"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC") Y, (SELECT Q."$QC"LAT_CEC_name"$QC" AS HOST_NAME, -1 AS PHYSICAL_MEMORY, -1 AS MIN_MEMORY_USAGE, -1 AS MAX_MEMORY_USAGE, -1 AS AVG_MEMORY_USAGE, -1 AS SUM_MEMORY_USAGE, P."$QC"MIN_USED_MEMORY_MB"$QC" AS MIN_MEMORY_UTILIZATION, P."$QC"MAX_USED_MEMORY_MB"$QC" AS MAX_MEMORY_UTILIZATION, P."$QC"AVG_USED_MEMORY_MB"$QC" AS AVG_MEMORY_UTILIZATION, P."$QC"SUM_USED_MEMORY_MB"$QC" AS SUM_MEMORY_UTILIZATION, -1 AS MIN_ACTIVE_MEMORY, -1 AS MAX_ACTIVE_MEMORY, -1 AS AVG_ACTIVE_MEMORY, -1 AS SUM_ACTIVE_MEMORY, -1 AS MIN_GRANTED_MEMORY, -1 AS MAX_GRANTED_MEMORY, -1 AS AVG_GRANTED_MEMORY, -1 AS SUM_GRANTED_MEMORY, -1 AS MIN_SWAP_USED, -1 AS MAX_SWAP_USED, -1 AS AVG_SWAP_USED, -1 AS SUM_SWAP_USED, -1 AS MIN_FREE_MEM, -1 AS MAX_FREE_MEM, -1 AS AVG_FREE_MEM, -1 AS SUM_FREE_MEM, -1 AS MIN_BALLOON_USED, -1 AS MAX_BALLOON_USED, -1 AS AVG_BALLOON_USED, -1 AS SUM_BALLOON_USED, -1 AS MIN_SWAP_IN_RATE, -1 AS MAX_SWAP_IN_RATE, -1 AS AVG_SWAP_IN_RATE, -1 AS SUM_SWAP_IN_RATE, -1 AS MIN_SWAP_OUT_RATE, -1 AS MAX_SWAP_OUT_RATE, -1 AS AVG_SWAP_OUT_RATE, -1 AS SUM_SWAP_OUT_RATE, -1 AS MIN_SWAP_TOTAL_RATE, -1 AS MAX_SWAP_TOTAL_RATE, -1 AS AVG_SWAP_TOTAL_RATE, -1 AS SUM_SWAP_TOTAL_RATE, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" AS WRITETIME FROM (SELECT "$QC"Node"$QC", "$QC"WRITETIME"$QC", "$QC"MIN_Used_Memory_MB"$QC" AS MIN_USED_MEMORY_MB, "$QC"MAX_Used_Memory_MB"$QC" AS MAX_USED_MEMORY_MB, "$QC"AVG_Used_Memory_MB"$QC" AS AVG_USED_MEMORY_MB, "$QC"SUM_Used_Memory_MB"$QC" AS SUM_USED_MEMORY_MB FROM FED_KVA_PHYSICAL_MEMORY"$PM_CDM_SUMM_L""_PS_MEM") P INNER JOIN (SELECT KSL."$QC"LAT_CEC_name"$QC", KT."$QC"Node"$QC", KT."$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$PM_CDM_SUMM_L""_PS_MEM" KSL, FED_KVA_TADDM"$PM_CDM_SUMM_L""_PS_MEM" KT WHERE KSL."$QC"CEC_Model"$QC" = KT."$QC"LAT_CEC_Model"$QC" AND KSL."$QC"CEC_SN"$QC" = KT."$QC"LAT_CEC_SN"$QC") Q ON P."$QC"Node"$QC" = Q."$QC"Node"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC") Z WHERE X."$QC"WRITETIME"$QC" = Z."$QC"WRITETIME"$QC")"
    fi

    if [ -z "$CDM_DB2CMD" ]
    then
		VIEW_DEF=$PS_MEM_VIEW_DEF

		if [ ! -z "$PM_CDM_SUMM_L" ]
		then
			VIEW_DEF=$PS_MEM_VIEW_DEF_AGG
		fi

        CDM_DB2CMD="$DB2_CMD_CREATE_VIEW $SPACE "$DM_SCHEMA_NAME"."MES_PS_MEM""$PM_CDM_SUMM_L" "$VIEW_DEF""
    fi
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo "$DB2 $CDM_DB2CMD ">> $TMP_DDL_FILE_NAME
	else
	echo "Creating view MES_PS_MEM$PM_CDM_SUMM_L" >> $LOG_F_NAME
    echo $CDM_DB2CMD > $TMP_F_NAME
    echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
	fi
    run_command
}

################################################################################
# Sets up the federation for Physical Server Memory utilization.
################################################################################
PS_MEM_Process_Args()
{
    PMPA_SUMM_L=$1
    
    G_LAST_ERROR=0

    if [ $COMMAND == "-add" ]
    then

        create_nickname "Unix_Memory""$PMPA_SUMM_L" "PS_MEM"
		if [ $G_LAST_ERROR != 0 ]
		then
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			FAILED_VIEW=$FAILED_VIEW","MES_PS_MEM$PMPA_SUMM_L
			return
		fi

        create_nickname "Machine_Information""$PMPA_SUMM_L" "PS_MEM"
		if [ $G_LAST_ERROR != 0 ]
		then
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			FAILED_VIEW=$FAILED_VIEW","MES_PS_MEM$PMPA_SUMM_L
			return
		fi

        create_nickname "KPH_SERVER_LPARS""$PMPA_SUMM_L" "PS_MEM"
		if [ $G_LAST_ERROR != 0 ]
		then
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			FAILED_VIEW=$FAILED_VIEW","MES_PS_MEM$PMPA_SUMM_L
			return
		fi

        if [ ! -z $LINUX_ENV ]
        then
            create_nickname "KLZ_VM_Stats""$PMPA_SUMM_L" "PS_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
				FAILED_VIEW=$FAILED_VIEW","MES_PS_MEM$PMPA_SUMM_L
			    return
		   fi

            create_nickname "Linux_Machine_Information""$PMPA_SUMM_L" "PS_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
				FAILED_VIEW=$FAILED_VIEW","MES_PS_MEM$PMPA_SUMM_L
			    return
		    fi
        fi

        create_nickname "KVA_PHYSICAL_MEMORY""$PMPA_SUMM_L" "PS_MEM"
		if [ $G_LAST_ERROR != 0 ]
		then
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			FAILED_VIEW=$FAILED_VIEW","MES_PS_MEM$PMPA_SUMM_L
			return
			
		fi

        create_nickname "KVA_TADDM""$PMPA_SUMM_L" "PS_MEM"
		if [ $G_LAST_ERROR != 0 ]
		then
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			FAILED_VIEW=$FAILED_VIEW","MES_PS_MEM$PMPA_SUMM_L
			return
		fi

        PS_MEM_create_dm_view $PMPA_SUMM_L
		
		if [ $G_LAST_ERROR != 0 ]
		then
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			FAILED_VIEW=$FAILED_VIEW","MES_PS_MEM$PMPA_SUMM_L
			echo "Failed to create a view  MES_PS_MEM$PMPA_SUMM_L" >> $LOG_F_NAME
			echo "................................................................................" >> $LOG_F_NAME
			return
			else
			SUCCESS_VIEW=$SUCCESS_VIEW","MES_PS_MEM$PMPA_SUMM_L
			if [ $DBA_MODE != "DBAMODE" ]
			then
			echo "View MES_PS_MEM$PMPA_SUMM_L created successfully " >> $LOG_F_NAME 
			fi	
		fi
		

    elif [ $COMMAND == "-delete" ]
    then
     
        PS_MEM_delete_dm_view "$PMPA_SUMM_L"
		if [ $G_LAST_ERROR != 0 ]
		then
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        if [ $VIEW_EXISTS -eq 1 ]
	    then
            delete_nickname "Unix_Memory""$PMPA_SUMM_L" "PS_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi
    
            delete_nickname "Machine_Information""$PMPA_SUMM_L" "PS_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi
    
            delete_nickname "KPH_SERVER_LPARS""$PMPA_SUMM_L" "PS_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi    
            if [ ! -z $LINUX_ENV ]
            then
                delete_nickname "KLZ_VM_Stats""$PMPA_SUMM_L" "PS_MEM"
		        if [ $G_LAST_ERROR != 0 ]
		        then
			        G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			        return
		        fi
    
                delete_nickname "Linux_Machine_Information""$PMPA_SUMM_L" "PS_MEM"
		        if [ $G_LAST_ERROR != 0 ]
		            then
			        G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			        return
		        fi
            fi

            delete_nickname "KVA_PHYSICAL_MEMORY""$PMPA_SUMM_L" "PS_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            delete_nickname "KVA_TADDM""$PMPA_SUMM_L" "PS_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

        fi
    fi
    if [ $DBA_MODE != "DBAMODE" ]
	then
    echo "................................................................................" >> $LOG_F_NAME
    fi
}

################################################################################
# Removes view MES_VM_MEM_*
################################################################################
VM_MEM_delete_dm_view()
{
    G_LAST_ERROR=0

    VMDM_SUMM_L=$1
    TABLE_BODY=$TABLE_BODY_VM_MEM

    if [ ! -z $VMDM_SUMM_L ]
    then
        TABLE_BODY=$TABLE_BODY_VM_MEM_AGG
    fi


	drop_view_if_exists "VM_MEM""$VMDM_SUMM_L"
    if [ $G_LAST_ERROR != 0 ]
    then
        return
    fi

	if [ $VIEW_EXISTS -eq 1 ]
	then
		create_dm_table "VM_MEM""$VMDM_SUMM_L" "$TABLE_BODY"
        if [ $G_LAST_ERROR != 0 ]
        then
            return
        fi
	fi
}

################################################################################
# Creates Datamart view: MES_VM_MEM*
# Arguments:
#   $1 (Mandatory)  :   Summarization level
################################################################################
VM_MEM_create_dm_view()
{
    G_LAST_ERROR=0
    CDM_DB2CMD=""

    VM_CDM_SUMM_L=$1
	drop_table_if_exists "MES_VM_MEM""$VM_CDM_SUMM_L"
	if [ $G_LAST_ERROR != 0 ]
	then
		return
	fi

	if [ $DB2_VERSION = "v9.5" ]
	then
		drop_view_if_exists "VM_MEM""$VM_CDM_SUMM_L"
		if [ $G_LAST_ERROR != 0 ]
		then
			return
		fi
	fi

    VM_MEM_VIEW_DEF="(HOST_NAME, VM_NAME, VM_SERVER_NAME, HOST_USAGE, GUEST_USAGE, HOST_UTILIZATION, GUEST_UTILIZATION, HOST_FREE, GUEST_FREE, BALLOON_USAGE, SWAP_TO_FILE, TIMESTAMP, WRITETIME) AS ( SELECT P."$QC"Hostname"$QC" AS HOST_NAME, P."$QC"LPAR_Name"$QC" AS VM_NAME, Q."$QC"CEC_name"$QC" AS VM_SERVER_NAME, -1 AS HOST_NAME, -1 AS GUEST_USAGE, -1 AS HOST_UTILIZATION, P."$QC"Used_Real_Mem_MB"$QC" AS GUEST_UTILIZATION, -1 AS HOST_FREE, -1 AS GUEST_FREE, -1 AS BALLOON_USAGE, -1 AS SWAP_TO_FILE, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" FROM (SELECT MI."$QC"Hostname"$QC", MI."$QC"Hardware_Model"$QC", MI."$QC"Machine_Serial"$QC", AL."$QC"LPAR_Name"$QC", UM."$QC"Used_Real_Mem_MB"$QC", UM."$QC"WRITETIME"$QC" FROM FED_Machine_Information"$VM_CDM_SUMM_L""_VM_MEM" MI, FED_AIX_LPAR"$VM_CDM_SUMM_L""_VM_MEM" AL, FED_Unix_Memory"$VM_CDM_SUMM_L""_VM_MEM" UM WHERE MI."$QC"System_Name"$QC" = AL."$QC"System_Name"$QC" AND AL."$QC"System_Name"$QC" = UM."$QC"System_Name"$QC" AND MI."$QC"WRITETIME"$QC" = AL."$QC"WRITETIME"$QC" AND AL."$QC"WRITETIME"$QC" = UM."$QC"WRITETIME"$QC") P INNER JOIN (SELECT "$QC"CEC_name"$QC", "$QC"CEC_Mfg"$QC", "$QC"CEC_Model"$QC", "$QC"CEC_SN"$QC", "$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$VM_CDM_SUMM_L""_VM_MEM") Q ON P."$QC"Hardware_Model"$QC" = Q."$QC"CEC_Model"$QC" AND SUBSTR(P."$QC"Machine_Serial"$QC", 7) = Q."$QC"CEC_SN"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC")  UNION ALL ( SELECT H."$QC"Hostname"$QC" AS HOST_NAME, H."$QC"VIOS_Name"$QC" AS VM_NAME, I."$QC"CEC_name"$QC" AS VM_SERVER_NAME, -1 AS HOST_NAME, -1 AS GUEST_USAGE, -1 AS HOST_UTILIZATION, H."$QC"Used_Memory_MB"$QC" AS GUEST_UTILIZATION, -1 AS HOST_FREE, -1 AS GUEST_FREE, -1 AS BALLOON_USAGE, -1 AS SWAP_TO_FILE, -1 AS TIMESTAMP, H."$QC"WRITETIME"$QC" FROM (SELECT KPM."$QC"Node"$QC", KPM."$QC"Used_Memory_MB"$QC", KSM."$QC"Hostname"$QC", KSM."$QC"VIOS_Name"$QC", KPM."$QC"WRITETIME"$QC" FROM FED_KVA_PHYSICAL_MEMORY"$VM_CDM_SUMM_L""_VM_MEM" KPM, FED_KVA_STORAGE_MAPPINGS"$VM_CDM_SUMM_L""_VM_MEM" KSM WHERE KPM."$QC"Node"$QC" = KSM."$QC"Node"$QC" AND KPM."$QC"WRITETIME"$QC" = KSM."$QC"WRITETIME"$QC") H INNER JOIN (SELECT KSL."$QC"CEC_name"$QC", KT."$QC"Node"$QC" FROM FED_KPH_SERVER_LPARS"$VM_CDM_SUMM_L""_VM_MEM" KSL, FED_KVA_TADDM"$VM_CDM_SUMM_L""_VM_MEM" KT WHERE KSL."$QC"CEC_Model"$QC" = KT."$QC"CEC_Model"$QC" AND KSL."$QC"CEC_SN"$QC" = KT."$QC"CEC_SN"$QC") I ON H."$QC"Node"$QC" = I."$QC"Node"$QC")"
	VM_MEM_VIEW_DEF_AGG="(    HOST_NAME,    VM_NAME,    VM_SERVER_NAME,    MIN_HOST_USAGE,    MAX_HOST_USAGE,    AVG_HOST_USAGE,    SUM_HOST_USAGE,    MIN_GUEST_USAGE,    MAX_GUEST_USAGE,    AVG_GUEST_USAGE,    SUM_GUEST_USAGE,    MIN_HOST_UTILIZATION,    MAX_HOST_UTILIZATION,    AVG_HOST_UTILIZATION,    SUM_HOST_UTILIZATION,    MIN_GUEST_UTILIZATION,    MAX_GUEST_UTILIZATION,    AVG_GUEST_UTILIZATION,    SUM_GUEST_UTILIZATION,    MIN_HOST_FREE,    MAX_HOST_FREE,    AVG_HOST_FREE,    SUM_HOST_FREE,    MIN_GUEST_FREE,    MAX_GUEST_FREE,    AVG_GUEST_FREE,    SUM_GUEST_FREE,    MIN_BALLOON_USAGE,    MAX_BALLOON_USAGE,    AVG_BALLOON_USAGE,    SUM_BALLOON_USAGE,    MIN_SWAP_TO_FILE,    MAX_SWAP_TO_FILE,    AVG_SWAP_TO_FILE,    SUM_SWAP_TO_FILE,    TIMESTAMP,    WRITETIME ) AS (    SELECT    P."$QC"LAT_Hostname"$QC" AS HOST_NAME,    P."$QC"LAT_LPAR_Name"$QC" AS VM_NAME,    Q."$QC"LAT_CEC_name"$QC" AS VM_SERVER_NAME,    -1 AS MIN_HOST_USAGE,    -1 AS MAX_HOST_USAGE,    -1 AS AVG_HOST_USAGE,    -1 AS SUM_HOST_USAGE,    -1 AS MIN_GUEST_USAGE,    -1 AS MAX_GUEST_USAGE,    -1 AS AVG_GUEST_USAGE,    -1 AS SUM_GUEST_USAGE,    -1 AS MIN_HOST_UTILIZATION,    -1 AS MAX_HOST_UTILIZATION,    -1 AS AVG_HOST_UTILIZATION,    -1 AS SUM_HOST_UTILIZATION,    P."$QC"MIN_Used_Real_Mem_MB"$QC" AS MIN_GUEST_UTILIZATION,    P."$QC"MAX_Used_Real_Mem_MB"$QC" AS MAX_GUEST_UTILIZATION,    P."$QC"AVG_Used_Real_Mem_MB"$QC" AS AVG_GUEST_UTILIZATION,    P."$QC"SUM_Used_Real_Mem_MB"$QC" AS SUM_GUEST_UTILIZATION,    -1 AS MIN_HOST_FREE,    -1 AS MAX_HOST_FREE,    -1 AS AVG_HOST_FREE,    -1 AS SUM_HOST_FREE,    -1 AS MIN_GUEST_FREE,    -1 AS MAX_GUEST_FREE,    -1 AS AVG_GUEST_FREE,    -1 AS SUM_GUEST_FREE,    -1 AS MIN_BALLOON_USAGE,    -1 AS MAX_BALLOON_USED,    -1 AS AVG_BALLOON_USED,    -1 AS SUM_BALLOON_USED,    -1 AS MIN_SWAP_TO_FILE,    -1 AS MAX_SWAP_TO_FILE,    -1 AS AVG_SWAP_TO_FILE,    -1 AS SUM_SWAP_TO_FILE,    -1 AS TIMESTAMP,    P."$QC"WRITETIME"$QC" 	FROM    (       SELECT       MI."$QC"LAT_Hostname"$QC",       MI."$QC"LAT_Hardware_Model"$QC",       MI."$QC"LAT_Machine_Serial"$QC",       AL."$QC"LAT_LPAR_Name"$QC",       UM."$QC"MIN_Used_Real_Mem_MB"$QC",       UM."$QC"MAX_Used_Real_Mem_MB"$QC",       UM."$QC"AVG_Used_Real_Mem_MB"$QC",       UM."$QC"SUM_Used_Real_Mem_MB"$QC",       UM."$QC"WRITETIME"$QC"       FROM FED_Machine_Information"$VM_CDM_SUMM_L""_VM_MEM" MI,       FED_AIX_LPAR"$VM_CDM_SUMM_L""_VM_MEM" AL,       FED_Unix_Memory"$VM_CDM_SUMM_L""_VM_MEM" UM       WHERE MI."$QC"System_Name"$QC" = AL."$QC"System_Name"$QC"       AND AL."$QC"System_Name"$QC" = UM."$QC"System_Name"$QC"       AND MI."$QC"WRITETIME"$QC" = AL."$QC"WRITETIME"$QC"       AND AL."$QC"WRITETIME"$QC" = UM."$QC"WRITETIME"$QC"    )    P    INNER JOIN    (       SELECT       "$QC"LAT_LPAR_Name"$QC", "$QC"LAT_CEC_name"$QC", "$QC"CEC_Mfg"$QC", "$QC"CEC_Model"$QC", "$QC"CEC_SN"$QC", "$QC"WRITETIME"$QC"       FROM FED_KPH_SERVER_LPARS"$VM_CDM_SUMM_L""_VM_MEM"    )    Q ON P."$QC"LAT_Hardware_Model"$QC" = Q."$QC"CEC_Model"$QC"    AND SUBSTR(P."$QC"LAT_Machine_Serial"$QC", 7) = Q."$QC"CEC_SN"$QC"    AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC"    AND P."$QC"LAT_LPAR_Name"$QC" = Q."$QC"LAT_LPAR_Name"$QC" ) UNION ALL (    SELECT    J."$QC"LAT_Hostname"$QC" AS HOST_NAME,    J."$QC"LAT_VIOS_Name"$QC" AS VM_NAME,    'DUMMY_SERVER_NAME' AS VM_SERVER_NAME,    -1 AS MIN_HOST_USAGE,    -1 AS MAX_HOST_USAGE,    -1 AS AVG_HOST_USAGE,    -1 AS SUM_HOST_USAGE,    -1 AS MIN_GUEST_USAGE,    -1 AS MAX_GUEST_USAGE,    -1 AS AVG_GUEST_USAGE,    -1 AS SUM_GUEST_USAGE,    -1 AS MIN_HOST_UTILIZATION,    -1 AS MAX_HOST_UTILIZATION,    -1 AS AVG_HOST_UTILIZATION,    -1 AS SUM_HOST_UTILIZATION,    H."$QC"MIN_Used_Memory_MB"$QC" AS MIN_GUEST_UTILIZATION,    H."$QC"MAX_Used_Memory_MB"$QC" AS MAX_GUEST_UTILIZAITON,    H."$QC"AVG_Used_Memory_MB"$QC" AS AVG_GUEST_UTILIZATION,    H."$QC"SUM_Used_Memory_MB"$QC" AS SUM_GUEST_UTILIZATION,    -1 AS MIN_HOST_FREE,    -1 AS MAX_HOST_FREE,    -1 AS AVG_HOST_FREE,    -1 AS SUM_HOST_FREE,    -1 AS MIN_GUEST_FREE,    -1 AS MAX_GUEST_FREE,    -1 AS AVG_GUEST_FREE,    -1 AS SUM_GUEST_FREE,    -1 AS MIN_BALLOON_USAGE,    -1 AS MAX_BALLOON_USAGE,    -1 AS AVG_BALLOON_USAGE,    -1 AS SUM_BALLOON_USAGE,    -1 AS MIN_SWAP_TO_FILE,    -1 AS MAX_SWAP_TO_FILE,    -1 AS AVG_SWAP_TO_FILE,    -1 AS SUM_SWAP_TO_FILE,    -1 AS TIMESTAMP,    H."$QC"WRITETIME"$QC" FROM    (       SELECT       KPM."$QC"Node"$QC",       KPM."$QC"MIN_Used_Memory_MB"$QC",       KPM."$QC"MAX_Used_Memory_MB"$QC",       KPM."$QC"AVG_Used_Memory_MB"$QC",       KPM."$QC"SUM_Used_Memory_MB"$QC",       KPM."$QC"WRITETIME"$QC"       FROM FED_KVA_PHYSICAL_MEMORY"$VM_CDM_SUMM_L""_VM_MEM" KPM    )    H 	INNER JOIN 	( SELECT DISTINCT  	KSM."$QC"LAT_Hostname"$QC", 	KSM."$QC"LAT_VIOS_Name"$QC", 	KSM."$QC"Node"$QC"    		FROM FED_KVA_STORAGE_MAPPINGS"$VM_CDM_SUMM_L""_VM_MEM" KSM) J    ON    H."$QC"Node"$QC" = J."$QC"Node"$QC" )"
	
	
    if [ ! -z "$LINUX_ENV" ]
    then
        VM_MEM_VIEW_DEF="$VM_MEM_VIEW_DEF"" UNION ALL ( SELECT H."$QC"Hostname"$QC" AS HOST_NAME, H."$QC"LPAR_Name"$QC" AS VM_NAME, I."$QC"CEC_name"$QC" AS VM_SERVER_NAME, -1 AS HOST_NAME, -1 AS GUEST_USAGE, -1 AS HOST_UTILIZATION, H."$QC"Memory_Used"$QC" AS GUEST_UTILIZATION, -1 AS HOST_FREE, -1 AS GUEST_FREE, -1 AS BALLOON_USAGE, -1 AS SWAP_TO_FILE, -1 AS TIMESTAMP, H."$QC"WRITETIME"$QC" FROM (SELECT LMI."$QC"System_Name"$QC", LMI."$QC"Hostname"$QC", LMI."$QC"Hardware_Model"$QC", LMI."$QC"Machine_Serial"$QC", LMI."$QC"WRITETIME"$QC", KL."$QC"LPAR_Name"$QC", KVS."$QC"Memory_Used"$QC" FROM FED_Linux_Machine_Information"$VM_CDM_SUMM_L""_VM_MEM" LMI, FED_KLZ_LPAR"$VM_CDM_SUMM_L""_VM_MEM" KL, FED_KLZ_VM_Stats"$VM_CDM_SUMM_L""_VM_MEM" KVS WHERE LMI."$QC"System_Name"$QC" = KL."$QC"System_Name"$QC" AND KL."$QC"System_Name"$QC" = KVS."$QC"System_Name"$QC" AND LMI."$QC"WRITETIME"$QC" = KL."$QC"WRITETIME"$QC" AND KL."$QC"WRITETIME"$QC" = KVS."$QC"WRITETIME"$QC") H INNER JOIN (SELECT "$QC"CEC_name"$QC", "$QC"CEC_Mfg"$QC", "$QC"CEC_Model"$QC", "$QC"CEC_SN"$QC", "$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$VM_CDM_SUMM_L""_VM_MEM") I ON H."$QC"Hardware_Model"$QC" = I."$QC"CEC_Model"$QC" AND H."$QC"Machine_Serial"$QC" = I."$QC"CEC_SN"$QC" AND H."$QC"WRITETIME"$QC" = I."$QC"WRITETIME"$QC")"
        VM_MEM_VIEW_DEF_AGG="$VM_MEM_VIEW_DEF_AGG"" UNION ALL (    SELECT    H."$QC"LAT_Hostname"$QC" AS HOST_NAME,    H."$QC"LAT_LPAR_Name"$QC" AS VM_NAME,    I."$QC"LAT_CEC_name"$QC" AS VM_SERVER_NAME,    -1 AS MIN_HOST_USAGE,    -1 AS MAX_HOST_USAGE,    -1 AS AVG_HOST_USAGE,    -1 AS SUM_HOST_USAGE,    -1 AS MIN_GUEST_USAGE,    -1 AS MAX_GUEST_USAGE,    -1 AS AVG_GUEST_USAGE,    -1 AS SUM_GUEST_USAGE,    -1 AS MIN_HOST_UTILIZATION,    -1 AS MAX_HOST_UTILIZATION,    -1 AS AVG_HOST_UTILIZATION,    -1 AS SUM_HOST_UTILIZATION,    H."$QC"MIN_Memory_Used"$QC" AS MIN_GUEST_UTILIZATION,    H."$QC"MAX_Memory_Used"$QC" AS MAX_GUEST_UTILIZATION,    H."$QC"AVG_Memory_Used"$QC" AS AVG_GUEST_UTILIZATION,    H."$QC"SUM_Memory_Used"$QC" AS SUM_GUEST_UTILIZATION,    -1 AS MIN_HOST_FREE,    -1 AS MAX_HOST_FREE,    -1 AS AVG_HOST_FREE,    -1 AS SUM_HOST_FREE,    -1 AS MIN_GUEST_FREE,    -1 AS MAX_GUEST_FREE,    -1 AS AVG_GUEST_FREE,    -1 AS SUM_GUEST_FREE,    -1 AS MIN_BALLOON_USAGE,    -1 AS MAX_BALLOON_USED,    -1 AS AVG_BALLOON_USED,    -1 AS SUM_BALLOON_USED,    -1 AS MIN_SWAP_TO_FILE,    -1 AS MAX_SWAP_TO_FILE,    -1 AS AVG_SWAP_TO_FILE,    -1 AS SUM_SWAP_TO_FILE,    -1 AS TIMESTAMP,    H."$QC"WRITETIME"$QC"   FROM    (       SELECT       LMI."$QC"System_Name"$QC",       LMI."$QC"LAT_Hostname"$QC",       LMI."$QC"LAT_Hardware_Model"$QC",       LMI."$QC"LAT_Machine_Serial"$QC",       LMI."$QC"WRITETIME"$QC",       KL."$QC"LAT_LPAR_Name"$QC",       KVS."$QC"MIN_Memory_Used"$QC",       KVS."$QC"MAX_Memory_Used"$QC",       KVS."$QC"AVG_Memory_Used"$QC",       KVS."$QC"SUM_Memory_Used"$QC"       FROM FED_Linux_Machine_Information"$VM_CDM_SUMM_L""_VM_MEM" LMI,       FED_KLZ_LPAR"$VM_CDM_SUMM_L""_VM_MEM" KL,       FED_KLZ_VM_Stats"$VM_CDM_SUMM_L""_VM_MEM" KVS       WHERE LMI."$QC"System_Name"$QC" = KL."$QC"System_Name"$QC"       AND KL."$QC"System_Name"$QC" = KVS."$QC"System_Name"$QC"       AND LMI."$QC"WRITETIME"$QC" = KL."$QC"WRITETIME"$QC"       AND KL."$QC"WRITETIME"$QC" = KVS."$QC"WRITETIME"$QC"    )    H    INNER JOIN    (       SELECT       "$QC"LAT_LPAR_Name"$QC","$QC"LAT_CEC_name"$QC", "$QC"CEC_Mfg"$QC", "$QC"CEC_Model"$QC", "$QC"CEC_SN"$QC", "$QC"WRITETIME"$QC"       FROM FED_KPH_SERVER_LPARS"$VM_CDM_SUMM_L""_VM_MEM"    )    I ON H."$QC"LAT_Hardware_Model"$QC" = I."$QC"CEC_Model"$QC"    AND H."$QC"LAT_Machine_Serial"$QC" = I."$QC"CEC_SN"$QC"    AND H."$QC"WRITETIME"$QC" = I."$QC"WRITETIME"$QC"    AND H."$QC"LAT_LPAR_Name"$QC" = I."$QC"LAT_LPAR_Name"$QC" )"
    fi

    if [ -z "$CDM_DB2CMD" ]
    then

		VIEW_DEF=$VM_MEM_VIEW_DEF
		if [ ! -z "$VM_CDM_SUMM_L" ]
		then
			VIEW_DEF=$VM_MEM_VIEW_DEF_AGG
		fi

        CDM_DB2CMD="$DB2_CMD_CREATE_VIEW $SPACE "$DM_SCHEMA_NAME"."MES_VM_MEM""$VM_CDM_SUMM_L" "$VIEW_DEF""
    fi
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo "$DB2 $CDM_DB2CMD ">> $TMP_DDL_FILE_NAME
	else 
	echo "Creating a view MES_VM_MEM$VM_CDM_SUMM_L" >> $LOG_F_NAME
    echo $CDM_DB2CMD > $TMP_F_NAME
    echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
	fi
    run_command
}

################################################################################
# Sets up the federation for Virtual Machine Memory utilization.
################################################################################
VM_MEM_Process_Args()
{
    VMPA_SUMM_L=$1
    
    G_LAST_ERROR=0

    if [ $COMMAND == "-add" ]
    then

        create_nickname "Unix_Memory""$VMPA_SUMM_L" "VM_MEM"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_MEM$VMPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        create_nickname "Machine_Information""$VMPA_SUMM_L" "VM_MEM"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_MEM$VMPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        create_nickname "AIX_LPAR""$VMPA_SUMM_L" "VM_MEM"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_MEM$VMPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        create_nickname "KPH_SERVER_LPARS""$VMPA_SUMM_L" "VM_MEM"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_MEM$VMPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        if [ ! -z $LINUX_ENV ]
        then
            create_nickname "KLZ_LPAR""$VMPA_SUMM_L" "VM_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
				FAILED_VIEW=$FAILED_VIEW","MES_VM_MEM$VMPA_SUMM_L
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
			fi

            create_nickname "KLZ_VM_Stats""$VMPA_SUMM_L" "VM_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
				FAILED_VIEW=$FAILED_VIEW","MES_VM_MEM$VMPA_SUMM_L
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            create_nickname "Linux_Machine_Information""$VMPA_SUMM_L" "VM_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
				FAILED_VIEW=$FAILED_VIEW","MES_VM_MEM$VMPA_SUMM_L
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi
        fi

        create_nickname "KVA_PHYSICAL_MEMORY""$VMPA_SUMM_L" "VM_MEM"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_MEM$VMPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        create_nickname "KVA_STORAGE_MAPPINGS""$VMPA_SUMM_L" "VM_MEM"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_MEM$VMPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        create_nickname "KVA_TADDM""$VMPA_SUMM_L" "VM_MEM"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_MEM$VMPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi
		
		
        VM_MEM_create_dm_view $VMPA_SUMM_L
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_MEM$VMPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			echo "Failed to create a view MES_VM_MEM$VMPA_SUMM_L" >> $LOG_F_NAME
			echo "................................................................................" >> $LOG_F_NAME
			return
			else 
				SUCCESS_VIEW=$SUCCESS_VIEW","MES_VM_MEM$VMPA_SUMM_L
				if [ $DBA_MODE != "DBAMODE" ]
				then
				echo "View MES_VM_MEM$VMPA_SUMM_L created successfully " >> $LOG_F_NAME 
				fi	
		fi


    elif [ $COMMAND == "-delete" ]
    then
     
        VM_MEM_delete_dm_view "$VMPA_SUMM_L"
		if [ $G_LAST_ERROR != 0 ]
		then
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        if [ $VIEW_EXISTS -eq 1 ]
	    then
            delete_nickname "Unix_Memory""$VMPA_SUMM_L" "VM_MEM"
	    	if [ $G_LAST_ERROR != 0 ]
	    	then
	    		G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
	    		return
	    	fi

            delete_nickname "Machine_Information""$VMPA_SUMM_L" "VM_MEM"
	    	if [ $G_LAST_ERROR != 0 ]
	    	then
	    		G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            delete_nickname "AIX_LPAR""$VMPA_SUMM_L" "VM_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            delete_nickname "KPH_SERVER_LPARS""$VMPA_SUMM_L" "VM_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            if [ ! -z $LINUX_ENV ]
            then
                delete_nickname "KLZ_LPAR""$VMPA_SUMM_L" "VM_MEM"
		        if [ $G_LAST_ERROR != 0 ]
		        then
			        G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			        return
		        fi
    
                delete_nickname "KLZ_VM_Stats""$VMPA_SUMM_L" "VM_MEM"
		        if [ $G_LAST_ERROR != 0 ]
		        then
			        G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			        return
		        fi

                delete_nickname "Linux_Machine_Information""$VMPA_SUMM_L" "VM_MEM"
		        if [ $G_LAST_ERROR != 0 ]
		        then
			        G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			        return
		        fi
            fi

            delete_nickname "KVA_PHYSICAL_MEMORY""$VMPA_SUMM_L" "VM_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi
    
            delete_nickname "KVA_STORAGE_MAPPINGS""$VMPA_SUMM_L" "VM_MEM"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

        	delete_nickname "KVA_TADDM""$VMPA_SUMM_L" "VM_MEM"
			if [ $G_LAST_ERROR != 0 ]
			then
				G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
				return
			fi
        fi

    fi
    if [ $DBA_MODE != "DBAMODE" ]
	then
    echo "................................................................................" >> $LOG_F_NAME
    fi
}

################################################################################
# Removes view MES_VM_DS_*
################################################################################
VM_DS_delete_dm_view()
{
    G_LAST_ERROR=0

    VMDS_SUMM_L=$1
    TABLE_BODY=$TABLE_BODY_VM_DS

    if [ ! -z $VMDS_SUMM_L ]
    then
        TABLE_BODY=$TABLE_BODY_VM_DS_AGG
    fi


	drop_view_if_exists "VM_DATA_STORE""$VMDS_SUMM_L"
    if [ $G_LAST_ERROR != 0 ]
    then
        return
    fi

	if [ $VIEW_EXISTS -eq 1 ]
	then
		create_dm_table "VM_DATA_STORE""$VMDS_SUMM_L" "$TABLE_BODY"
        if [ $G_LAST_ERROR != 0 ]
        then
            return
        fi
	fi
}

################################################################################
# Creates Datamart view: MES_VM_DS*
# Arguments:
#   $1 (Mandatory)  :   Summarization level
################################################################################
VM_DS_create_dm_view()
{
    G_LAST_ERROR=0
    CDM_DB2CMD=""

    VD_CDM_SUMM_L=$1
	drop_table_if_exists "MES_VM_DATA_STORE""$VD_CDM_SUMM_L"
	if [ $G_LAST_ERROR != 0 ]
	then
		return
	fi

	if [ $DB2_VERSION = "v9.5" ]
	then
		drop_view_if_exists "VM_DATA_STORE""$VD_CDM_SUMM_L"
		if [ $G_LAST_ERROR != 0 ]
		then
			return
		fi
	fi

    VM_DS_VIEW_DEF="(DATA_STORE_NAME, HOST_NAME, VM_NAME, DATA_CENTER_NAME, TOTAL_READ, TOTAL_WRITE, TOTAL_IO, TIMESTAMP, WRITETIME) AS (SELECT P."$QC"Disk_Name"$QC" AS DATA_STORE_NAME, P."$QC"Hostname"$QC" AS HOST_NAME, P."$QC"LPAR_Name"$QC" AS VM_NAME, Q."$QC"CEC_name"$QC" AS DATA_CENTER_NAME, (P."$QC"Disk_Read_Bytes_Sec"$QC"/1000) AS TOTAL_READ, (P."$QC"Disk_Write_Bytes_Sec"$QC"/1000) AS TOTAL_WRITE, P."$QC"Transfers_KB_per_Sec"$QC" AS TOTAL_IO, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" FROM (SELECT MI."$QC"Hostname"$QC", MI."$QC"Hardware_Model"$QC", MI."$QC"Machine_Serial"$QC", AL."$QC"LPAR_Name"$QC", DP."$QC"Disk_Name"$QC", DP."$QC"Disk_Read_Bytes_Sec"$QC", DP."$QC"Disk_Write_Bytes_Sec"$QC", DP."$QC"Transfers_KB_per_Sec"$QC", DP."$QC"WRITETIME"$QC" FROM FED_Machine_Information"$VD_CDM_SUMM_L""_VM_DS" MI, FED_Disk_Performance"$VD_CDM_SUMM_L""_VM_DS" DP, FED_AIX_LPAR"$VD_CDM_SUMM_L""_VM_DS" AL WHERE DP."$QC"System_Name"$QC" = MI."$QC"System_Name"$QC" AND MI."$QC"System_Name"$QC" = AL."$QC"System_Name"$QC" AND DP."$QC"WRITETIME"$QC" = MI."$QC"WRITETIME"$QC" AND MI."$QC"WRITETIME"$QC" = AL."$QC"WRITETIME"$QC") P INNER JOIN (SELECT "$QC"CEC_name"$QC", "$QC"CEC_Model"$QC", "$QC"CEC_SN"$QC", "$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$VD_CDM_SUMM_L""_VM_DS") Q ON P."$QC"Hardware_Model"$QC" = Q."$QC"CEC_Model"$QC" AND SUBSTR(P."$QC"Machine_Serial"$QC", 7) = Q."$QC"CEC_SN"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC")"
    VM_DS_VIEW_DEF_AGG="(DATA_STORE_NAME, HOST_NAME, VM_NAME, DATA_CENTER_NAME, MIN_TOTAL_READ, MAX_TOTAl_READ, AVG_TOTAL_READ, SUM_TOTAL_READ, MIN_TOTAL_WRITE, MAX_TOTAL_WRITE, AVG_TOTAL_WRITE, SUM_TOTAL_WRITE, MIN_TOTAL_IO, MAX_TOTAL_IO, AVG_TOTAL_IO, SUM_TOTAL_IO, MIN_READ_OPS, MAX_READ_OPS, AVG_READ_OPS, SUM_READ_OPS, MIN_WRITE_OPS, MAX_WRITE_OPS, AVG_WRITE_OPS, SUM_WRITE_OPS, TIMESTAMP, WRITETIME) AS (SELECT P."$QC"LAT_Disk_Name"$QC" AS DATA_STORE_NAME, P."$QC"LAT_Hostname"$QC" AS HOST_NAME, P."$QC"LAT_LPAR_Name"$QC" AS VM_NAME, Q."$QC"LAT_CEC_name"$QC" AS DATA_CENTER_NAME, (P."$QC"MIN_Disk_Read_Bytes_Sec"$QC"/1000) AS MIN_TOTAL_READ, (P."$QC"MAX_Disk_Read_Bytes_Sec"$QC"/1000) AS MAX_TOTAL_READ, (P."$QC"AVG_Disk_Read_Bytes_Sec"$QC"/1000) AS AVG_TOTAL_READ, (P."$QC"SUM_Disk_Read_Bytes_Sec"$QC"/1000) AS SUM_TOTAL_READ, (P."$QC"MIN_Disk_Write_Bytes_Sec"$QC"/1000) AS MIN_TOTAL_WRITE, (P."$QC"MAX_Disk_Write_Bytes_Sec"$QC"/1000) AS MAX_TOTAL_WRITE, (P."$QC"AVG_Disk_Write_Bytes_Sec"$QC"/1000) AS AVG_TOTAL_WRITE, (P."$QC"SUM_Disk_Write_Bytes_Sec"$QC"/1000) AS SUM_TOTAL_WRITE, P."$QC"MIN_Transfers_KB_per_Sec"$QC" AS MIN_TOTAL_IO, P."$QC"MAX_Transfers_KB_per_Sec"$QC" AS MAX_TOTAL_IO, P."$QC"AVG_Transfers_KB_per_Sec"$QC" AS AVG_TOTAL_IO, P."$QC"SUM_Transfers_KB_per_Sec"$QC" AS SUM_TOTAL_IO, P."$QC"MIN_Read_Transfers_per_Sec"$QC" AS MIN_READ_OPS, P."$QC"MAX_Read_Transfers_per_Sec"$QC" AS MAX_READ_OPS, P."$QC"AVG_Read_Transfers_per_Sec"$QC" AS AVG_READ_OPS, P."$QC"SUM_Read_Transfers_per_Sec"$QC" AS SUM_READ_OPS, P."$QC"MIN_Write_Transfers_per_Sec"$QC" AS MIN_WRITE_OPS, P."$QC"MAX_Write_Transfers_per_Sec"$QC" AS MAX_WRITE_OPS, P."$QC"AVG_Write_Transfers_per_Sec"$QC" AS AVG_WRITE_OPS, P."$QC"SUM_Write_Transfers_per_Sec"$QC" AS SUM_WRITE_OPS, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" FROM (SELECT MI."$QC"LAT_Hostname"$QC", MI."$QC"LAT_Hardware_Model"$QC", MI."$QC"LAT_Machine_Serial"$QC", AL."$QC"LAT_LPAR_Name"$QC", DP."$QC"LAT_Disk_Name"$QC", DP."$QC"MIN_Disk_Read_Bytes_Sec"$QC", DP."$QC"MAX_Disk_Read_Bytes_Sec"$QC", DP."$QC"AVG_Disk_Read_Bytes_Sec"$QC", DP."$QC"SUM_Disk_Read_Bytes_Sec"$QC", DP."$QC"MIN_Disk_Write_Bytes_Sec"$QC", DP."$QC"MAX_Disk_Write_Bytes_Sec"$QC", DP."$QC"AVG_Disk_Write_Bytes_Sec"$QC", DP."$QC"SUM_Disk_Write_Bytes_Sec"$QC", DP."$QC"MIN_Transfers_KB_per_Sec"$QC", DP."$QC"MAX_Transfers_KB_per_Sec"$QC", DP."$QC"AVG_Transfers_KB_per_Sec"$QC", DP."$QC"SUM_Transfers_KB_per_Sec"$QC", DP."$QC"MIN_Read_Transfers_per_Sec"$QC", DP."$QC"MAX_Read_Transfers_per_Sec"$QC", DP."$QC"AVG_Read_Transfers_per_Sec"$QC", DP."$QC"SUM_Read_Transfers_per_Sec"$QC", DP."$QC"MIN_Write_Transfers_per_Sec"$QC", DP."$QC"MAX_Write_Transfers_per_Sec"$QC", DP."$QC"AVG_Write_Transfers_per_Sec"$QC", DP."$QC"SUM_Write_Transfers_per_Sec"$QC", DP."$QC"WRITETIME"$QC" FROM FED_Machine_Information"$VD_CDM_SUMM_L""_VM_DS" MI, FED_Disk_Performance"$VD_CDM_SUMM_L""_VM_DS" DP, FED_AIX_LPAR"$VD_CDM_SUMM_L""_VM_DS" AL WHERE DP."$QC"System_Name"$QC" = MI."$QC"System_Name"$QC" AND MI."$QC"System_Name"$QC" = AL."$QC"System_Name"$QC" AND DP."$QC"WRITETIME"$QC" = MI."$QC"WRITETIME"$QC" AND MI."$QC"WRITETIME"$QC" = AL."$QC"WRITETIME"$QC") P INNER JOIN (SELECT "$QC"LAT_CEC_name"$QC", "$QC"CEC_Model"$QC", "$QC"CEC_SN"$QC", "$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$VD_CDM_SUMM_L""_VM_DS") Q ON P."$QC"LAT_Hardware_Model"$QC" = Q."$QC"CEC_Model"$QC" AND SUBSTR(P."$QC"LAT_Machine_Serial"$QC", 7) = Q."$QC"CEC_SN"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC")"

    if [ ! -z "$LINUX_ENV" ]
    then
        VM_DS_VIEW_DEF="$VM_DS_VIEW_DEF ""UNION (SELECT P."$QC"Device_Name"$QC" AS DATA_STORE_NAME, P."$QC"Hostname"$QC" AS HOST_NAME, P."$QC"LPAR_Name"$QC" AS VM_NAME, Q."$QC"CEC_name"$QC" AS DATA_CENTER_NAME, (P."$QC"Read_bytes_per_sec"$QC"/1000) AS TOTAL_READ, (P."$QC"Write_bytes_per_sec"$QC"/1000) AS TOTAL_WRITE, (P."$QC"Transfers_bytes_per_sec"$QC"/1000) AS TOTAL_IO, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" FROM (SELECT LMI."$QC"System_Name"$QC", LMI."$QC"Hostname"$QC", LMI."$QC"Hardware_Model"$QC", LMI."$QC"Machine_Serial"$QC", LMI."$QC"WRITETIME"$QC", KL."$QC"LPAR_Name"$QC", KIOE."$QC"Device_Name"$QC", KIOE."$QC"Read_bytes_per_sec"$QC", KIOE."$QC"Write_bytes_per_sec"$QC", KIOE."$QC"Transfers_bytes_per_sec"$QC" FROM FED_Linux_Machine_Information"$VD_CDM_SUMM_L""_VM_DS" LMI, FED_KLZ_LPAR"$VD_CDM_SUMM_L""_VM_DS" KL, FED_KLZ_IO_Ext"$VD_CDM_SUMM_L""_VM_DS" KIOE WHERE LMI."$QC"System_Name"$QC" = KL."$QC"System_Name"$QC" AND KL."$QC"System_Name"$QC" = KIOE."$QC"System_Name"$QC" AND LMI."$QC"WRITETIME"$QC" = KL."$QC"WRITETIME"$QC" AND KL."$QC"WRITETIME"$QC" = KIOE."$QC"WRITETIME"$QC") P INNER JOIN (SELECT "$QC"CEC_name"$QC", "$QC"CEC_Model"$QC", "$QC"CEC_SN"$QC", "$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$VD_CDM_SUMM_L""_VM_DS") Q ON P."$QC"Hardware_Model"$QC" = Q."$QC"CEC_Model"$QC" AND P."$QC"Machine_Serial"$QC" = Q."$QC"CEC_SN"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC")"
        VM_DS_VIEW_DEF_AGG="$VM_DS_VIEW_DEF_AGG ""UNION (SELECT P."$QC"Device_Name"$QC" AS DATA_STORE_NAME, P."$QC"LAT_Hostname"$QC" AS HOST_NAME, P."$QC"LAT_LPAR_Name"$QC" AS VM_NAME, Q."$QC"LAT_CEC_name"$QC" AS DATA_CENTER_NAME, (P."$QC"MIN_Read_bytes_per_sec"$QC"/1000) AS MIN_TOTAL_READ, (P."$QC"MAX_Read_bytes_per_sec"$QC"/1000) AS MAX_TOTAL_READ, (P."$QC"AVG_Read_bytes_per_sec"$QC"/1000) AS AVG_TOTAL_READ, (P."$QC"SUM_Read_bytes_per_sec"$QC"/1000) AS SUM_TOTAL_READ, (P."$QC"MIN_Write_bytes_per_sec"$QC"/1000) AS MIN_TOTAL_WRITE, (P."$QC"MAX_Write_bytes_per_sec"$QC"/1000) AS MAX_TOTAL_WRITE, (P."$QC"AVG_Write_bytes_per_sec"$QC"/1000) AS AVG_TOTAL_WRITE, (P."$QC"SUM_Write_bytes_per_sec"$QC"/1000) AS SUM_TOTAL_WRITE, (P."$QC"MIN_Transfers_bytes_per_sec"$QC"/1000) AS MIN_TOTAL_IO, (P."$QC"MAX_Transfers_bytes_per_sec"$QC"/1000) AS MAX_TOTAL_IO, (P."$QC"AVG_Transfers_bytes_per_sec"$QC"/1000) AS AVG_TOTAL_IO, (P."$QC"SUM_Transfers_bytes_per_sec"$QC"/1000) AS SUM_TOTAL_IO, P."$QC"MIN_Read_req_per_sec"$QC" AS MIN_READ_OPS, P."$QC"MAX_Read_req_per_sec"$QC" AS MAX_READ_OPS, P."$QC"AVG_Read_req_per_sec"$QC" AS AVG_READ_OPS, P."$QC"SUM_Read_req_per_sec"$QC" AS SUM_READ_OPS, P."$QC"MIN_Write_req_per_sec"$QC" AS MIN_WRITE_OPS, P."$QC"MAX_Write_req_per_sec"$QC" AS MAX_WRITE_OPS, P."$QC"AVG_Write_req_per_sec"$QC" AS AVG_WRITE_OPS, P."$QC"SUM_Write_req_per_sec"$QC" AS SUM_WRITE_OPS, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" FROM (SELECT LMI."$QC"System_Name"$QC", LMI."$QC"LAT_Hostname"$QC", LMI."$QC"LAT_Hardware_Model"$QC", LMI."$QC"LAT_Machine_Serial"$QC", LMI."$QC"WRITETIME"$QC", KL."$QC"LAT_LPAR_Name"$QC", KIOE."$QC"Device_Name"$QC", KIOE."$QC"MIN_Read_bytes_per_sec"$QC", KIOE."$QC"MAX_Read_bytes_per_sec"$QC", KIOE."$QC"AVG_Read_bytes_per_sec"$QC", KIOE."$QC"SUM_Read_bytes_per_sec"$QC", KIOE."$QC"MIN_Write_bytes_per_sec"$QC", KIOE."$QC"MAX_Write_bytes_per_sec"$QC", KIOE."$QC"AVG_Write_bytes_per_sec"$QC", KIOE."$QC"SUM_Write_bytes_per_sec"$QC", KIOE."$QC"MIN_Transfers_bytes_per_sec"$QC", KIOE."$QC"MAX_Transfers_bytes_per_sec"$QC", KIOE."$QC"AVG_Transfers_bytes_per_sec"$QC", KIOE."$QC"SUM_Transfers_bytes_per_sec"$QC", KIOE."$QC"MIN_Read_req_per_sec"$QC", KIOE."$QC"MAX_Read_req_per_sec"$QC", KIOE."$QC"AVG_Read_req_per_sec"$QC", KIOE."$QC"SUM_Read_req_per_sec"$QC", KIOE."$QC"MIN_Write_req_per_sec"$QC", KIOE."$QC"MAX_Write_req_per_sec"$QC", KIOE."$QC"AVG_Write_req_per_sec"$QC", KIOE."$QC"SUM_Write_req_per_sec"$QC" FROM FED_Linux_Machine_Information"$VD_CDM_SUMM_L""_VM_DS" LMI, FED_KLZ_LPAR"$VD_CDM_SUMM_L""_VM_DS" KL, FED_KLZ_IO_Ext"$VD_CDM_SUMM_L""_VM_DS" KIOE WHERE LMI."$QC"System_Name"$QC" = KL."$QC"System_Name"$QC" AND KL."$QC"System_Name"$QC" = KIOE."$QC"System_Name"$QC" AND LMI."$QC"WRITETIME"$QC" = KL."$QC"WRITETIME"$QC" AND KL."$QC"WRITETIME"$QC" = KIOE."$QC"WRITETIME"$QC") P INNER JOIN (SELECT "$QC"LAT_CEC_name"$QC", "$QC"CEC_Model"$QC", "$QC"CEC_SN"$QC", "$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$VD_CDM_SUMM_L""_VM_DS") Q ON P."$QC"LAT_Hardware_Model"$QC" = Q."$QC"CEC_Model"$QC" AND P."$QC"LAT_Machine_Serial"$QC" = Q."$QC"CEC_SN"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC")"
    fi

    if [ -z "$CDM_DB2CMD" ]
    then

		VIEW_DEF=$VM_DS_VIEW_DEF
		if [ ! -z "$VD_CDM_SUMM_L" ]
		then
			VIEW_DEF=$VM_DS_VIEW_DEF_AGG
		fi

        CDM_DB2CMD="$DB2_CMD_CREATE_VIEW $SPACE "$DM_SCHEMA_NAME"."MES_VM_DATA_STORE""$VD_CDM_SUMM_L" "$VIEW_DEF""
    fi
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo "$DB2 $CDM_DB2CMD" >> $TMP_DDL_FILE_NAME
	else
	echo "Creating view MES_VM_DATA_STORE$VD_CDM_SUMM_L" >> $LOG_F_NAME
    echo $CDM_DB2CMD > $TMP_F_NAME
    echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
	fi
    run_command
}

################################################################################
# Sets up the federation for Virtual Machine Disk utilization.
################################################################################
VM_DS_Process_Args()
{
    VDPA_SUMM_L=$1
    
    G_LAST_ERROR=0

    if [ $COMMAND == "-add" ]
    then
        
        create_nickname "Disk_Performance""$VDPA_SUMM_L" "VM_DS"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_DATA_STORE$VDPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        create_nickname "Machine_Information""$VDPA_SUMM_L" "VM_DS"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_DATA_STORE$VDPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        create_nickname "AIX_LPAR""$VDPA_SUMM_L" "VM_DS"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_DATA_STORE$VDPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        create_nickname "KPH_SERVER_LPARS""$VDPA_SUMM_L" "VM_DS"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_DATA_STORE$VDPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
			
		fi

        if [ ! -z $LINUX_ENV ]
        then
            create_nickname "Linux_Machine_Information""$VDPA_SUMM_L" "VM_DS"
		    if [ $G_LAST_ERROR != 0 ]
		    then
				FAILED_VIEW=$FAILED_VIEW","MES_VM_DATA_STORE$VDPA_SUMM_L
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            create_nickname "KLZ_LPAR""$VDPA_SUMM_L" "VM_DS"
		    if [ $G_LAST_ERROR != 0 ]
		    then
				FAILED_VIEW=$FAILED_VIEW","MES_VM_DATA_STORE$VDPA_SUMM_L
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            create_nickname "KLZ_IO_Ext""$VDPA_SUMM_L" "VM_DS"
		    if [ $G_LAST_ERROR != 0 ]
		    then
				FAILED_VIEW=$FAILED_VIEW","MES_VM_DATA_STORE$VDPA_SUMM_L
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

        fi
		
        VM_DS_create_dm_view $VDPA_SUMM_L
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_DATA_STORE$VDPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			echo "Failed to create a view MES_VM_DATA_STORE$VDPA_SUMM_L" >> $LOG_F_NAME
			echo "................................................................................" >> $LOG_F_NAME
			return
			else
			SUCCESS_VIEW=$SUCCESS_VIEW","MES_VM_DATA_STORE$VDPA_SUMM_L
			if [ $DBA_MODE != "DBAMODE" ]
				then
				echo "View MES_VM_DATA_STORE$VDPA_SUMM_L created successfully " >> $LOG_F_NAME 
			fi	
			
		fi

    elif [ $COMMAND == "-delete" ]
    then

        VM_DS_delete_dm_view "$VDPA_SUMM_L"
		if [ $G_LAST_ERROR != 0 ]
		then
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        if [ $VIEW_EXISTS -eq 1 ]
	    then
            delete_nickname "Disk_Performance""$VDPA_SUMM_L" "VM_DS"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            delete_nickname "Machine_Information""$VDPA_SUMM_L" "VM_DS"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            delete_nickname "AIX_LPAR""$VDPA_SUMM_L" "VM_DS"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            delete_nickname "KPH_SERVER_LPARS""$VDPA_SUMM_L" "VM_DS"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi
    
            if [ ! -z $LINUX_ENV ]
            then
                delete_nickname "Linux_Machine_Information""$VDPA_SUMM_L" "VM_DS"
		        if [ $G_LAST_ERROR != 0 ]
		        then
			        G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			        return
		        fi

                delete_nickname "KLZ_LPAR""$VDPA_SUMM_L" "VM_DS"
		        if [ $G_LAST_ERROR != 0 ]
		        then
			        G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			        return
		        fi

                delete_nickname "KLZ_IO_Ext""$VDPA_SUMM_L" "VM_DS"
		        if [ $G_LAST_ERROR != 0 ]
		        then
			        G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			        return
		        fi
    
            fi

        fi

    fi
    if [ $DBA_MODE != "DBAMODE" ]
	then
    echo "................................................................................" >> $LOG_F_NAME
    fi
}

################################################################################
# Removes view MES_VM_NET_*
################################################################################
VM_NET_delete_dm_view()
{
    G_LAST_ERROR=0

    VMNET_SUMM_L=$1
    TABLE_BODY=$TABLE_BODY_VM_NET

    if [ ! -z $VMNET_SUMM_L ]
    then
        TABLE_BODY=$TABLE_BODY_VM_NET_AGG
    fi


	drop_view_if_exists "VM_NETWORK""$VMNET_SUMM_L"
    if [ $G_LAST_ERROR != 0 ]
    then
        return
    fi

	if [ $VIEW_EXISTS -eq 1 ]
	then
		create_dm_table "VM_NETWORK""$VMNET_SUMM_L" "$TABLE_BODY"
        if [ $G_LAST_ERROR != 0 ]
        then
            return
        fi
	fi
}

################################################################################
# Creates Datamart view: MES_VM_NET*
# Arguments:
#   $1 (Mandatory)  :   Summarization level
################################################################################
VM_NET_create_dm_view()
{
   G_LAST_ERROR=0
    CDM_DB2CMD=""

    VN_CDM_SUMM_L=$1
	drop_table_if_exists "MES_VM_NETWORK""$VN_CDM_SUMM_L"
	if [ $G_LAST_ERROR != 0 ]
	then
		return
	fi

	if [ $DB2_VERSION = "v9.5" ]
	then
		drop_view_if_exists "VM_NETWORK""$VN_CDM_SUMM_L"
		if [ $G_LAST_ERROR != 0 ]
		then
			return
		fi
	fi

    VM_NET_VIEW_DEF="(HOST_NAME, VM_NAME, VM_SERVER_NAME, TRANSMITTED_KBPS, RECEIVED_KBPS, PKTS_TRANSMITTED, PKTS_RECEIVED, TIMESTAMP, WRITETIME) AS ( SELECT P."$QC"Hostname"$QC" AS HOST_NAME, P."$QC"LPAR_Name"$QC" AS VM_NAME, Q."$QC"CEC_name"$QC" AS VM_SERVER_NAME, (P."$QC"Transmitted_MB"$QC"/1000) AS TRANSMITTED_KBPS, (P."$QC"Received_MB"$QC"/1000) AS RECEIVED_KBPS, P."$QC"Transmitted_Count_64"$QC" AS PKTS_TRANSMITTED, P."$QC"Received_Count_64"$QC" AS PKTS_RECEIVED, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" FROM (SELECT MI."$QC"Hostname"$QC", MI."$QC"Hardware_Model"$QC", MI."$QC"Machine_Serial"$QC", AL."$QC"LPAR_Name"$QC", NET."$QC"Transmitted_MB"$QC", NET."$QC"Received_MB"$QC", NET."$QC"Transmitted_Count_64"$QC", NET."$QC"Received_Count_64"$QC", NET."$QC"WRITETIME"$QC" FROM FED_Machine_Information"$VN_CDM_SUMM_L""_VM_NET" MI, FED_AIX_LPAR"$VN_CDM_SUMM_L""_VM_NET" AL, FED_Network"$VN_CDM_SUMM_L""_VM_NET" NET WHERE NET."$QC"Network_Interface_Name"$QC" != 'Aggregate' AND NET."$QC"System_Name"$QC" = MI."$QC"System_Name"$QC" AND MI."$QC"System_Name"$QC" = AL."$QC"System_Name"$QC" AND NET."$QC"WRITETIME"$QC" = MI."$QC"WRITETIME"$QC" AND MI."$QC"WRITETIME"$QC" = AL."$QC"WRITETIME"$QC") P INNER JOIN (SELECT "$QC"CEC_name"$QC", "$QC"CEC_Mfg"$QC", "$QC"CEC_Model"$QC", "$QC"CEC_SN"$QC", "$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$VN_CDM_SUMM_L""_VM_NET") Q ON P."$QC"Hardware_Model"$QC" = Q."$QC"CEC_Model"$QC" AND SUBSTR(P."$QC"Machine_Serial"$QC", 7) = Q."$QC"CEC_SN"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC")"
    VM_NET_VIEW_DEF_AGG="(HOST_NAME, VM_NAME, VM_SERVER_NAME, MIN_TRANSMITTED_KBPS, MAX_TRANSMITTED_KBPS, AVG_TRANSMITTED_KBPS, SUM_TRANSMITTED_KBPS, MIN_RECEIVED_KBPS, MAX_RECEIVED_KBPS, AVG_RECEIVED_KBPS, SUM_RECEIVED_KBPS, MIN_PKTS_TRANSMITTED, MAX_PKTS_TRANSMITTED, AVG_PKTS_TRANSMITTED, SUM_PKTS_TRANSMITTED, MIN_PKTS_RECEIVED, MAX_PKTS_RECEIVED, AVG_PKTS_RECEIVED, SUM_PKTS_RECEIVED, TIMESTAMP, WRITETIME) AS ( SELECT P."$QC"LAT_Hostname"$QC" AS HOST_NAME, P."$QC"LAT_LPAR_Name"$QC" AS VM_NAME, Q."$QC"LAT_CEC_name"$QC" AS VM_SERVER_NAME, (P."$QC"MIN_Transmitted_MB"$QC"*1000) AS MIN_TRANSMITTED_KBPS, (P."$QC"MAX_Transmitted_MB"$QC"*1000) AS MAX_TRANSMITTED_KBPS, (P."$QC"AVG_Transmitted_MB"$QC"*1000) AS AVG_TRANSMITTED_KBPS, (P."$QC"SUM_Transmitted_MB"$QC"*1000) AS SUM_TRANSMITTED_KBPS, (P."$QC"MIN_Received_MB"$QC"*1000) AS MIN_RECEIVED_KBPS, (P."$QC"MAX_Received_MB"$QC"*1000) AS MAX_RECEIVED_KBPS, (P."$QC"AVG_Received_MB"$QC"*1000) AS AVG_RECEIVED_KBPS, (P."$QC"SUM_Received_MB"$QC"*1000) AS SUM_RECEIVED_KBPS, P."$QC"MIN_Frames_Transmitted_per_sec"$QC" AS MIN_PKTS_TRANSMITTED, P."$QC"MAX_Frames_Transmitted_per_sec"$QC" AS MAX_PKTS_TRANSMITTED, P."$QC"AVG_Frames_Transmitted_per_sec"$QC" AS AVG_PKTS_TRANSMITTED, P."$QC"SUM_Frames_Transmitted_per_sec"$QC" AS SUM_PKTS_TRANSMITTED, P."$QC"MIN_Frames_Received_per_sec"$QC" AS MIN_PKTS_RECEIVED, P."$QC"MAX_Frames_Received_per_sec"$QC" AS MAX_PKTS_RECEIVED, P."$QC"AVG_Frames_Received_per_sec"$QC" AS AVG_PKTS_RECEIVED, P."$QC"SUM_Frames_Received_per_sec"$QC" AS SUM_PKTS_RECEIVED, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" FROM (SELECT MI."$QC"LAT_Hostname"$QC", MI."$QC"LAT_Hardware_Model"$QC", MI."$QC"LAT_Machine_Serial"$QC", AL."$QC"LAT_LPAR_Name"$QC", NET."$QC"MIN_Transmitted_MB"$QC", NET."$QC"MAX_Transmitted_MB"$QC", NET."$QC"AVG_Transmitted_MB"$QC", NET."$QC"SUM_Transmitted_MB"$QC", NET."$QC"MIN_Received_MB"$QC", NET."$QC"MAX_Received_MB"$QC", NET."$QC"AVG_Received_MB"$QC", NET."$QC"SUM_Received_MB"$QC", NET."$QC"MIN_Frames_Transmitted_per_sec"$QC", NET."$QC"MAX_Frames_Transmitted_per_sec"$QC", NET."$QC"AVG_Frames_Transmitted_per_sec"$QC", NET."$QC"SUM_Frames_Transmitted_per_sec"$QC", NET."$QC"MIN_Frames_Received_per_sec"$QC", NET."$QC"MAX_Frames_Received_per_sec"$QC", NET."$QC"AVG_Frames_Received_per_sec"$QC", NET."$QC"SUM_Frames_Received_per_sec"$QC", NET."$QC"WRITETIME"$QC" FROM FED_Machine_Information"$VN_CDM_SUMM_L""_VM_NET" MI, FED_AIX_LPAR"$VN_CDM_SUMM_L""_VM_NET" AL, FED_Network"$VN_CDM_SUMM_L""_VM_NET" NET WHERE NET."$QC"Network_Interface_Name"$QC" != 'Aggregate' AND NET."$QC"System_Name"$QC" = MI."$QC"System_Name"$QC" AND MI."$QC"System_Name"$QC" = AL."$QC"System_Name"$QC" AND NET."$QC"WRITETIME"$QC" = MI."$QC"WRITETIME"$QC" AND MI."$QC"WRITETIME"$QC" = AL."$QC"WRITETIME"$QC") P INNER JOIN (SELECT "$QC"LAT_CEC_name"$QC", "$QC"CEC_Mfg"$QC", "$QC"CEC_Model"$QC", "$QC"CEC_SN"$QC", "$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$VN_CDM_SUMM_L""_VM_NET") Q ON P."$QC"LAT_Hardware_Model"$QC" = Q."$QC"CEC_Model"$QC" AND SUBSTR(P."$QC"LAT_Machine_Serial"$QC", 7) = Q."$QC"CEC_SN"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC")"

    if [ ! -z "$LINUX_ENV" ]
    then
        VM_NET_VIEW_DEF="$VM_NET_VIEW_DEF"" UNION ( SELECT P."$QC"Hostname"$QC" AS HOST_NAME, P."$QC"LPAR_Name"$QC" AS VM_NAME, Q."$QC"CEC_name"$QC" AS VM_SERVER_NAME, P."$QC"KBytes_Transmitted_Count"$QC" AS TRANSMITTED_KBPS, P."$QC"KBytes_Received_Count"$QC" AS RECEIVED_KBPS, P."$QC"Packets_Transmitted"$QC" AS PKTS_TRANSMITTED, P."$QC"Packets_Received_Count"$QC" AS PKTS_RECEIVED, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" FROM (SELECT LMI."$QC"Hostname"$QC", LMI."$QC"Hardware_Model"$QC", LMI."$QC"Machine_Serial"$QC", KN."$QC"WRITETIME"$QC", KL."$QC"LPAR_Name"$QC", KN."$QC"KBytes_Transmitted_Count"$QC", KN."$QC"KBytes_Received_Count"$QC", KN."$QC"Packets_Transmitted"$QC", KN."$QC"Packets_Received_Count"$QC" FROM FED_Linux_Machine_Information"$VN_CDM_SUMM_L""_VM_NET" LMI, FED_KLZ_LPAR"$VN_CDM_SUMM_L""_VM_NET" KL, FED_KLZ_Network"$VN_CDM_SUMM_L""_VM_NET" KN WHERE KN."$QC"Network_Interface_Name"$QC" != 'Aggregate' AND KN."$QC"System_Name"$QC" = LMI."$QC"System_Name"$QC" AND LMI."$QC"System_Name"$QC" = KL."$QC"System_Name"$QC" AND KN."$QC"WRITETIME"$QC" = LMI."$QC"WRITETIME"$QC" AND LMI."$QC"WRITETIME"$QC" = KL."$QC"WRITETIME"$QC") P INNER JOIN (SELECT "$QC"CEC_name"$QC", "$QC"CEC_Mfg"$QC", "$QC"CEC_Model"$QC", "$QC"CEC_SN"$QC", "$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$VN_CDM_SUMM_L""_VM_NET") Q ON P."$QC"Hardware_Model"$QC" = Q."$QC"CEC_Model"$QC" AND P."$QC"Machine_Serial"$QC" = Q."$QC"CEC_SN"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC")"
        VM_NET_VIEW_DEF_AGG="$VM_NET_VIEW_DEF_AGG"" UNION (SELECT P."$QC"LAT_Hostname"$QC" AS HOST_NAME, P."$QC"LAT_LPAR_Name"$QC" AS VM_NAME, Q."$QC"LAT_CEC_name"$QC" AS VM_SERVER_NAME, P."$QC"MIN_Bytes_Transmitted_per_sec"$QC"/1000 AS MIN_TRANSMITTED_KBPS, P."$QC"MAX_Bytes_Transmitted_per_sec"$QC"/1000 AS MAX_TRANSMITTED_KBPS, P."$QC"AVG_Bytes_Transmitted_per_sec"$QC"/1000 AS AVG_TRANSMITTED_KBPS, P."$QC"SUM_Bytes_Transmitted_per_sec"$QC"/1000 AS SUM_TRANSMITTED_KBPS, P."$QC"MIN_Bytes_Received_per_sec"$QC"/1000 AS MIN_RECEIVED_KBPS, P."$QC"MAX_Bytes_Received_per_sec"$QC"/1000 AS MAX_RECEIVED_KBPS, P."$QC"AVG_Bytes_Received_per_sec"$QC"/1000 AS AVG_RECEIVED_KBPS, P."$QC"SUM_Bytes_Received_per_sec"$QC"/1000 AS SUM_RECEIVED_KBPS, P."$QC"MIN_$TRANSMITTED_PKTS_COL_NAME"$QC" AS MIN_PKTS_TRANSMITTED, P."$QC"MAX_$TRANSMITTED_PKTS_COL_NAME"$QC" AS MAX_PKTS_TRANSMITTED, P."$QC"AVG_$TRANSMITTED_PKTS_COL_NAME"$QC" AS AVG_PKTS_TRANSMITTED, P."$QC"SUM_$TRANSMITTED_PKTS_COL_NAME"$QC" AS SUM_PKTS_TRANSMITTED, P."$QC"MIN_Packets_Received_per_sec"$QC" AS MIN_PKTS_RECEIVED, P."$QC"MAX_Packets_Received_per_sec"$QC" AS MAX_PKTS_RECEIVED, P."$QC"AVG_Packets_Received_per_sec"$QC" AS AVG_PKTS_RECEIVED, P."$QC"SUM_Packets_Received_per_sec"$QC" AS SUM_PKTS_RECEIVED, -1 AS TIMESTAMP, P."$QC"WRITETIME"$QC" FROM (SELECT LMI."$QC"LAT_Hostname"$QC", LMI."$QC"LAT_Hardware_Model"$QC", LMI."$QC"LAT_Machine_Serial"$QC", KN."$QC"WRITETIME"$QC", KL."$QC"LAT_LPAR_Name"$QC", KN."$QC"MIN_Bytes_Transmitted_per_sec"$QC", KN."$QC"MAX_Bytes_Transmitted_per_sec"$QC", KN."$QC"AVG_Bytes_Transmitted_per_sec"$QC", KN."$QC"SUM_Bytes_Transmitted_per_sec"$QC", KN."$QC"MIN_Bytes_Received_per_sec"$QC", KN."$QC"MAX_Bytes_Received_per_sec"$QC", KN."$QC"AVG_Bytes_Received_per_sec"$QC", KN."$QC"SUM_Bytes_Received_per_sec"$QC", KN."$QC"MIN_$TRANSMITTED_PKTS_COL_NAME"$QC", KN."$QC"MAX_$TRANSMITTED_PKTS_COL_NAME"$QC", KN."$QC"AVG_$TRANSMITTED_PKTS_COL_NAME"$QC", KN."$QC"SUM_$TRANSMITTED_PKTS_COL_NAME"$QC", KN."$QC"MIN_Packets_Received_per_sec"$QC", KN."$QC"MAX_Packets_Received_per_sec"$QC", KN."$QC"AVG_Packets_Received_per_sec"$QC", KN."$QC"SUM_Packets_Received_per_sec"$QC" FROM FED_Linux_Machine_Information"$VN_CDM_SUMM_L""_VM_NET" LMI, FED_KLZ_LPAR"$VN_CDM_SUMM_L""_VM_NET" KL, FED_KLZ_Network"$VN_CDM_SUMM_L""_VM_NET" KN WHERE KN."$QC"Network_Interface_Name"$QC" != 'Aggregate' AND KN."$QC"System_Name"$QC" = LMI."$QC"System_Name"$QC" AND LMI."$QC"System_Name"$QC" = KL."$QC"System_Name"$QC" AND KN."$QC"WRITETIME"$QC" = LMI."$QC"WRITETIME"$QC" AND LMI."$QC"WRITETIME"$QC" = KL."$QC"WRITETIME"$QC") P INNER JOIN (SELECT "$QC"LAT_CEC_name"$QC", "$QC"CEC_Mfg"$QC", "$QC"CEC_Model"$QC", "$QC"CEC_SN"$QC", "$QC"WRITETIME"$QC" FROM FED_KPH_SERVER_LPARS"$VN_CDM_SUMM_L""_VM_NET") Q ON P."$QC"LAT_Hardware_Model"$QC" = Q."$QC"CEC_Model"$QC" AND P."$QC"LAT_Machine_Serial"$QC" = Q."$QC"CEC_SN"$QC" AND P."$QC"WRITETIME"$QC" = Q."$QC"WRITETIME"$QC")"
    fi

    if [ -z "$CDM_DB2CMD" ]
    then

		VIEW_DEF=$VM_NET_VIEW_DEF
		if [ ! -z "$VN_CDM_SUMM_L" ]
		then
			VIEW_DEF=$VM_NET_VIEW_DEF_AGG
		fi

        CDM_DB2CMD="$DB2_CMD_CREATE_VIEW $SPACE "$DM_SCHEMA_NAME"."MES_VM_NETWORK""$VN_CDM_SUMM_L" "$VIEW_DEF""
    fi
	
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo "$DB2 $CDM_DB2CMD" >> $TMP_DDL_FILE_NAME
	else
	echo "Creating view MES_VM_NETWORK$VN_CDM_SUMM_L" >> $LOG_F_NAME
    echo $CDM_DB2CMD > $TMP_F_NAME
    echo $DB2_CMD_SEPARATOR >> $TMP_F_NAME
	fi
    run_command
}

################################################################################
# Sets up the federation for Virtual Machine Network utilization.
################################################################################
VM_NET_Process_Args()
{
    VNPA_SUMM_L=$1
    
    G_LAST_ERROR=0

    if [ $COMMAND == "-add" ]
    then
 
        create_nickname "Network""$VNPA_SUMM_L" "VM_NET"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_NETWORK$VNPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        create_nickname "Machine_Information""$VNPA_SUMM_L" "VM_NET"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_NETWORK$VNPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        create_nickname "AIX_LPAR""$VNPA_SUMM_L" "VM_NET"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_NETWORK$VNPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        create_nickname "KPH_SERVER_LPARS""$VNPA_SUMM_L" "VM_NET"
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_NETWORK$VNPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        if [ ! -z $LINUX_ENV ]
        then
            create_nickname "KLZ_LPAR""$VNPA_SUMM_L" "VM_NET"
		    if [ $G_LAST_ERROR != 0 ]
		    then
				FAILED_VIEW=$FAILED_VIEW","MES_VM_NETWORK$VNPA_SUMM_L
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            create_nickname "KLZ_Network""$VNPA_SUMM_L" "VM_NET"
		    if [ $G_LAST_ERROR != 0 ]
		    then
				FAILED_VIEW=$FAILED_VIEW","MES_VM_NETWORK$VNPA_SUMM_L
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            create_nickname "Linux_Machine_Information""$VNPA_SUMM_L" "VM_NET"
		    if [ $G_LAST_ERROR != 0 ]
		    then
				FAILED_VIEW=$FAILED_VIEW","MES_VM_NETWORK$VNPA_SUMM_L
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi
        fi

        VM_NET_create_dm_view $VNPA_SUMM_L
		if [ $G_LAST_ERROR != 0 ]
		then
			FAILED_VIEW=$FAILED_VIEW","MES_VM_NETWORK$VNPA_SUMM_L
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			echo "Failed to create a view MES_VM_NETWORK$VNPA_SUMM_L" >> $LOG_F_NAME
			echo "................................................................................" >> $LOG_F_NAME
			return
			else
			SUCCESS_VIEW=$SUCCESS_VIEW","MES_VM_NETWORK$VNPA_SUMM_L
			if [ $DBA_MODE != "DBAMODE" ]
				then
				echo "View MES_VM_NETWORK$VNPA_SUMM_L created successfully " >> $LOG_F_NAME 
			fi	
			
		fi       # TBD TBD TBD

    elif [ $COMMAND == "-delete" ]
    then

        VM_NET_delete_dm_view "$VNPA_SUMM_L"
		if [ $G_LAST_ERROR != 0 ]
		then
			G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			return
		fi

        if [ $VIEW_EXISTS -eq 1 ]
	    then

            delete_nickname "Network""$VNPA_SUMM_L" "VM_NET"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi
    
            delete_nickname "Machine_Information""$VNPA_SUMM_L" "VM_NET"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi
    
            delete_nickname "AIX_LPAR""$VNPA_SUMM_L" "VM_NET"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            delete_nickname "KPH_SERVER_LPARS""$VNPA_SUMM_L" "VM_NET"
		    if [ $G_LAST_ERROR != 0 ]
		    then
			    G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			    return
		    fi

            if [ ! -z $LINUX_ENV ]
            then
                delete_nickname "KLZ_LPAR""$VNPA_SUMM_L" "VM_NET"
		        if [ $G_LAST_ERROR != 0 ]
		        then
			        G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			        return
		        fi

                delete_nickname "KLZ_Network""$VNPA_SUMM_L" "VM_NET"
		        if [ $G_LAST_ERROR != 0 ]
		        then
			        G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			        return
		        fi
    
                delete_nickname "Linux_Machine_Information""$VNPA_SUMM_L" "VM_NET"
		        if [ $G_LAST_ERROR != 0 ]
		        then
			        G_FAILED_COUNT=`expr $G_FAILED_COUNT + 1`
			        return
		        fi
            fi
        fi

    fi
    if [ $DBA_MODE != "DBAMODE" ]
	then
    echo "................................................................................" >> $LOG_F_NAME
    fi
}

################################################################################
# Usage.
################################################################################
usage()
{
	echo "Usage: $0 -help
       tadfdc_setup_fed.sh -server <SERVER_NAME> -dm <DATABASE_NAME>
          -dmschema <SCHEMA_NAME> [-add | -delete]
          [ all | PS_CPU[_[H|D|W|M|Q|Y]] PS_MEM[_[H|D|W|M|Q|Y]]
          PS_IO[_[H|D|W|M|Q|Y]] PS_NET[_[H|D|W|M|Q|Y]]
          VM_CPU[_[H|D|W|M|Q|Y]] VM_MEM[_[H|D|W|M|Q|Y]]
          VM_NET[_[H|D|W|M|Q|Y]] VM_DS[_[H|D|W|M|Q|Y]] ]
where
       -server    : Name of the remote data source configured with
                    the DRDA wrapper using CREATE SERVER command
       -dm        : Name of the Capacity Planner database
       -dmschema  : Name of the Capacity Planner database schema
       -add       : Adds a federation link
       -delete    : Removes a federation link

Arguments are of the form MACHINE_COMPONENT[_AGGREGATION-LEVEL]

where
   MACHINE     : physical server (PS) or virtual machine (VM),
   COMPONENT   : CPU (CPU), memory (MEM), IO (IO),
                 network (NET) or datastore (DS)
and
   AGGREGATION-LEVEL   : Hourly (_H), Daily (_D), Weekly (_W),
                         Monthly (_M), Quarterly (_Q) or Yearly (_Y)
Argument all adds or deletes all the required federation links.

Examples

(i) Set up federation for Physical Server CPU Hourly utilization:

tadfdc_setup_fed.sh -server WHSERVER -dm TADFDCDB -dmschema TADFDC -add PS_CPU_
H

(ii) Set up federation for Virtual Machine Memory Daily utilization:

tadfdc_setup_fed.sh -server WHSERVER -dm TADFDCDB -dmschema TADFDC -add VM_MEM_
D

(iii) Set up federation for Physical Server Network Weekly utilization:

tadfdc_setup_fed.sh -server WHSERVER -dm TADFDCDB -dmschema TADFDC -add PS_NET_
W

(iv) Set up federation for all supported utilization metrics:

tadfdc_setup_fed.sh -server WHSERVER -dm TADFDCDB -dmschema TADFDC -add all

(v) Remove federation for Virtual Machine Datastore Monthly utilization:

tadfdc_setup_fed.sh -server WHSERVER -dm TADFDCDB -dmschema TADFDC -delete VM_D
S_M

(vi) Remove federation for Physical Server Disk IO Quarterly utilization:

tadfdc_setup_fed.sh -server WHSERVER -dm TADFDCDB -dmschema TADFDC -delete PS_I
O_Q"
}

################################################################################
# Initializes the working environment of the script.
################################################################################
init()
{
    G_LAST_ERROR=0
	
	
	if [ -f $TMP_F_NAME ]
	then
		$REM $TMP_F_NAME
	fi

    LOCAL_SERVER_NAME=$2
    DM_NAME=$4
    DM_SCHEMA_NAME=$6
	DBA_MODE=$7
	TDW_SCHEMA_NAME=$8
    COMMAND=$9

    NICK_NAME_PREFIX="$DM_SCHEMA_NAME"."FED"
    DM_VIEW_NAME_PREFIX="$DM_SCHEMA_NAME"."MES"
    TDW_TABLE_PREFIX="$LOCAL_SERVER_NAME"."$TDW_SCHEMA_NAME"
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo $DB2 "connect to $DM_NAME" >> $TMP_DDL_FILE_NAME
	G_LAST_ERROR=0
	else 
    $DB2 "connect to $DM_NAME" 2>&1 >> $LOG_F_NAME
	G_LAST_ERROR=$?
	fi
	
	if [ $G_LAST_ERROR != 0 ]
	then
		echo "Failed to connect to database: $DM_NAME." >> $LOG_F_NAME
		exit 6
	fi
	  
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo $DB2 "set schema=$DM_SCHEMA_NAME" >> $TMP_DDL_FILE_NAME
	G_LAST_ERROR=0
	else
	echo "Setting schema to: " $DM_SCHEMA_NAME "..." >> $LOG_F_NAME
    $DB2 "set schema=$DM_SCHEMA_NAME" 2>&1 >> $LOG_F_NAME
	fi
	G_LAST_ERROR=$?
	if [ $G_LAST_ERROR != 0 ]
	then
		echo "Failed to set schema to: $DM_SCHEMA_NAME." >> $LOG_F_NAME
		echo "................................................................................" >> $LOG_F_NAME
		echo >> $LOG_F_NAME
		
		exit 7
	fi

	if [ $DBA_MODE == "DBAMODE" ]
	then
	VERSION="DB2 v10.1.0.0"
	echo "db2 -x select service_level from sysibmadm.env_inst_info" >> $TMP_DDL_FILE_NAME
	G_LAST_ERROR=0
	else
	VERSION=`db2 -x select service_level from sysibmadm.env_inst_info`
	fi
	G_LAST_ERROR=$?
	if [ $G_LAST_ERROR != 0 ]
	then
		echo "Failed to extract DB2 version." >> $LOG_F_NAME
		exit 8
	fi

	DB2_VERSION=`expr substr "$VERSION" 5 4`
	if [ $DB2_VERSION = "v9.5" ]
	then
		DB2_CMD_CREATE_NICKNAME="CREATE NICKNAME"
		DB2_CMD_CREATE_VIEW="CREATE VIEW"
	fi
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo db2 set passthru $LOCAL_SERVER_NAME >> $TMP_DDL_FILE_NAME
	else 
	db2 set passthru $LOCAL_SERVER_NAME
	fi
	
    # Check if the ITM POWER environment has Linux OS agent activated.
	if [ $DBA_MODE == "DBAMODE" ]
	then
	G_LAST_ERROR=0
		if [ $WRAPPER_NAME == "MSSQLODBC3" ] 
			then
				echo "db2 -x select name from sys.objects where name = 'KLZ_LPAR' and type = 'U' and schema_name(schema_id) = '$TDW_SCHEMA_NAME'" >> $TMP_DDL_FILE_NAME
			elif [ $WRAPPER_NAME == "DRDA" ] 
			then
				echo "db2 -x select tabname from syscat.tables where tabname = 'KLZ_LPAR' and type = 'T' and tabschema = '$TDW_SCHEMA_NAME' " >> $TMP_DDL_FILE_NAME
			elif [ $WRAPPER_NAME == "NET8" ] 
			then
				echo "db2 -x select table_name from all_tables where table_name = 'KLZ_LPAR' and owner = '$TDW_SCHEMA_NAME'">>  $TMP_DDL_FILE_NAME
			fi
	else 
			if [ $WRAPPER_NAME == "MSSQLODBC3" ] 
			then
				LINUX_ENV=
				db2 -x "select name from sys.objects where name = 'KLZ_LPAR' and type = 'U' and schema_name(schema_id) = '$TDW_SCHEMA_NAME'"
			elif [ $WRAPPER_NAME == "DRDA" ] 
			then
				LINUX_ENV=
				db2 -x "select tabname from syscat.tables where tabname = 'KLZ_LPAR' and type = 'T' and tabschema = '$TDW_SCHEMA_NAME' "
			elif [ $WRAPPER_NAME == "NET8" ] 
			then
				LINUX_ENV=
				db2 -x "select table_name from all_tables where table_name = 'KLZ_LPAR' and owner = '$TDW_SCHEMA_NAME'"
			fi
			G_LAST_ERROR=$?
	fi

	
	if [ $G_LAST_ERROR == 0 ]
	then
		LINUX_ENV=1
	fi
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo "db2 set passthru RESET " >>  $TMP_DDL_FILE_NAME
	else 
	db2 set passthru RESET
	fi
}

################################################################################
# Releases resources.
################################################################################
shut_down()
{
	rm -f $TMP_F_NAME
	echo >> $LOG_F_NAME
	if [ $DBA_MODE != "DBAMODE" ]
	then
	echo "Disconnecting from: " $DM_NAME >> $LOG_F_NAME
	fi
}

################################################################################
# Argument parsing.
################################################################################
parse_arguments()
{
    G_LAST_ERROR=0

    if [ $# -eq 1 ]
    then
        if [ $1 == "-help" ]
        then
            # "Configures federation between remote metrics data sources and the
            # Capacity Planner database."
            $JAVA $CLASSNAME "ANA01003I"
        else
            $JAVA $CLASSNAME "ANA01002E"
            usage
            exit 6
       	fi

        usage
        exit 0
    fi

    if [ $# -lt 9 ]
    then
        $JAVA $CLASSNAME "ANA01002E"
        usage
        exit 1
    fi

    if [ $1 != "-server" -o $3 != "-dm" -o $5 != "-dmschema" ]
    then
        $JAVA $CLASSNAME "ANA01002E"
        usage
        exit 2
    fi
#### 7th argument is DBA MODE 
    if [ $9 != "-add" -a $9 != "-delete" ]
    then
        $JAVA $CLASSNAME "ANA01002E"
        usage
        exit 3
    fi

    ITEM_NO=0
    for ITEM in $*
    do
        ITEM_NO=$[ITEM_NO + 1]
        if [ $ITEM_NO -lt 10 ]
        then
            continue;
        fi
		
		case $ITEM in
			all)

            shift
            ;;

            PS_CPU|PS_CPU_H|PS_CPU_D|PS_CPU_W|PS_CPU_M|PS_CPU_Q|PS_CPU_Y)
            shift
            ;;

            PS_MEM|PS_MEM_H|PS_MEM_D|PS_MEM_W|PS_MEM_M|PS_MEM_Q|PS_MEM_Y)
            ;;

            PS_IO|PS_IO_H|PS_IO_D|PS_IO_W|PS_IO_M|PS_IO_Q|PS_IO_Y)
            ;;

            PS_NET|PS_NET_H|PS_NET_D|PS_NET_W|PS_NET_M|PS_NET_Q|PS_NET_Y)
            ;;

            VM_CPU|VM_CPU_H|VM_CPU_D|VM_CPU_W|VM_CPU_M|VM_CPU_Q|VM_CPU_Y)
            ;;

            VM_MEM|VM_MEM_H|VM_MEM_D|VM_MEM_W|VM_MEM_M|VM_MEM_Q|VM_MEM_Y)
            ;;

            VM_NET|VM_NET_H|VM_NET_D|VM_NET_W|VM_NET_M|VM_NET_Q|VM_NET_Y)
            ;;

            VM_DS|VM_DS_H|VM_DS_D|VM_DS_W|VM_DS_M|VM_DS_Q|VM_DS_Y)
            ;;

            *)
                echo "Invalid argument:" $ITEM >> $LOG_F_NAME
                usage
                exit 4
        esac

    done
}
################################################################################
# Sets up the federation environment.
################################################################################
process_arguments()
{
    G_LAST_ERROR=0

    shift 9
    while [ $# -gt 0 ]
    do
		ARG=$1
		ARG_LEN=${#ARG}
		SUMM_INDEX=`expr $ARG_LEN - 1`
		SUMM_L=`expr substr $ARG $SUMM_INDEX 2` 
		
		if [ "$SUMM_L" != "_H" -a "$SUMM_L" != "_D" -a "$SUMM_L" != "_W" -a "$SUMM_L" != "_M" -a "$SUMM_L" != "_Q" -a "$SUMM_L" != "_Y" ]
		then
			SUMM_L=""
		fi
		
        case $ARG in
            all)

            shift
            ;;

            PS_CPU|PS_CPU_H|PS_CPU_D|PS_CPU_W|PS_CPU_M|PS_CPU_Q|PS_CPU_Y)
                process "KPH_SERVER_DETAILS""$SUMM_L" `echo $1 | awk '{ sub("PS", "SERVER");print}'`
                shift
            ;;

            PS_MEM|PS_MEM_H|PS_MEM_D|PS_MEM_W|PS_MEM_M|PS_MEM_Q|PS_MEM_Y)
                PS_MEM_Process_Args $SUMM_L
                shift
            ;;

            PS_IO|PS_IO_H|PS_IO_D|PS_IO_W|PS_IO_M|PS_IO_Q|PS_IO_Y)
                NEW_ARG=`echo $ARG | awk '{ sub("PS", "SERVER");print}'`
                process "KVA_DISKS""$SUMM_L" `echo $NEW_ARG | awk '{ sub("IO", "DISK");print}'`
                shift
            ;;

            PS_NET|PS_NET_H|PS_NET_D|PS_NET_W|PS_NET_M|PS_NET_Q|PS_NET_Y)
                NEW_ARG=`echo $ARG | awk '{ sub("PS", "SERVER");print}'`
                process "KVA_NETWORK_ADAPTERS_RATES""$SUMM_L" `echo $NEW_ARG | awk '{ sub("NET", "NETWORK");print}'`
                shift
            ;;

            VM_CPU|VM_CPU_H|VM_CPU_D|VM_CPU_W|VM_CPU_M|VM_CPU_Q|VM_CPU_Y)
                process "KPH_SERVER_LPARS""$SUMM_L" `echo $ARG | awk '{ sub("VM_CPU", "VIRTUAL_MACHINES");print}'`
                shift
            ;;

            VM_MEM|VM_MEM_H|VM_MEM_D|VM_MEM_W|VM_MEM_M|VM_MEM_Q|VM_MEM_Y)
                VM_MEM_Process_Args $SUMM_L
                shift
            ;;

            VM_NET|VM_NET_H|VM_NET_D|VM_NET_W|VM_NET_M|VM_NET_Q|VM_NET_Y)
                VM_NET_Process_Args $SUMM_L
                shift
            ;;

            VM_DS|VM_DS_H|VM_DS_D|VM_DS_W|VM_DS_M|VM_DS_Q|VM_DS_Y)
                VM_DS_Process_Args $SUMM_L
                shift
            ;;

            *)
                usage
                exit 5
        esac
    done

    # run_commands
}

################################################################################
# Entry point.
################################################################################
main()
{

	ARGS=$*
	
	if [ $1 == "-CONFIGSERVER" ]
	then
		if [ $2 == "SET_AUTO_STATS_PROF_OFF" ]
		then
			PROFOFF $ARGS
		elif [ $2 == "CREATE_WRAPPER" ]
		then
			CREATE_WRAPPER $ARGS
		elif [ $2 == "CREATE_SERVER" ]
		then
			CREATE_SERVER $ARGS
		elif [ $2 == "CREATE_USER_MAPPING" ]
		then
			CREATE_USER_MAPPING $ARGS
		elif [ $2 == "UPDATE_USER_MAPPING" ]
		then
			UPDATE_USER_MAPPING $ARGS
		elif [ $2 == "DROP_WRAPPER" ]
		then
			DROP_WRAPPER $ARGS
		fi
	fi
	
	GET_WRAPPER_NAME_FOR_SERVER $*
	initTableDefs
	
	parse_arguments $ARGS
##### 7th argument is for DBA MODE  and 8th argument is TDW Schema Name
    if [ ${10} == "all" ]
    then
        ARGS="$* $ALL_SUPPORTED"
    fi

    # Handle interrupts gracefully.
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo "$DB2 terminate" >> $TMP_DDL_FILE_NAME 
	else
    trap "$DB2 terminate 2>&1 >> $LOG_F_NAME" 0 2 3 9 15
	fi
	$JAVA $CLASSNAME "ANA01003I"
    init $ARGS
	process_arguments $ARGS
    # "Please check $LOG_F_NAME for details."
    shut_down

		if [ $DBA_MODE != "DBAMODE" ]
	then	
	if [[ "$SUCCESS_VIEW" = "MES_VM_MEM_*" ]]
	then
	echo
	else
		if [ $LINUX_ENV == 1 ]
		then
		echo MEM_TDW_TABLES="Unix_Memory,Machine_Information,AIX_LPAR,KPH_SERVER_LPARS,KLZ_LPAR,KLZ_VM_Stats,Linux_Machine_Information,KVA_PHYSICAL_MEMORY,KVA_STORAGE_MAPPINGS,KVA_TADDM"
		else
		echo MEM_TDW_TABLES="Unix_Memory,Machine_Information,AIX_LPAR,KPH_SERVER_LPARS,KVA_PHYSICAL_MEMORY,KVA_STORAGE_MAPPINGS,KVA_TADDM"
		fi
	fi
	if [[ "$SUCCESS_VIEW" = "MES_VM_CPU_*" ]]
	then
	echo "View MES_VM_CPU_ is present "
	else 
	echo CPU_TDW_TABLES="KPH_SERVER_LPARS"
	fi
	if [[ "$SUCCESS_VIEW" = "MES_VM_DATA_STORE_*" ]]
	then
	echo
	else
		if [ $LINUX_ENV == 1 ]
		then
			echo DATA_STORE_TDW_TABLES="Disk_Performance,Machine_Information,AIX_LPAR,KPH_SERVER_LPARS,Linux_Machine_Information,KLZ_LPAR,KLZ_IO_Ext"
		else
			echo DATA_STORE_TDW_TABLES="Disk_Performance,Machine_Information,AIX_LPAR,KPH_SERVER_LPARS"
		fi
	
	fi
	if [[ "$SUCCESS_VIEW" = "MES_VM_NETWORK_*" ]]
	then
	echo
	else
		if [ $LINUX_ENV == 1 ]
		then
		echo NETWORK_TDW_TABLES="Network,Machine_Information,AIX_LPAR,KPH_SERVER_LPARS,KLZ_LPAR,KLZ_Network,Linux_Machine_Information"
		else
		echo NETWORK_TDW_TABLES="Network,Machine_Information,AIX_LPAR,KPH_SERVER_LPARS"
		fi
	fi
	fi
	echo SUCCESS_VIEWS=$SUCCESS_VIEW
	echo FAILED_COUNT=$G_FAILED_COUNT
	exit $G_LAST_ERROR
}

PROFOFF()
{
	DB_NAME=$3
	USER_NAME=$4
	USER_PASSWORD=$5
	DBA_MODE=$6
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo $DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD >> $TMP_DDL_FILE_NAME 
	echo $DB2 "update db cfg using AUTO_STATS_PROF OFF" >> $TMP_DDL_FILE_NAME
	echo $DB2 terminate >> $TMP_DDL_FILE_NAME 
	STATUS=0
	else
	$DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD
	$DB2 "update db cfg using AUTO_STATS_PROF OFF"
	STATUS=$?
	$DB2 terminate 2>&1 >> $LOG_F_NAME
	fi
	exit $STATUS
}

CREATE_WRAPPER()
{
	DB_NAME=$3
	USER_NAME=$4
	USER_PASSWORD=$5
	WRAPPER_NAME=$6
	DBA_MODE=$7
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo $DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD >> $TMP_DDL_FILE_NAME 
	echo $DB2 "CREATE WRAPPER $WRAPPER_NAME" >> $TMP_DDL_FILE_NAME 
	echo $DB2 terminate >> $TMP_DDL_FILE_NAME 
	STATUS=0
	else
	$DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD
	$DB2 "CREATE WRAPPER $WRAPPER_NAME"
	STATUS=$?
	$DB2 terminate 2>&1 >> $LOG_F_NAME
	fi
	echo $STATUS
	exit $STATUS
}

DROP_WRAPPER()
{
	DB_NAME=$3
	USER_NAME=$4
	USER_PASSWORD=$5
	DBA_MODE=$7
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo $DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD >> $TMP_DDL_FILE_NAME 
	echo $DB2 "DROP WRAPPER DRDA" >> $TMP_DDL_FILE_NAME 
	echo $DB2 terminate >> $TMP_DDL_FILE_NAME 
	STATUS=0
	else 
	$DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD
	$DB2 "DROP WRAPPER DRDA"
	STATUS=$?
	$DB2 terminate 2>&1 >> $LOG_F_NAME
	echo $STATUS
	fi
	exit $STATUS
}

CREATE_SERVER()
{

	CONN_STRING=$3
	conn_str_len=${#CONN_STRING}
	delim_index=`expr index "$CONN_STRING" "\:"`
	delim_index=`expr $delim_index + 1`
	num_chars=`expr $conn_str_len - $delim_index + 1`
	CONN_STRING=`expr substr $CONN_STRING $delim_index $num_chars`
	delim_index=`expr index "$CONN_STRING" "\/"`
	num_name_chars=`expr $delim_index - 1`
	DB_NAME=`expr substr $CONN_STRING 1 $num_name_chars`

	conn_str_len=${#CONN_STRING}
	delim_index=`expr $delim_index + 1`
	num_chars=`expr $conn_str_len - $delim_index + 1`
	CONN_STRING=`expr substr $CONN_STRING $delim_index $num_chars`
	delim_index=`expr index "$CONN_STRING" "\/"`
	num_name_chars=`expr $delim_index - 1`
	USER_NAME=`expr substr $CONN_STRING 1 $num_name_chars`

	conn_str_len=${#CONN_STRING}
	delim_index=`expr $delim_index + 1`
	num_chars=`expr $conn_str_len - $delim_index + 1`
	CONN_STRING=`expr substr $CONN_STRING $delim_index $num_chars`
	delim_index=${#CONN_STRING}
	num_name_chars=`expr $delim_index`
	USER_PASSWORD=`expr substr $CONN_STRING 1 $num_name_chars`

	SERVER_NAME=$4
	SERVER_TYPE=$5
	SERVER_VERSION=$6
	REMOTE_USER=$7
	REMOTE_PASSWORD=$8
	
	REMOTE_DB_CONF_STRING=$9
	conn_str_len=${#REMOTE_DB_CONF_STRING}
	delim_index=`expr index "$REMOTE_DB_CONF_STRING" "\/"`
	num_name_chars=`expr $delim_index - 1`
	WRAPPER_NAME=`expr substr $REMOTE_DB_CONF_STRING 1 $num_name_chars`
	
	delim_index=`expr $delim_index + 1`
	num_chars=`expr $conn_str_len - $delim_index + 1`
	REMOTE_DB_CONF_STRING=`expr substr $REMOTE_DB_CONF_STRING $delim_index $num_chars`
	delim_index=`expr index "$REMOTE_DB_CONF_STRING" "\/"`
	num_name_chars=`expr $delim_index - 1`
	NODE_NAME=`expr substr $REMOTE_DB_CONF_STRING 1 $num_name_chars`
	
	delim_index=`expr $delim_index + 1`
	num_chars=`expr $conn_str_len - $delim_index + 1`
	TDW_NAME=`expr substr $REMOTE_DB_CONF_STRING $delim_index $num_chars`
	
	DB_OPTIONS=""
	
	if [ ! -z "$NODE_NAME" ]
	then 
		DB_OPTIONS="NODE '$NODE_NAME'"
	fi
	
	if [ ! -z "$TDW_NAME" ]
	then 
		if [ ! -z "$DB_OPTIONS" ] 
		then
			DB_OPTIONS="$DB_OPTIONS"", DBNAME '$TDW_NAME'"
		else
			DB_OPTIONS="DBNAME '$TDW_NAME'"
		fi
	fi
	DBA_MODE=${10}
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo $DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD >> $TMP_DDL_FILE_NAME 
	echo $DB2 "CREATE SERVER $SERVER_NAME TYPE $SERVER_TYPE VERSION $SERVER_VERSION WRAPPER $WRAPPER_NAME AUTHORIZATION \"$REMOTE_USER\" PASSWORD \"$REMOTE_PASSWORD\" OPTIONS ($DB_OPTIONS)" >> $TMP_DDL_FILE_NAME 
	echo $DB2 terminate >> $TMP_DDL_FILE_NAME 
	STATUS=0
	else
	$DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD
	$DB2 "CREATE SERVER $SERVER_NAME TYPE $SERVER_TYPE VERSION $SERVER_VERSION WRAPPER $WRAPPER_NAME AUTHORIZATION \"$REMOTE_USER\" PASSWORD \"$REMOTE_PASSWORD\" OPTIONS ($DB_OPTIONS)" 
	STATUS=$?
	$DB2 terminate 2>&1 >> $LOG_F_NAME
	fi
	exit $STATUS

}

CREATE_USER_MAPPING()
{

	DB_NAME=$3
	USER_NAME=$4
	USER_PASSWORD=$5
	SERVER_NAME=$6
	REMOTE_USER=$7
	REMOTE_PASSWORD=$8
	DBA_MODE=$9
	if [ $DBA_MODE == "DBAMODE" ]
	then
	echo $DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD >> $TMP_DDL_FILE_NAME 
	echo $DB2 "CREATE USER MAPPING FOR $USER_NAME SERVER $SERVER_NAME OPTIONS (REMOTE_AUTHID '$REMOTE_USER', REMOTE_PASSWORD '$REMOTE_PASSWORD')" >> $TMP_DDL_FILE_NAME 
	echo $DB2 SET PASSTHRU $SERVER_NAME >> $TMP_DDL_FILE_NAME 
	echo $DB2 terminate >> $TMP_DDL_FILE_NAME 
	STATUS=0
	else
	$DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD
	$DB2 "CREATE USER MAPPING FOR $USER_NAME SERVER $SERVER_NAME OPTIONS (REMOTE_AUTHID '$REMOTE_USER', REMOTE_PASSWORD '$REMOTE_PASSWORD')"
	
	STATUS=$?
	echo $STATUS
	$DB2 SET PASSTHRU $SERVER_NAME
	$DB2 terminate 2>&1 >> $LOG_F_NAME
	fi
	exit $STATUS

}

UPDATE_USER_MAPPING()
{

	DB_NAME=$3
	USER_NAME=$4
	USER_PASSWORD=$5
	SERVER_NAME=$6
	REMOTE_USER=$7
	REMOTE_PASSWORD=$8
	DBA_MODE=$9
	if [ $DBA_MODE == "DBAMODE" ]
	then 
	echo $DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD >> $TMP_DDL_FILE_NAME 
	echo $DB2 "ALTER USER MAPPING FOR $USER_NAME SERVER $SERVER_NAME OPTIONS (SET REMOTE_AUTHID '$REMOTE_USER', SET REMOTE_PASSWORD '$REMOTE_PASSWORD')" >> $TMP_DDL_FILE_NAME 
	echo $DB2 terminate >> $TMP_DDL_FILE_NAME 
	else 
	$DB2 CONNECT TO $DB_NAME USER $USER_NAME USING $USER_PASSWORD
	$DB2 "ALTER USER MAPPING FOR $USER_NAME SERVER $SERVER_NAME OPTIONS (SET REMOTE_AUTHID '$REMOTE_USER', SET REMOTE_PASSWORD '$REMOTE_PASSWORD')"

	STATUS=$?
	$DB2 terminate 2>&1 >> $LOG_F_NAME
	echo $STATUS
	fi
	exit $STATUS

}

GET_WRAPPER_NAME_FOR_SERVER()
{
	DB_NAME=$4
	SERVER_NAME=$2
	DBA_MODE=$7
	if [ $DBA_MODE == "DBAMODE" ]
	then 
	echo $DB2 CONNECT TO $DB_NAME >> $TMP_DDL_FILE_NAME 
	echo $DB2 -x SELECT WRAPNAME FROM SYSCAT.SERVERS WHERE SERVERNAME=\'$SERVER_NAME\' >> $TMP_DDL_FILE_NAME 
	echo $DB2 terminate >> $TMP_DDL_FILE_NAME 
	$WRAPPER_NAME == "DRDA" 
	else
	$DB2 CONNECT TO $DB_NAME 2>&1 >> $LOG_F_NAME
	WRAPPER_NAME=`$DB2 -x SELECT WRAPNAME FROM SYSCAT.SERVERS WHERE SERVERNAME=\'$SERVER_NAME\'`
		if [ $WRAPPER_NAME == "MSSQLODBC3" ]
		then
			QC=""
			TRANSMITTED_PKTS_COL_NAME="Packets_Transmitted_per_sec"
		fi
	$DB2 terminate
	fi
}

# Main
main $*
