#!/bin/sh

# ****************************************************************************
# IBM Confidential
# OCO Source Materials
# (c) Copyright IBM Corp. 2011
#
# The source code for this program is not published or otherwise divested of
# its trade secrets, irrespective of what has been deposited with the U.S.
# Copyright Office.
# ****************************************************************************

# Author: Rahul Shekatkar
# Return status of 0 means that configuration is already complete
# Return status of 1 means we must configure summarization ONLY 
# Return status of 2 means we must configure Historical collation
# Return status of 3 means we must configure both S&P & Hist collation

exec >> ./histconfig.log
exec 2>&1

CURDIR=`pwd`
cd $CANDLEHOME/bin


#Check if historical collection has been started on this agent:attribute group

prodCode=$1
attrGroup=$2
msnGroup=$3

retStatus=0

echo "Attribute Group is " $prodCode:$attrGroup

isHistStarted=0
lines=`./tacmd histlistcollections -t $prodCode -o "$attrGroup"`

for line in $lines
do
	if [ "$line" == 'Started(*'$msnGroup')' ];
	then
		isHistStarted=1
	fi
done

#Check if Summarization and Pruning has been configured
lines=`./tacmd histviewattributegroup -t $prodCode -o "$attrGroup"`

START_COUNTING=0
COUNT=0
set cnt=0
for line in $lines
do
        if [ "$line" == "Yearly" ];
	then
		START_COUNTING=1
        fi

       	if [ $START_COUNTING == 1 ]
       	then
		COUNT=$(( $COUNT + 1 ))
       	fi
       	if [ $COUNT == 15 ];
	then
		# COUNT of 15 checks if Daily Summarization is configured
    		if [ "$line" == "Off" ];
       		then
			# Summarization is not configured
			# Check if History collection is configured:
			echo "Summarization is not configured"
			if [ $isHistStarted -eq 1 ]
			then
				# Must configure Summarization Only
        			echo "Historical Collection  already started for $attrGroup";
				echo "Must configure Summarization & Pruning";
				retStatus=1
			else
				# Must configure both S&P & Hist collation
				echo "Nothing is configured.  Must configure both historical collection and S&P for $attrGroup";
        			retStatus=3
			fi

       		else
			# Summarization is configured
                        # Check if History collection is configured:
                        if [ $isHistStarted -eq 1 ]
                        then
                                # Everything is configured properly
                                echo "Historical Collection is configured properly for $attrGroup";
                                retStatus=0
                        else
                                # Must configure Historical collection
				echo "Historical Collection is not configured, but S&P is configured for $attrGroup";
                                retStatus=2
                        fi

		fi
			
        fi
done

cd $CURDIR

exit $retStatus
