############################################################ {COPYRIGHT-TOP} ###
# IBM Confidential
# OCO Source Materials
# Tivoli Common Reporting Infrastructure
# 5724-Q87
#
# (c) Copyright IBM Corp. 2007
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
############################################################ {COPYRIGHT-END} ##
# wsadmin jython script for creating a shared library.
# The shared library is associated with the classloader of the
# application server, so all applications running in the application
# server will use the same classes in the shared library.

import sys

# variables used below
global AdminConfig
global AdminControl

# Note:  script execution starts below at the main block

#-----------------------------------------
# Usage
#-----------------------------------------
def printUsage():
    print "Usage:  <was_profile_dir>/bin/wsadmin -lang jython -f addSharedLib.py <cellName> <nodeName> <serverName> <installDir>"
    print "   where <was_profile_dir>   is your was profile directory"
    print "         <cellName>          is the cell name of the server"
    print "         <nodeName>          is the node name of the server"
    print "         <serverName>        is the server name of the server"
    print "         <installDir>        is the path of the aucConsole installation"
    print "         <libName>        	is the name of the library"


#----------------------------------------------------------------------------
# definition of the getNodeId routine
#
# parameters:
#
# nodeName - the name of the node containing the server
#---------------------------------------------------------------------------
def getNodeId(nodeName):
   # make sure the node exists
   fullNodeName = "/Node:" + nodeName + "/"
   print "Looking for Node: " + fullNodeName
   nodeId = AdminConfig.getid(fullNodeName)
   if len(nodeId) == 0:
      print "   Exiting because the Node was not found"
      return None
   else:
      print "   Found Node: "  + nodeId
      return nodeId    

#----------------------------------------------------------------------------
# definition of the getAppId routine
#
# parameters:
#
# app - the name of the app to configure 
#---------------------------------------------------------------------------
def getAppId(app):
   appId = AdminConfig.getid('/Deployment:' + app + '/');
   return appId

#----------------------------------------------------------------------------
# definition of the createLibrary routine
#
# parameters:
#
# nodeId     - the id of the node containing the server
# shLibName  - the name of the shared library
# shLibDesc  - the description of the shared library
# shLibValue - the value of the shared library including the fully qualified path to the jars
#              if there are more than one jars, the user of this script is responsible for constructing
#              this value (ie, E:/ibm/tivoli/tip/coreapi.jar;E:/ibm/tivoli/tip/engineapi.jar; )
#---------------------------------------------------------------------------
def createLibrary(nodeId, shLibName, shLibDesc, shLibValue):
   print "Creating Library"
   libraryId = AdminConfig.create('Library', nodeId, [['name', shLibName], ['description',shLibDesc], ['classPath', shLibValue], ['isolatedClassLoader', 'true']])
   print "   Created Library: " + libraryId
   return libraryId

#----------------------------------------------------------------------------
# definition of the getClassLoaders routine
#
# parameters:
#
# appId - the application id used to retrieve the classloaders 
#---------------------------------------------------------------------------
def getClassLoaders(appId):
   print "Looking for Classloader for the Application " + appId
   classLoaderIds = AdminConfig.list('Classloader',appId).split(lineSeparator)
   return classLoaderIds

#----------------------------------------------------------------------------
# definition of the createClassLoader routine
#
# parameters:
#
# appId - the application Id used to retrieve the classloaders
# libraires - the list of librarys to add to the classloader
# mode       - the mode for the classLoader 'PARENT_LAST' or 'PARENT_FIRST'
#---------------------------------------------------------------------------
def createClassLoader(appId, libraries, mode):
   classLoaderId = AdminConfig.create('Classloader', appId, [['libraries', libraries ], ['mode', mode]])
   print "      Created Classloader: " + classLoaderId
   return classLoaderId

#----------------------------------------------------------------------------
# definition of the createLibraryRef routine
#
# parameters:
#
# classLoaderId - the id of a classloader for an application or server
# shLibName     - the name of the shared library to create a reference for
# isShared      - determines if the classloader is shared
#---------------------------------------------------------------------------
def createLibraryRef(classLoaderId, shLibName, isShared):
   print "Creating LibraryRef"
   libraryRefId = AdminConfig.create('LibraryRef', classLoaderId, [['libraryName', shLibName],  ['sharedClassloader', isShared]])
   print "   Created LibraryRef: " + libraryRefId
   return libraryRefId

#------------------------------------------------------------------------------
# definition of the search routine
#
# parameters:
# 
# shLibName   - the name of the node shared library
# 
#----------------------------------------------------------------------------
def search(shLibName):
    existingLibraryIds = AdminConfig.list('Library').split(lineSeparator)
    print "Found number of existing Libraries: %s" % (len(existingLibraryIds))
    for existingLibraryId in existingLibraryIds:
        if len(existingLibraryId) > 0:
            existingLibraryName = AdminConfig.showAttribute(existingLibraryId, 'name')
            print "      Library name: " + existingLibraryName
            if existingLibraryName == shLibName:
                return "true"
    return "false"


#---------------------------------------------------------------------------------
# definition of the addShLib routine
#
# parameters:
# 
# shLibName  - the name of the shared library
# app        - the application to apply the shared library to
# mode       - the mode for the classLoader 'PARENT_LAST' or 'PARENT_FIRST'
# isShared   - determins wheter the shLib classloader is shared 'true' or 'false' 
#---------------------------------------------------------------------------------
def addShLib(shLibName, app, mode, isShared):

   #get app id
   appId = getAppId(app)
   print "      APP name: " + app
   print "      APP ID: " + appId
   # look for the classloader for the application
   classLoaderIds = getClassLoaders(appId)
    
   classLoaderId = None
   # create the classloader if it does not exist
   if len(classLoaderIds) == 0:
      print "   Did not find Classloader, creating a new Classloader"
      classLoaderId = createClassLoader(appId, [], mode)
   else:
      classLoaderId = classLoaderIds[0]
      print "   Found Classloader: " + classLoaderId

   # create library ref associating appserver class to shared library
   print "Creating LibraryRef"
   libraryRefId = createLibraryRef(classLoaderId, shLibName, isShared)

   # Save all the changes made by this routine
   print "Saving all configuration changes made by addSharedLib"
   AdminConfig.save()
   print "   Saved all configuration changes"

#------------------------------------------------------------
# definition of the createTADfDCSharedLib routine
#
# installDir - the installation directory of aucConsole
# nodeId     - the node id containing the server
# app        - the application to associate the libray with
#------------------------------------------------------------
def createTADfDCSharedLib(installDir, nodeId, app, libName):
   #Classloader options
   PARENT_LAST = 'PARENT_LAST'
   PARENT_FIRST = 'PARENT_FIRST'
   TRUE = 'true'
   FALSE = 'false'   

   #TADfDC SHARED LIBRARY VARS
   TADfDCSharedLibName  = libName
   TADfDCSharedLibDesc  = "A shared library that represents the TADfDC (common-fileupload-1.2.1.jar) jars"
   TADfDCSharedLibValue = installDir + "/WEB-INF/lib/commons-fileupload-1.2.1.jar;" + installDir  + "/WEB-INF/lib/log4j-1.2.15.jar"
   
   successMsgTADfDC = "Shared library " + TADfDCSharedLibName + " installed correctly on "

   #Check for library already existing
   if ( search(TADfDCSharedLibName) == "true"):
      sys.stderr.write(TADfDCSharedLibName + " already exists, returning")
      sys.exit(0)
    
   #Create the library
   TADfDCLibraryId = createLibrary(nodeId, TADfDCSharedLibName, TADfDCSharedLibDesc, TADfDCSharedLibValue)
   #Add the shared library to the application
   addShLib(TADfDCSharedLibName, app, PARENT_FIRST, TRUE)
   print "Finished executing addShLib function"

   print "Verifying the installation, if the library was installed correctly successMsg would be printed"
   if search(TADfDCSharedLibName) == "true":
      print successMsgTADfDC + app
   else:
      sys.stderr.write("Shared library was not installed correctly\n")
      sys.exit(103)


###############################################################################
# Main block -- script execution starts here
###############################################################################

# Uncomment the following line to enable tracing to the wsadmin.traceout file
# AdminControl.trace('com.ibm.*=all=enabled')

# Initialize the values necessary to create shared library
# The shared library value will have to be changed based on the install root
# that was specified by the Installer's user. i.e. replace C: with the
# value of the directory specified by user

# Verify the correct number or parameters was passed in
if not (len(sys.argv) == 5):
   sys.stderr.write("Invalid number of arguments\n")
   printUsage()
   sys.exit(101)

# retrieve the cell name
cellName = sys.argv[0]

# retrieve the node name
nodeName = sys.argv[1]

# retrieve the server name
serverName = sys.argv[2]

# retrieve the install directory
installDir = sys.argv[3]

libName = sys.argv[4]

nodeId = getNodeId(nodeName)
if ( nodeId == None or len(nodeId) == 0 ):
   sys.stderr.write("Could not find the node\n")
   sys.exit(103)

#Application Name
analyticsConsoleApp = "isc"



createTADfDCSharedLib(installDir, nodeId, analyticsConsoleApp, libName)


AdminConfig.save()
print "   Saved all configuration changes"
